/* riscv-opc.h.  RISC-V instruction opcode and CSR macros.
   Copyright (C) 2011-2021 Free Software Foundation, Inc.
   Contributed by Andrew Waterman

   This file is part of GDB, GAS, and the GNU binutils.

   GDB, GAS, and the GNU binutils are free software; you can redistribute
   them and/or modify them under the terms of the GNU General Public
   License as published by the Free Software Foundation; either version
   3, or (at your option) any later version.

   GDB, GAS, and the GNU binutils are distributed in the hope that they
   will be useful, but WITHOUT ANY WARRANTY; without even the implied
   warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
   the GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING3. If not,
   see <http://www.gnu.org/licenses/>.  */

#ifndef RISCV_ENCODING_H
#define RISCV_ENCODING_H
/* Instruction opcode macros.  */
#define MATCH_SLLI_RV32 0x1013
#define MASK_SLLI_RV32  0xfe00707f
#define MATCH_SRLI_RV32 0x5013
#define MASK_SRLI_RV32  0xfe00707f
#define MATCH_SRAI_RV32 0x40005013
#define MASK_SRAI_RV32  0xfe00707f
#define MATCH_FRFLAGS 0x102073
#define MASK_FRFLAGS  0xfffff07f
#define MATCH_FSFLAGS 0x101073
#define MASK_FSFLAGS  0xfff0707f
#define MATCH_FSFLAGSI 0x105073
#define MASK_FSFLAGSI  0xfff0707f
#define MATCH_FRRM 0x202073
#define MASK_FRRM  0xfffff07f
#define MATCH_FSRM 0x201073
#define MASK_FSRM  0xfff0707f
#define MATCH_FSRMI 0x205073
#define MASK_FSRMI  0xfff0707f
#define MATCH_FSCSR 0x301073
#define MASK_FSCSR  0xfff0707f
#define MATCH_FRCSR 0x302073
#define MASK_FRCSR  0xfffff07f
#define MATCH_RDCYCLE 0xc0002073
#define MASK_RDCYCLE  0xfffff07f
#define MATCH_RDTIME 0xc0102073
#define MASK_RDTIME  0xfffff07f
#define MATCH_RDINSTRET 0xc0202073
#define MASK_RDINSTRET  0xfffff07f
#define MATCH_RDCYCLEH 0xc8002073
#define MASK_RDCYCLEH  0xfffff07f
#define MATCH_RDTIMEH 0xc8102073
#define MASK_RDTIMEH  0xfffff07f
#define MATCH_RDINSTRETH 0xc8202073
#define MASK_RDINSTRETH  0xfffff07f
#define MATCH_SCALL 0x73
#define MASK_SCALL  0xffffffff
#define MATCH_SBREAK 0x100073
#define MASK_SBREAK  0xffffffff
#define MATCH_BEQ 0x63
#define MASK_BEQ  0x707f
#define MATCH_BNE 0x1063
#define MASK_BNE  0x707f
#define MATCH_BLT 0x4063
#define MASK_BLT  0x707f
#define MATCH_BGE 0x5063
#define MASK_BGE  0x707f
#define MATCH_BLTU 0x6063
#define MASK_BLTU  0x707f
#define MATCH_BGEU 0x7063
#define MASK_BGEU  0x707f
#define MATCH_JALR 0x67
#define MASK_JALR  0x707f
#define MATCH_JAL 0x6f
#define MASK_JAL  0x7f
#define MATCH_LUI 0x37
#define MASK_LUI  0x7f
#define MATCH_AUIPC 0x17
#define MASK_AUIPC  0x7f
#define MATCH_ADDI 0x13
#define MASK_ADDI  0x707f
#define MATCH_SLLI 0x1013
#define MASK_SLLI  0xfc00707f
#define MATCH_SLTI 0x2013
#define MASK_SLTI  0x707f
#define MATCH_SLTIU 0x3013
#define MASK_SLTIU  0x707f
#define MATCH_XORI 0x4013
#define MASK_XORI  0x707f
#define MATCH_SRLI 0x5013
#define MASK_SRLI  0xfc00707f
#define MATCH_SRAI 0x40005013
#define MASK_SRAI  0xfc00707f
#define MATCH_ORI 0x6013
#define MASK_ORI  0x707f
#define MATCH_ANDI 0x7013
#define MASK_ANDI  0x707f
#define MATCH_ADD 0x33
#define MASK_ADD  0xfe00707f
#define MATCH_SUB 0x40000033
#define MASK_SUB  0xfe00707f
#define MATCH_SLL 0x1033
#define MASK_SLL  0xfe00707f
#define MATCH_SLT 0x2033
#define MASK_SLT  0xfe00707f
#define MATCH_SLTU 0x3033
#define MASK_SLTU  0xfe00707f
#define MATCH_XOR 0x4033
#define MASK_XOR  0xfe00707f
#define MATCH_SRL 0x5033
#define MASK_SRL  0xfe00707f
#define MATCH_SRA 0x40005033
#define MASK_SRA  0xfe00707f
#define MATCH_OR 0x6033
#define MASK_OR  0xfe00707f
#define MATCH_AND 0x7033
#define MASK_AND  0xfe00707f
#define MATCH_ADDIW 0x1b
#define MASK_ADDIW  0x707f
#define MATCH_SLLIW 0x101b
#define MASK_SLLIW  0xfe00707f
#define MATCH_SRLIW 0x501b
#define MASK_SRLIW  0xfe00707f
#define MATCH_SRAIW 0x4000501b
#define MASK_SRAIW  0xfe00707f
#define MATCH_ADDW 0x3b
#define MASK_ADDW  0xfe00707f
#define MATCH_SUBW 0x4000003b
#define MASK_SUBW  0xfe00707f
#define MATCH_SLLW 0x103b
#define MASK_SLLW  0xfe00707f
#define MATCH_SRLW 0x503b
#define MASK_SRLW  0xfe00707f
#define MATCH_SRAW 0x4000503b
#define MASK_SRAW  0xfe00707f
#define MATCH_LB 0x3
#define MASK_LB  0x707f
#define MATCH_LH 0x1003
#define MASK_LH  0x707f
#define MATCH_LW 0x2003
#define MASK_LW  0x707f
#define MATCH_LD 0x3003
#define MASK_LD  0x707f
#define MATCH_LBU 0x4003
#define MASK_LBU  0x707f
#define MATCH_LHU 0x5003
#define MASK_LHU  0x707f
#define MATCH_LWU 0x6003
#define MASK_LWU  0x707f
#define MATCH_SB 0x23
#define MASK_SB  0x707f
#define MATCH_SH 0x1023
#define MASK_SH  0x707f
#define MATCH_SW 0x2023
#define MASK_SW  0x707f
#define MATCH_SD 0x3023
#define MASK_SD  0x707f
#define MATCH_PAUSE 0x0100000f
#define MASK_PAUSE  0xffffffff
#define MATCH_FENCE 0xf
#define MASK_FENCE  0x707f
#define MATCH_FENCE_I 0x100f
#define MASK_FENCE_I  0x707f
#define MATCH_FENCE_TSO 0x8330000f
#define MASK_FENCE_TSO  0xfff0707f
#define MATCH_MUL 0x2000033
#define MASK_MUL  0xfe00707f
#define MATCH_MULH 0x2001033
#define MASK_MULH  0xfe00707f
#define MATCH_MULHSU 0x2002033
#define MASK_MULHSU  0xfe00707f
#define MATCH_MULHU 0x2003033
#define MASK_MULHU  0xfe00707f
#define MATCH_DIV 0x2004033
#define MASK_DIV  0xfe00707f
#define MATCH_DIVU 0x2005033
#define MASK_DIVU  0xfe00707f
#define MATCH_REM 0x2006033
#define MASK_REM  0xfe00707f
#define MATCH_REMU 0x2007033
#define MASK_REMU  0xfe00707f
#define MATCH_MULW 0x200003b
#define MASK_MULW  0xfe00707f
#define MATCH_DIVW 0x200403b
#define MASK_DIVW  0xfe00707f
#define MATCH_DIVUW 0x200503b
#define MASK_DIVUW  0xfe00707f
#define MATCH_REMW 0x200603b
#define MASK_REMW  0xfe00707f
#define MATCH_REMUW 0x200703b
#define MASK_REMUW  0xfe00707f
#define MATCH_ANDN 0x40007033
#define MASK_ANDN  0xfe00707f
#define MATCH_ORN 0x40006033
#define MASK_ORN  0xfe00707f
#define MATCH_XNOR 0x40004033
#define MASK_XNOR  0xfe00707f
#define MATCH_SLOI 0x20001013
#define MASK_SLOI  0xfc00707f
#define MATCH_SROI 0x20005013
#define MASK_SROI  0xfc00707f
#define MATCH_SLO 0x20001033
#define MASK_SLO  0xfe00707f
#define MATCH_SRO 0x20005033
#define MASK_SRO  0xfe00707f
#define MATCH_ROL 0x60001033
#define MASK_ROL  0xfe00707f
#define MATCH_ROR 0x60005033
#define MASK_ROR  0xfe00707f
#define MATCH_BCLR 0x48001033
#define MASK_BCLR  0xfe00707f
#define MATCH_BSET 0x28001033
#define MASK_BSET  0xfe00707f
#define MATCH_BINV 0x68001033
#define MASK_BINV  0xfe00707f
#define MATCH_BEXT 0x48005033
#define MASK_BEXT  0xfe00707f
#define MATCH_GORC 0x28005033
#define MASK_GORC  0xfe00707f
#define MATCH_GREV 0x68005033
#define MASK_GREV  0xfe00707f
#define MATCH_RORI 0x60005013
#define MASK_RORI  0xfc00707f
#define MATCH_BCLRI 0x48001013
#define MASK_BCLRI  0xfc00707f
#define MATCH_BSETI 0x28001013
#define MASK_BSETI  0xfc00707f
#define MATCH_BINVI 0x68001013
#define MASK_BINVI  0xfc00707f
#define MATCH_BEXTI 0x48005013
#define MASK_BEXTI  0xfc00707f
#define MATCH_GORCI 0x28005013
#define MASK_GORCI  0xfc00707f
#define MATCH_GREVI 0x68005013
#define MASK_GREVI  0xfc00707f
#define MATCH_CMIX 0x6001033
#define MASK_CMIX  0x600707f
#define MATCH_CMOV 0x6005033
#define MASK_CMOV  0x600707f
#define MATCH_FSL 0x4001033
#define MASK_FSL  0x600707f
#define MATCH_FSR 0x4005033
#define MASK_FSR  0x600707f
#define MATCH_FSRI 0x4005013
#define MASK_FSRI  0x400707f
#define MATCH_CLZ 0x60001013
#define MASK_CLZ  0xfff0707f
#define MATCH_CTZ 0x60101013
#define MASK_CTZ  0xfff0707f
#define MATCH_CPOP 0x60201013
#define MASK_CPOP  0xfff0707f
#define MATCH_SEXT_B 0x60401013
#define MASK_SEXT_B  0xfff0707f
#define MATCH_SEXT_H 0x60501013
#define MASK_SEXT_H  0xfff0707f
#define MATCH_CRC32_B 0x61001013
#define MASK_CRC32_B  0xfff0707f
#define MATCH_CRC32_H 0x61101013
#define MASK_CRC32_H  0xfff0707f
#define MATCH_CRC32_W 0x61201013
#define MASK_CRC32_W  0xfff0707f
#define MATCH_CRC32C_B 0x61801013
#define MASK_CRC32C_B  0xfff0707f
#define MATCH_CRC32C_H 0x61901013
#define MASK_CRC32C_H  0xfff0707f
#define MATCH_CRC32C_W 0x61a01013
#define MASK_CRC32C_W  0xfff0707f
#define MATCH_SH1ADD 0x20002033
#define MASK_SH1ADD  0xfe00707f
#define MATCH_SH2ADD 0x20004033
#define MASK_SH2ADD  0xfe00707f
#define MATCH_SH3ADD 0x20006033
#define MASK_SH3ADD  0xfe00707f
#define MATCH_CLMUL 0xa001033
#define MASK_CLMUL  0xfe00707f
#define MATCH_CLMULR 0xa002033
#define MASK_CLMULR  0xfe00707f
#define MATCH_CLMULH 0xa003033
#define MASK_CLMULH  0xfe00707f
#define MATCH_MIN 0xa004033
#define MASK_MIN  0xfe00707f
#define MATCH_MAX 0xa006033
#define MASK_MAX  0xfe00707f
#define MATCH_MINU 0xa005033
#define MASK_MINU  0xfe00707f
#define MATCH_MAXU 0xa007033
#define MASK_MAXU  0xfe00707f
#define MATCH_SHFL 0x8001033
#define MASK_SHFL  0xfe00707f
#define MATCH_UNSHFL 0x8005033
#define MASK_UNSHFL  0xfe00707f
#define MATCH_BMEXT 0x8006033
#define MASK_BMEXT  0xfe00707f
#define MATCH_BMDEP 0x48006033
#define MASK_BMDEP  0xfe00707f
#define MATCH_PACK 0x8004033
#define MASK_PACK  0xfe00707f
#define MATCH_PACKU 0x48004033
#define MASK_PACKU  0xfe00707f
#define MATCH_PACKH 0x8007033
#define MASK_PACKH  0xfe00707f
#define MATCH_BFP 0x48007033
#define MASK_BFP  0xfe00707f
#define MATCH_SHFLI 0x8001013
#define MASK_SHFLI  0xfe00707f
#define MATCH_UNSHFLI 0x8005013
#define MASK_UNSHFLI  0xfe00707f
#define MATCH_BMATFLIP 0x60301013
#define MASK_BMATFLIP  0xfff0707f
#define MATCH_CRC32_D 0x61301013
#define MASK_CRC32_D  0xfff0707f
#define MATCH_CRC32C_D 0x61b01013
#define MASK_CRC32C_D  0xfff0707f
#define MATCH_BMATOR 0x8003033
#define MASK_BMATOR  0xfe00707f
#define MATCH_BMATXOR 0x48003033
#define MASK_BMATXOR  0xfe00707f
#define MATCH_SLLIU_W 0x800101b
#define MASK_SLLIU_W  0xfc00707f
#define MATCH_ADDU_W 0x800003b
#define MASK_ADDU_W  0xfe00707f
#define MATCH_ROLW 0x6000103b
#define MASK_ROLW  0xfe00707f
#define MATCH_RORW 0x6000503b
#define MASK_RORW  0xfe00707f
#define MATCH_BCLRW 0x4800103b
#define MASK_BCLRW  0xfe00707f
#define MATCH_BSETW 0x2800103b
#define MASK_BSETW  0xfe00707f
#define MATCH_BINVW 0x6800103b
#define MASK_BINVW  0xfe00707f
#define MATCH_BEXTW 0x4800503b
#define MASK_BEXTW  0xfe00707f
#define MATCH_GORCW 0x2800503b
#define MASK_GORCW  0xfe00707f
#define MATCH_GREVW 0x6800503b
#define MASK_GREVW  0xfe00707f
#define MATCH_RORIW 0x6000501b
#define MASK_RORIW  0xfe00707f
#define MATCH_BCLRIW 0x4800101b
#define MASK_BCLRIW  0xfe00707f
#define MATCH_BSETIW 0x2800101b
#define MASK_BSETIW  0xfe00707f
#define MATCH_BINVIW 0x6800101b
#define MASK_BINVIW  0xfe00707f
#define MATCH_GORCIW 0x2800501b
#define MASK_GORCIW  0xfe00707f
#define MATCH_GREVIW 0x6800501b
#define MASK_GREVIW  0xfe00707f
#define MATCH_FSLW 0x400103b
#define MASK_FSLW  0x600707f
#define MATCH_FSRW 0x400503b
#define MASK_FSRW  0x600707f
#define MATCH_FSRIW 0x400501b
#define MASK_FSRIW  0x600707f
#define MATCH_CLZW 0x6000101b
#define MASK_CLZW  0xfff0707f
#define MATCH_CTZW 0x6010101b
#define MASK_CTZW  0xfff0707f
#define MATCH_CPOPW 0x6020101b
#define MASK_CPOPW  0xfff0707f
#define MATCH_SH1ADDU_W 0x2000203b
#define MASK_SH1ADDU_W  0xfe00707f
#define MATCH_SH2ADDU_W 0x2000403b
#define MASK_SH2ADDU_W  0xfe00707f
#define MATCH_SH3ADDU_W 0x2000603b
#define MASK_SH3ADDU_W  0xfe00707f
#define MATCH_SHFLW 0x800103b
#define MASK_SHFLW  0xfe00707f
#define MATCH_UNSHFLW 0x800503b
#define MASK_UNSHFLW  0xfe00707f
#define MATCH_BMEXTW 0x800603b
#define MASK_BMEXTW  0xfe00707f
#define MATCH_BMDEPW 0x4800603b
#define MASK_BMDEPW  0xfe00707f
#define MATCH_PACKW 0x800403b
#define MASK_PACKW  0xfe00707f
#define MATCH_PACKUW 0x4800403b
#define MASK_PACKUW  0xfe00707f
#define MATCH_BFPW 0x4800703b
#define MASK_BFPW  0xfe00707f
#define MATCH_XPERMN 0x28002033
#define MASK_XPERMN  0xfe00707f
#define MATCH_XPERMB 0x28004033
#define MASK_XPERMB  0xfe00707f
#define MATCH_XPERMH 0x28006033
#define MASK_XPERMH  0xfe00707f
#define MATCH_XPERMW 0x28000033
#define MASK_XPERMW  0xfe00707f
#define MATCH_AES32ESMI 0x36000033
#define MASK_AES32ESMI  0x3e007fff
#define MATCH_AES32ESI 0x32000033
#define MASK_AES32ESI  0x3e007fff
#define MATCH_AES32DSMI 0x3e000033
#define MASK_AES32DSMI  0x3e007fff
#define MATCH_AES32DSI 0x3a000033
#define MASK_AES32DSI  0x3e007fff
#define MATCH_SHA256SIG0 0x10201013
#define MASK_SHA256SIG0  0xfff0707f
#define MATCH_SHA256SIG1 0x10301013
#define MASK_SHA256SIG1  0xfff0707f
#define MATCH_SHA256SUM0 0x10001013
#define MASK_SHA256SUM0  0xfff0707f
#define MATCH_SHA256SUM1 0x10101013
#define MASK_SHA256SUM1  0xfff0707f
#define MATCH_SHA512SUM0R 0x50000033
#define MASK_SHA512SUM0R  0xfe00707f
#define MATCH_SHA512SUM1R 0x52000033
#define MASK_SHA512SUM1R  0xfe00707f
#define MATCH_SHA512SIG0L 0x54000033
#define MASK_SHA512SIG0L  0xfe00707f
#define MATCH_SHA512SIG0H 0x5c000033
#define MASK_SHA512SIG0H  0xfe00707f
#define MATCH_SHA512SIG1L 0x56000033
#define MASK_SHA512SIG1L  0xfe00707f
#define MATCH_SHA512SIG1H 0x5e000033
#define MASK_SHA512SIG1H  0xfe00707f

#define MATCH_AMOADD_W 0x202f
#define MASK_AMOADD_W  0xf800707f
#define MATCH_AMOXOR_W 0x2000202f
#define MASK_AMOXOR_W  0xf800707f
#define MATCH_AMOOR_W 0x4000202f
#define MASK_AMOOR_W  0xf800707f
#define MATCH_AMOAND_W 0x6000202f
#define MASK_AMOAND_W  0xf800707f
#define MATCH_AMOMIN_W 0x8000202f
#define MASK_AMOMIN_W  0xf800707f
#define MATCH_AMOMAX_W 0xa000202f
#define MASK_AMOMAX_W  0xf800707f
#define MATCH_AMOMINU_W 0xc000202f
#define MASK_AMOMINU_W  0xf800707f
#define MATCH_AMOMAXU_W 0xe000202f
#define MASK_AMOMAXU_W  0xf800707f
#define MATCH_AMOSWAP_W 0x800202f
#define MASK_AMOSWAP_W  0xf800707f
#define MATCH_LR_W 0x1000202f
#define MASK_LR_W  0xf9f0707f
#define MATCH_SC_W 0x1800202f
#define MASK_SC_W  0xf800707f
#define MATCH_AMOADD_D 0x302f
#define MASK_AMOADD_D  0xf800707f
#define MATCH_AMOXOR_D 0x2000302f
#define MASK_AMOXOR_D  0xf800707f
#define MATCH_AMOOR_D 0x4000302f
#define MASK_AMOOR_D  0xf800707f
#define MATCH_AMOAND_D 0x6000302f
#define MASK_AMOAND_D  0xf800707f
#define MATCH_AMOMIN_D 0x8000302f
#define MASK_AMOMIN_D  0xf800707f
#define MATCH_AMOMAX_D 0xa000302f
#define MASK_AMOMAX_D  0xf800707f
#define MATCH_AMOMINU_D 0xc000302f
#define MASK_AMOMINU_D  0xf800707f
#define MATCH_AMOMAXU_D 0xe000302f
#define MASK_AMOMAXU_D  0xf800707f
#define MATCH_AMOSWAP_D 0x800302f
#define MASK_AMOSWAP_D  0xf800707f
#define MATCH_LR_D 0x1000302f
#define MASK_LR_D  0xf9f0707f
#define MATCH_SC_D 0x1800302f
#define MASK_SC_D  0xf800707f
#define MATCH_ECALL 0x73
#define MASK_ECALL  0xffffffff
#define MATCH_EBREAK 0x100073
#define MASK_EBREAK  0xffffffff
#define MATCH_URET 0x200073
#define MASK_URET  0xffffffff
#define MATCH_SRET 0x10200073
#define MASK_SRET  0xffffffff
#define MATCH_HRET 0x20200073
#define MASK_HRET  0xffffffff
#define MATCH_MRET 0x30200073
#define MASK_MRET  0xffffffff
#define MATCH_DRET 0x7b200073
#define MASK_DRET  0xffffffff
#define MATCH_SFENCE_VM 0x10400073
#define MASK_SFENCE_VM  0xfff07fff
#define MATCH_SFENCE_VMA 0x12000073
#define MASK_SFENCE_VMA  0xfe007fff
#define MATCH_WFI 0x10500073
#define MASK_WFI  0xffffffff
#define MATCH_CSRRW 0x1073
#define MASK_CSRRW  0x707f
#define MATCH_CSRRS 0x2073
#define MASK_CSRRS  0x707f
#define MATCH_CSRRC 0x3073
#define MASK_CSRRC  0x707f
#define MATCH_CSRRWI 0x5073
#define MASK_CSRRWI  0x707f
#define MATCH_CSRRSI 0x6073
#define MASK_CSRRSI  0x707f
#define MATCH_CSRRCI 0x7073
#define MASK_CSRRCI  0x707f
#define MATCH_FADD_S 0x53
#define MASK_FADD_S  0xfe00007f
#define MATCH_FSUB_S 0x8000053
#define MASK_FSUB_S  0xfe00007f
#define MATCH_FMUL_S 0x10000053
#define MASK_FMUL_S  0xfe00007f
#define MATCH_FDIV_S 0x18000053
#define MASK_FDIV_S  0xfe00007f
#define MATCH_FSGNJ_S 0x20000053
#define MASK_FSGNJ_S  0xfe00707f
#define MATCH_FSGNJN_S 0x20001053
#define MASK_FSGNJN_S  0xfe00707f
#define MATCH_FSGNJX_S 0x20002053
#define MASK_FSGNJX_S  0xfe00707f
#define MATCH_FMIN_S 0x28000053
#define MASK_FMIN_S  0xfe00707f
#define MATCH_FMAX_S 0x28001053
#define MASK_FMAX_S  0xfe00707f
#define MATCH_FSQRT_S 0x58000053
#define MASK_FSQRT_S  0xfff0007f
#define MATCH_FADD_D 0x2000053
#define MASK_FADD_D  0xfe00007f
#define MATCH_FSUB_D 0xa000053
#define MASK_FSUB_D  0xfe00007f
#define MATCH_FMUL_D 0x12000053
#define MASK_FMUL_D  0xfe00007f
#define MATCH_FDIV_D 0x1a000053
#define MASK_FDIV_D  0xfe00007f
#define MATCH_FSGNJ_D 0x22000053
#define MASK_FSGNJ_D  0xfe00707f
#define MATCH_FSGNJN_D 0x22001053
#define MASK_FSGNJN_D  0xfe00707f
#define MATCH_FSGNJX_D 0x22002053
#define MASK_FSGNJX_D  0xfe00707f
#define MATCH_FMIN_D 0x2a000053
#define MASK_FMIN_D  0xfe00707f
#define MATCH_FMAX_D 0x2a001053
#define MASK_FMAX_D  0xfe00707f
#define MATCH_FCVT_S_D 0x40100053
#define MASK_FCVT_S_D  0xfff0007f
#define MATCH_FCVT_D_S 0x42000053
#define MASK_FCVT_D_S  0xfff0007f
#define MATCH_FSQRT_D 0x5a000053
#define MASK_FSQRT_D  0xfff0007f
#define MATCH_FADD_Q 0x6000053
#define MASK_FADD_Q  0xfe00007f
#define MATCH_FSUB_Q 0xe000053
#define MASK_FSUB_Q  0xfe00007f
#define MATCH_FMUL_Q 0x16000053
#define MASK_FMUL_Q  0xfe00007f
#define MATCH_FDIV_Q 0x1e000053
#define MASK_FDIV_Q  0xfe00007f
#define MATCH_FSGNJ_Q 0x26000053
#define MASK_FSGNJ_Q  0xfe00707f
#define MATCH_FSGNJN_Q 0x26001053
#define MASK_FSGNJN_Q  0xfe00707f
#define MATCH_FSGNJX_Q 0x26002053
#define MASK_FSGNJX_Q  0xfe00707f
#define MATCH_FMIN_Q 0x2e000053
#define MASK_FMIN_Q  0xfe00707f
#define MATCH_FMAX_Q 0x2e001053
#define MASK_FMAX_Q  0xfe00707f
#define MATCH_FCVT_S_Q 0x40300053
#define MASK_FCVT_S_Q  0xfff0007f
#define MATCH_FCVT_Q_S 0x46000053
#define MASK_FCVT_Q_S  0xfff0007f
#define MATCH_FCVT_D_Q 0x42300053
#define MASK_FCVT_D_Q  0xfff0007f
#define MATCH_FCVT_Q_D 0x46100053
#define MASK_FCVT_Q_D  0xfff0007f
#define MATCH_FSQRT_Q 0x5e000053
#define MASK_FSQRT_Q  0xfff0007f
#define MATCH_FLE_S 0xa0000053
#define MASK_FLE_S  0xfe00707f
#define MATCH_FLT_S 0xa0001053
#define MASK_FLT_S  0xfe00707f
#define MATCH_FEQ_S 0xa0002053
#define MASK_FEQ_S  0xfe00707f
#define MATCH_FLE_D 0xa2000053
#define MASK_FLE_D  0xfe00707f
#define MATCH_FLT_D 0xa2001053
#define MASK_FLT_D  0xfe00707f
#define MATCH_FEQ_D 0xa2002053
#define MASK_FEQ_D  0xfe00707f
#define MATCH_FLE_Q 0xa6000053
#define MASK_FLE_Q  0xfe00707f
#define MATCH_FLT_Q 0xa6001053
#define MASK_FLT_Q  0xfe00707f
#define MATCH_FEQ_Q 0xa6002053
#define MASK_FEQ_Q  0xfe00707f
#define MATCH_FCVT_W_S 0xc0000053
#define MASK_FCVT_W_S  0xfff0007f
#define MATCH_FCVT_WU_S 0xc0100053
#define MASK_FCVT_WU_S  0xfff0007f
#define MATCH_FCVT_L_S 0xc0200053
#define MASK_FCVT_L_S  0xfff0007f
#define MATCH_FCVT_LU_S 0xc0300053
#define MASK_FCVT_LU_S  0xfff0007f
#define MATCH_FMV_X_S 0xe0000053
#define MASK_FMV_X_S  0xfff0707f
#define MATCH_FCLASS_S 0xe0001053
#define MASK_FCLASS_S  0xfff0707f
#define MATCH_FCVT_W_D 0xc2000053
#define MASK_FCVT_W_D  0xfff0007f
#define MATCH_FCVT_WU_D 0xc2100053
#define MASK_FCVT_WU_D  0xfff0007f
#define MATCH_FCVT_L_D 0xc2200053
#define MASK_FCVT_L_D  0xfff0007f
#define MATCH_FCVT_LU_D 0xc2300053
#define MASK_FCVT_LU_D  0xfff0007f
#define MATCH_FMV_X_D 0xe2000053
#define MASK_FMV_X_D  0xfff0707f
#define MATCH_FCLASS_D 0xe2001053
#define MASK_FCLASS_D  0xfff0707f
#define MATCH_FCVT_W_Q 0xc6000053
#define MASK_FCVT_W_Q  0xfff0007f
#define MATCH_FCVT_WU_Q 0xc6100053
#define MASK_FCVT_WU_Q  0xfff0007f
#define MATCH_FCVT_L_Q 0xc6200053
#define MASK_FCVT_L_Q  0xfff0007f
#define MATCH_FCVT_LU_Q 0xc6300053
#define MASK_FCVT_LU_Q  0xfff0007f
#define MATCH_FMV_X_Q 0xe6000053
#define MASK_FMV_X_Q  0xfff0707f
#define MATCH_FCLASS_Q 0xe6001053
#define MASK_FCLASS_Q  0xfff0707f
#define MATCH_FCVT_S_W 0xd0000053
#define MASK_FCVT_S_W  0xfff0007f
#define MATCH_FCVT_S_WU 0xd0100053
#define MASK_FCVT_S_WU  0xfff0007f
#define MATCH_FCVT_S_L 0xd0200053
#define MASK_FCVT_S_L  0xfff0007f
#define MATCH_FCVT_S_LU 0xd0300053
#define MASK_FCVT_S_LU  0xfff0007f
#define MATCH_FMV_S_X 0xf0000053
#define MASK_FMV_S_X  0xfff0707f
#define MATCH_FCVT_D_W 0xd2000053
#define MASK_FCVT_D_W  0xfff0007f
#define MATCH_FCVT_D_WU 0xd2100053
#define MASK_FCVT_D_WU  0xfff0007f
#define MATCH_FCVT_D_L 0xd2200053
#define MASK_FCVT_D_L  0xfff0007f
#define MATCH_FCVT_D_LU 0xd2300053
#define MASK_FCVT_D_LU  0xfff0007f
#define MATCH_FMV_D_X 0xf2000053
#define MASK_FMV_D_X  0xfff0707f
#define MATCH_FCVT_Q_W 0xd6000053
#define MASK_FCVT_Q_W  0xfff0007f
#define MATCH_FCVT_Q_WU 0xd6100053
#define MASK_FCVT_Q_WU  0xfff0007f
#define MATCH_FCVT_Q_L 0xd6200053
#define MASK_FCVT_Q_L  0xfff0007f
#define MATCH_FCVT_Q_LU 0xd6300053
#define MASK_FCVT_Q_LU  0xfff0007f
#define MATCH_FMV_Q_X 0xf6000053
#define MASK_FMV_Q_X  0xfff0707f
#define MATCH_FLW 0x2007
#define MASK_FLW  0x707f
#define MATCH_FLD 0x3007
#define MASK_FLD  0x707f
#define MATCH_FLQ 0x4007
#define MASK_FLQ  0x707f
#define MATCH_FSW 0x2027
#define MASK_FSW  0x707f
#define MATCH_FSD 0x3027
#define MASK_FSD  0x707f
#define MATCH_FSQ 0x4027
#define MASK_FSQ  0x707f
#define MATCH_FMADD_S 0x43
#define MASK_FMADD_S  0x600007f
#define MATCH_FMSUB_S 0x47
#define MASK_FMSUB_S  0x600007f
#define MATCH_FNMSUB_S 0x4b
#define MASK_FNMSUB_S  0x600007f
#define MATCH_FNMADD_S 0x4f
#define MASK_FNMADD_S  0x600007f
#define MATCH_FMADD_D 0x2000043
#define MASK_FMADD_D  0x600007f
#define MATCH_FMSUB_D 0x2000047
#define MASK_FMSUB_D  0x600007f
#define MATCH_FNMSUB_D 0x200004b
#define MASK_FNMSUB_D  0x600007f
#define MATCH_FNMADD_D 0x200004f
#define MASK_FNMADD_D  0x600007f
#define MATCH_FMADD_Q 0x6000043
#define MASK_FMADD_Q  0x600007f
#define MATCH_FMSUB_Q 0x6000047
#define MASK_FMSUB_Q  0x600007f
#define MATCH_FNMSUB_Q 0x600004b
#define MASK_FNMSUB_Q  0x600007f
#define MATCH_FNMADD_Q 0x600004f
#define MASK_FNMADD_Q  0x600007f
#define MATCH_C_ADDI4SPN 0x0
#define MASK_C_ADDI4SPN  0xe003
#define MATCH_C_FLD 0x2000
#define MASK_C_FLD  0xe003
#define MATCH_C_LW 0x4000
#define MASK_C_LW  0xe003
#define MATCH_C_FLW 0x6000
#define MASK_C_FLW  0xe003
#define MATCH_C_FSD 0xa000
#define MASK_C_FSD  0xe003
#define MATCH_C_SW 0xc000
#define MASK_C_SW  0xe003
#define MATCH_C_FSW 0xe000
#define MASK_C_FSW  0xe003
#define MATCH_C_ADDI 0x1
#define MASK_C_ADDI  0xe003
#define MATCH_C_JAL 0x2001
#define MASK_C_JAL  0xe003
#define MATCH_C_LI 0x4001
#define MASK_C_LI  0xe003
#define MATCH_C_LUI 0x6001
#define MASK_C_LUI  0xe003
#define MATCH_C_SRLI 0x8001
#define MASK_C_SRLI  0xec03
#define MATCH_C_SRLI64 0x8001
#define MASK_C_SRLI64  0xfc7f
#define MATCH_C_SRAI 0x8401
#define MASK_C_SRAI  0xec03
#define MATCH_C_SRAI64 0x8401
#define MASK_C_SRAI64  0xfc7f
#define MATCH_C_ANDI 0x8801
#define MASK_C_ANDI  0xec03
#define MATCH_C_SUB 0x8c01
#define MASK_C_SUB  0xfc63
#define MATCH_C_XOR 0x8c21
#define MASK_C_XOR  0xfc63
#define MATCH_C_OR 0x8c41
#define MASK_C_OR  0xfc63
#define MATCH_C_AND 0x8c61
#define MASK_C_AND  0xfc63
#define MATCH_C_SUBW 0x9c01
#define MASK_C_SUBW  0xfc63
#define MATCH_C_ADDW 0x9c21
#define MASK_C_ADDW  0xfc63
#define MATCH_C_J 0xa001
#define MASK_C_J  0xe003
#define MATCH_C_BEQZ 0xc001
#define MASK_C_BEQZ  0xe003
#define MATCH_C_BNEZ 0xe001
#define MASK_C_BNEZ  0xe003
#define MATCH_C_SLLI 0x2
#define MASK_C_SLLI  0xe003
#define MATCH_C_SLLI64 0x2
#define MASK_C_SLLI64 0xf07f
#define MATCH_C_FLDSP 0x2002
#define MASK_C_FLDSP  0xe003
#define MATCH_C_LWSP 0x4002
#define MASK_C_LWSP  0xe003
#define MATCH_C_FLWSP 0x6002
#define MASK_C_FLWSP  0xe003
#define MATCH_C_MV 0x8002
#define MASK_C_MV  0xf003
#define MATCH_C_ADD 0x9002
#define MASK_C_ADD  0xf003
#define MATCH_C_FSDSP 0xa002
#define MASK_C_FSDSP  0xe003
#define MATCH_C_SWSP 0xc002
#define MASK_C_SWSP  0xe003
#define MATCH_C_FSWSP 0xe002
#define MASK_C_FSWSP  0xe003
#define MATCH_C_NOP 0x1
#define MASK_C_NOP  0xffff
#define MATCH_C_ADDI16SP 0x6101
#define MASK_C_ADDI16SP  0xef83
#define MATCH_C_JR 0x8002
#define MASK_C_JR  0xf07f
#define MATCH_C_JALR 0x9002
#define MASK_C_JALR  0xf07f
#define MATCH_C_EBREAK 0x9002
#define MASK_C_EBREAK  0xffff
#define MATCH_C_LD 0x6000
#define MASK_C_LD  0xe003
#define MATCH_C_SD 0xe000
#define MASK_C_SD  0xe003
#define MATCH_C_ADDIW 0x2001
#define MASK_C_ADDIW  0xe003
#define MATCH_C_LDSP 0x6002
#define MASK_C_LDSP  0xe003
#define MATCH_C_SDSP 0xe002
#define MASK_C_SDSP  0xe003
#define MATCH_CUSTOM0 0xb
#define MASK_CUSTOM0  0x707f
#define MATCH_CUSTOM0_RS1 0x200b
#define MASK_CUSTOM0_RS1  0x707f
#define MATCH_CUSTOM0_RS1_RS2 0x300b
#define MASK_CUSTOM0_RS1_RS2  0x707f
#define MATCH_CUSTOM0_RD 0x400b
#define MASK_CUSTOM0_RD  0x707f
#define MATCH_CUSTOM0_RD_RS1 0x600b
#define MASK_CUSTOM0_RD_RS1  0x707f
#define MATCH_CUSTOM0_RD_RS1_RS2 0x700b
#define MASK_CUSTOM0_RD_RS1_RS2  0x707f
#define MATCH_CUSTOM1 0x2b
#define MASK_CUSTOM1  0x707f
#define MATCH_CUSTOM1_RS1 0x202b
#define MASK_CUSTOM1_RS1  0x707f
#define MATCH_CUSTOM1_RS1_RS2 0x302b
#define MASK_CUSTOM1_RS1_RS2  0x707f
#define MATCH_CUSTOM1_RD 0x402b
#define MASK_CUSTOM1_RD  0x707f
#define MATCH_CUSTOM1_RD_RS1 0x602b
#define MASK_CUSTOM1_RD_RS1  0x707f
#define MATCH_CUSTOM1_RD_RS1_RS2 0x702b
#define MASK_CUSTOM1_RD_RS1_RS2  0x707f
#define MATCH_CUSTOM2 0x5b
#define MASK_CUSTOM2  0x707f
#define MATCH_CUSTOM2_RS1 0x205b
#define MASK_CUSTOM2_RS1  0x707f
#define MATCH_CUSTOM2_RS1_RS2 0x305b
#define MASK_CUSTOM2_RS1_RS2  0x707f
#define MATCH_CUSTOM2_RD 0x405b
#define MASK_CUSTOM2_RD  0x707f
#define MATCH_CUSTOM2_RD_RS1 0x605b
#define MASK_CUSTOM2_RD_RS1  0x707f
#define MATCH_CUSTOM2_RD_RS1_RS2 0x705b
#define MASK_CUSTOM2_RD_RS1_RS2  0x707f
#define MATCH_CUSTOM3 0x7b
#define MASK_CUSTOM3  0x707f
#define MATCH_CUSTOM3_RS1 0x207b
#define MASK_CUSTOM3_RS1  0x707f
#define MATCH_CUSTOM3_RS1_RS2 0x307b
#define MASK_CUSTOM3_RS1_RS2  0x707f
#define MATCH_CUSTOM3_RD 0x407b
#define MASK_CUSTOM3_RD  0x707f
#define MATCH_CUSTOM3_RD_RS1 0x607b
#define MASK_CUSTOM3_RD_RS1  0x707f
#define MATCH_CUSTOM3_RD_RS1_RS2 0x707b
#define MASK_CUSTOM3_RD_RS1_RS2  0x707f
/* Amethyst SIMD Instructions */
#define MATCH_PWSUB_B 0x0000005B
#define MASK_PWSUB_B  0xFE00707F
#define MATCH_PWSUB_H 0x0000105B
#define MASK_PWSUB_H  0xFE00707F
#define MATCH_PWSUB_W 0x0000205B
#define MASK_PWSUB_W  0xFE00707F
#define MATCH_PDSUB_B 0x0000405B
#define MASK_PDSUB_B  0xFE00707F
#define MATCH_PDSUB_H 0x0000505B
#define MASK_PDSUB_H  0xFE00707F
#define MATCH_PDSUB_W 0x0000605B
#define MASK_PDSUB_W  0xFE00707F
#define MATCH_PDSUB_D 0x0000705B
#define MASK_PDSUB_D  0xFE00707F
#define MATCH_PWSUBHU_B 0x0200005B
#define MASK_PWSUBHU_B  0xFE00707F
#define MATCH_PWSUBHU_H 0x0200105B
#define MASK_PWSUBHU_H  0xFE00707F
#define MATCH_PWSUBHU_W 0x0200205B
#define MASK_PWSUBHU_W  0xFE00707F
#define MATCH_PDSUBHU_B 0x0200405B
#define MASK_PDSUBHU_B  0xFE00707F
#define MATCH_PDSUBHU_H 0x0200505B
#define MASK_PDSUBHU_H  0xFE00707F
#define MATCH_PDSUBHU_W 0x0200605B
#define MASK_PDSUBHU_W  0xFE00707F
#define MATCH_PDSUBHU_D 0x0200705B
#define MASK_PDSUBHU_D  0xFE00707F
#define MATCH_PWSUBSS_B 0x0400005B
#define MASK_PWSUBSS_B  0xFE00707F
#define MATCH_PWSUBSS_H 0x0400105B
#define MASK_PWSUBSS_H  0xFE00707F
#define MATCH_PWSUBSS_W 0x0400205B
#define MASK_PWSUBSS_W  0xFE00707F
#define MATCH_PDSUBSS_B 0x0400405B
#define MASK_PDSUBSS_B  0xFE00707F
#define MATCH_PDSUBSS_H 0x0400505B
#define MASK_PDSUBSS_H  0xFE00707F
#define MATCH_PDSUBSS_W 0x0400605B
#define MASK_PDSUBSS_W  0xFE00707F
#define MATCH_PDSUBSS_D 0x0400705B
#define MASK_PDSUBSS_D  0xFE00707F
#define MATCH_PWSUBUS_B 0x0600005B
#define MASK_PWSUBUS_B  0xFE00707F
#define MATCH_PWSUBUS_H 0x0600105B
#define MASK_PWSUBUS_H  0xFE00707F
#define MATCH_PWSUBUS_W 0x0600205B
#define MASK_PWSUBUS_W  0xFE00707F
#define MATCH_PDSUBUS_B 0x0600405B
#define MASK_PDSUBUS_B  0xFE00707F
#define MATCH_PDSUBUS_H 0x0600505B
#define MASK_PDSUBUS_H  0xFE00707F
#define MATCH_PDSUBUS_W 0x0600605B
#define MASK_PDSUBUS_W  0xFE00707F
#define MATCH_PDSUBUS_D 0x0600705B
#define MASK_PDSUBUS_D  0xFE00707F
#define MATCH_PWSUBHS_B 0x0800005B
#define MASK_PWSUBHS_B  0xFE00707F
#define MATCH_PWSUBHS_H 0x0800105B
#define MASK_PWSUBHS_H  0xFE00707F
#define MATCH_PWSUBHS_W 0x0800205B
#define MASK_PWSUBHS_W  0xFE00707F
#define MATCH_PDSUBHS_B 0x0800405B
#define MASK_PDSUBHS_B  0xFE00707F
#define MATCH_PDSUBHS_H 0x0800505B
#define MASK_PDSUBHS_H  0xFE00707F
#define MATCH_PDSUBHS_W 0x0800605B
#define MASK_PDSUBHS_W  0xFE00707F
#define MATCH_PDSUBHS_D 0x0800705B
#define MASK_PDSUBHS_D  0xFE00707F
#define MATCH_PWHADD_B 0x0C00005B
#define MASK_PWHADD_B  0xFE00707F
#define MATCH_PWHADD_H 0x0C00105B
#define MASK_PWHADD_H  0xFE00707F
#define MATCH_PDHADD_B 0x0C00405B
#define MASK_PDHADD_B  0xFE00707F
#define MATCH_PDHADD_H 0x0C00505B
#define MASK_PDHADD_H  0xFE00707F
#define MATCH_PDHADD_W 0x0C00605B
#define MASK_PDHADD_W  0xFE00707F
#define MATCH_PWHSUB_B 0x0E00005B
#define MASK_PWHSUB_B  0xFE00707F
#define MATCH_PWHSUB_H 0x0E00105B
#define MASK_PWHSUB_H  0xFE00707F
#define MATCH_PDHSUB_B 0x0E00405B
#define MASK_PDHSUB_B  0xFE00707F
#define MATCH_PDHSUB_H 0x0E00505B
#define MASK_PDHSUB_H  0xFE00707F
#define MATCH_PDHSUB_W 0x0E00605B
#define MASK_PDHSUB_W  0xFE00707F
#define MATCH_PWSLT_B 0x1000005B
#define MASK_PWSLT_B  0xFE00707F
#define MATCH_PWSLT_H 0x1000105B
#define MASK_PWSLT_H  0xFE00707F
#define MATCH_PWSLT_W 0x1000205B
#define MASK_PWSLT_W  0xFE00707F
#define MATCH_PDSLT_B 0x1000405B
#define MASK_PDSLT_B  0xFE00707F
#define MATCH_PDSLT_H 0x1000505B
#define MASK_PDSLT_H  0xFE00707F
#define MATCH_PDSLT_W 0x1000605B
#define MASK_PDSLT_W  0xFE00707F
#define MATCH_PDSLT_D 0x1000705B
#define MASK_PDSLT_D  0xFE00707F
#define MATCH_PWSLTM_B 0x1200005B
#define MASK_PWSLTM_B  0xFE00707F
#define MATCH_PWSLTM_H 0x1200105B
#define MASK_PWSLTM_H  0xFE00707F
#define MATCH_PWSLTM_W 0x1200205B
#define MASK_PWSLTM_W  0xFE00707F
#define MATCH_PDSLTM_B 0x1200405B
#define MASK_PDSLTM_B  0xFE00707F
#define MATCH_PDSLTM_H 0x1200505B
#define MASK_PDSLTM_H  0xFE00707F
#define MATCH_PDSLTM_W 0x1200605B
#define MASK_PDSLTM_W  0xFE00707F
#define MATCH_PDSLTM_D 0x1200705B
#define MASK_PDSLTM_D  0xFE00707F
#define MATCH_PWSLTU_B 0x1400005B
#define MASK_PWSLTU_B  0xFE00707F
#define MATCH_PWSLTU_H 0x1400105B
#define MASK_PWSLTU_H  0xFE00707F
#define MATCH_PWSLTU_W 0x1400205B
#define MASK_PWSLTU_W  0xFE00707F
#define MATCH_PDSLTU_B 0x1400405B
#define MASK_PDSLTU_B  0xFE00707F
#define MATCH_PDSLTU_H 0x1400505B
#define MASK_PDSLTU_H  0xFE00707F
#define MATCH_PDSLTU_W 0x1400605B
#define MASK_PDSLTU_W  0xFE00707F
#define MATCH_PDSLTU_D 0x1400705B
#define MASK_PDSLTU_D  0xFE00707F
#define MATCH_PWSLTUM_B 0x1600005B
#define MASK_PWSLTUM_B  0xFE00707F
#define MATCH_PWSLTUM_H 0x1600105B
#define MASK_PWSLTUM_H  0xFE00707F
#define MATCH_PWSLTUM_W 0x1600205B
#define MASK_PWSLTUM_W  0xFE00707F
#define MATCH_PDSLTUM_B 0x1600405B
#define MASK_PDSLTUM_B  0xFE00707F
#define MATCH_PDSLTUM_H 0x1600505B
#define MASK_PDSLTUM_H  0xFE00707F
#define MATCH_PDSLTUM_W 0x1600605B
#define MASK_PDSLTUM_W  0xFE00707F
#define MATCH_PDSLTUM_D 0x1600705B
#define MASK_PDSLTUM_D  0xFE00707F
#define MATCH_PWMIN_B 0x1800005B
#define MASK_PWMIN_B  0xFE00707F
#define MATCH_PWMIN_H 0x1800105B
#define MASK_PWMIN_H  0xFE00707F
#define MATCH_PWMIN_W 0x1800205B
#define MASK_PWMIN_W  0xFE00707F
#define MATCH_PDMIN_B 0x1800405B
#define MASK_PDMIN_B  0xFE00707F
#define MATCH_PDMIN_H 0x1800505B
#define MASK_PDMIN_H  0xFE00707F
#define MATCH_PDMIN_W 0x1800605B
#define MASK_PDMIN_W  0xFE00707F
#define MATCH_PDMIN_D 0x1800705B
#define MASK_PDMIN_D  0xFE00707F
#define MATCH_PWMINU_B 0x1A00005B
#define MASK_PWMINU_B  0xFE00707F
#define MATCH_PWMINU_H 0x1A00105B
#define MASK_PWMINU_H  0xFE00707F
#define MATCH_PWMINU_W 0x1A00205B
#define MASK_PWMINU_W  0xFE00707F
#define MATCH_PDMINU_B 0x1A00405B
#define MASK_PDMINU_B  0xFE00707F
#define MATCH_PDMINU_H 0x1A00505B
#define MASK_PDMINU_H  0xFE00707F
#define MATCH_PDMINU_W 0x1A00605B
#define MASK_PDMINU_W  0xFE00707F
#define MATCH_PDMINU_D 0x1A00705B
#define MASK_PDMINU_D  0xFE00707F
#define MATCH_PWMAX_B 0x1C00005B
#define MASK_PWMAX_B  0xFE00707F
#define MATCH_PWMAX_H 0x1C00105B
#define MASK_PWMAX_H  0xFE00707F
#define MATCH_PWMAX_W 0x1C00205B
#define MASK_PWMAX_W  0xFE00707F
#define MATCH_PDMAX_B 0x1C00405B
#define MASK_PDMAX_B  0xFE00707F
#define MATCH_PDMAX_H 0x1C00505B
#define MASK_PDMAX_H  0xFE00707F
#define MATCH_PDMAX_W 0x1C00605B
#define MASK_PDMAX_W  0xFE00707F
#define MATCH_PDMAX_D 0x1C00705B
#define MASK_PDMAX_D  0xFE00707F
#define MATCH_PWMAXU_B 0x1E00005B
#define MASK_PWMAXU_B  0xFE00707F
#define MATCH_PWMAXU_H 0x1E00105B
#define MASK_PWMAXU_H  0xFE00707F
#define MATCH_PWMAXU_W 0x1E00205B
#define MASK_PWMAXU_W  0xFE00707F
#define MATCH_PDMAXU_B 0x1E00405B
#define MASK_PDMAXU_B  0xFE00707F
#define MATCH_PDMAXU_H 0x1E00505B
#define MASK_PDMAXU_H  0xFE00707F
#define MATCH_PDMAXU_W 0x1E00605B
#define MASK_PDMAXU_W  0xFE00707F
#define MATCH_PDMAXU_D 0x1E00705B
#define MASK_PDMAXU_D  0xFE00707F
#define MATCH_PWADD_B 0x2000005B
#define MASK_PWADD_B  0xFE00707F
#define MATCH_PWADD_H 0x2000105B
#define MASK_PWADD_H  0xFE00707F
#define MATCH_PWADD_W 0x2000205B
#define MASK_PWADD_W  0xFE00707F
#define MATCH_PDADD_B 0x2000405B
#define MASK_PDADD_B  0xFE00707F
#define MATCH_PDADD_H 0x2000505B
#define MASK_PDADD_H  0xFE00707F
#define MATCH_PDADD_W 0x2000605B
#define MASK_PDADD_W  0xFE00707F
#define MATCH_PDADD_D 0x2000705B
#define MASK_PDADD_D  0xFE00707F
#define MATCH_PWAVGU_B 0x2200005B
#define MASK_PWAVGU_B  0xFE00707F
#define MATCH_PWAVGU_H 0x2200105B
#define MASK_PWAVGU_H  0xFE00707F
#define MATCH_PWAVGU_W 0x2200205B
#define MASK_PWAVGU_W  0xFE00707F
#define MATCH_PDAVGU_B 0x2200405B
#define MASK_PDAVGU_B  0xFE00707F
#define MATCH_PDAVGU_H 0x2200505B
#define MASK_PDAVGU_H  0xFE00707F
#define MATCH_PDAVGU_W 0x2200605B
#define MASK_PDAVGU_W  0xFE00707F
#define MATCH_PDAVGU_D 0x2200705B
#define MASK_PDAVGU_D  0xFE00707F
#define MATCH_PWADDSS_B 0x2400005B
#define MASK_PWADDSS_B  0xFE00707F
#define MATCH_PWADDSS_H 0x2400105B
#define MASK_PWADDSS_H  0xFE00707F
#define MATCH_PWADDSS_W 0x2400205B
#define MASK_PWADDSS_W  0xFE00707F
#define MATCH_PDADDSS_B 0x2400405B
#define MASK_PDADDSS_B  0xFE00707F
#define MATCH_PDADDSS_H 0x2400505B
#define MASK_PDADDSS_H  0xFE00707F
#define MATCH_PDADDSS_W 0x2400605B
#define MASK_PDADDSS_W  0xFE00707F
#define MATCH_PDADDSS_D 0x2400705B
#define MASK_PDADDSS_D  0xFE00707F
#define MATCH_PWADDUS_B 0x2600005B
#define MASK_PWADDUS_B  0xFE00707F
#define MATCH_PWADDUS_H 0x2600105B
#define MASK_PWADDUS_H  0xFE00707F
#define MATCH_PWADDUS_W 0x2600205B
#define MASK_PWADDUS_W  0xFE00707F
#define MATCH_PDADDUS_B 0x2600405B
#define MASK_PDADDUS_B  0xFE00707F
#define MATCH_PDADDUS_H 0x2600505B
#define MASK_PDADDUS_H  0xFE00707F
#define MATCH_PDADDUS_W 0x2600605B
#define MASK_PDADDUS_W  0xFE00707F
#define MATCH_PDADDUS_D 0x2600705B
#define MASK_PDADDUS_D  0xFE00707F
#define MATCH_PWAVGS_B 0x2800005B
#define MASK_PWAVGS_B  0xFE00707F
#define MATCH_PWAVGS_H 0x2800105B
#define MASK_PWAVGS_H  0xFE00707F
#define MATCH_PWAVGS_W 0x2800205B
#define MASK_PWAVGS_W  0xFE00707F
#define MATCH_PDAVGS_B 0x2800405B
#define MASK_PDAVGS_B  0xFE00707F
#define MATCH_PDAVGS_H 0x2800505B
#define MASK_PDAVGS_H  0xFE00707F
#define MATCH_PDAVGS_W 0x2800605B
#define MASK_PDAVGS_W  0xFE00707F
#define MATCH_PDAVGS_D 0x2800705B
#define MASK_PDAVGS_D  0xFE00707F
#define MATCH_PWSH1ADD_B 0x2A00005B
#define MASK_PWSH1ADD_B  0xFE00707F
#define MATCH_PWSH1ADD_H 0x2A00105B
#define MASK_PWSH1ADD_H  0xFE00707F
#define MATCH_PWSH1ADD_W 0x2A00205B
#define MASK_PWSH1ADD_W  0xFE00707F
#define MATCH_PDSH1ADD_B 0x2A00405B
#define MASK_PDSH1ADD_B  0xFE00707F
#define MATCH_PDSH1ADD_H 0x2A00505B
#define MASK_PDSH1ADD_H  0xFE00707F
#define MATCH_PDSH1ADD_W 0x2A00605B
#define MASK_PDSH1ADD_W  0xFE00707F
#define MATCH_PDSH1ADD_D 0x2A00705B
#define MASK_PDSH1ADD_D  0xFE00707F
#define MATCH_PWSH2ADD_B 0x2C00005B
#define MASK_PWSH2ADD_B  0xFE00707F
#define MATCH_PWSH2ADD_H 0x2C00105B
#define MASK_PWSH2ADD_H  0xFE00707F
#define MATCH_PWSH2ADD_W 0x2C00205B
#define MASK_PWSH2ADD_W  0xFE00707F
#define MATCH_PDSH2ADD_B 0x2C00405B
#define MASK_PDSH2ADD_B  0xFE00707F
#define MATCH_PDSH2ADD_H 0x2C00505B
#define MASK_PDSH2ADD_H  0xFE00707F
#define MATCH_PDSH2ADD_W 0x2C00605B
#define MASK_PDSH2ADD_W  0xFE00707F
#define MATCH_PDSH2ADD_D 0x2C00705B
#define MASK_PDSH2ADD_D  0xFE00707F
#define MATCH_PWSH3ADD_B 0x2E00005B
#define MASK_PWSH3ADD_B  0xFE00707F
#define MATCH_PWSH3ADD_H 0x2E00105B
#define MASK_PWSH3ADD_H  0xFE00707F
#define MATCH_PWSH3ADD_W 0x2E00205B
#define MASK_PWSH3ADD_W  0xFE00707F
#define MATCH_PDSH3ADD_B 0x2E00405B
#define MASK_PDSH3ADD_B  0xFE00707F
#define MATCH_PDSH3ADD_H 0x2E00505B
#define MASK_PDSH3ADD_H  0xFE00707F
#define MATCH_PDSH3ADD_W 0x2E00605B
#define MASK_PDSH3ADD_W  0xFE00707F
#define MATCH_PDSH3ADD_D 0x2E00705B
#define MASK_PDSH3ADD_D  0xFE00707F
#define MATCH_PWAND 0x3000005B
#define MASK_PWAND  0xFE00707F
#define MATCH_PDAND 0x3000405B
#define MASK_PDAND  0xFE00707F
#define MATCH_PWOR 0x3200005B
#define MASK_PWOR  0xFE00707F
#define MATCH_PDOR 0x3200405B
#define MASK_PDOR  0xFE00707F
#define MATCH_PWXOR 0x3400005B
#define MASK_PWXOR  0xFE00707F
#define MATCH_PDXOR 0x3400405B
#define MASK_PDXOR  0xFE00707F
#define MATCH_PWANDN 0x3800005B
#define MASK_PWANDN  0xFE00707F
#define MATCH_PDANDN 0x3800405B
#define MASK_PDANDN  0xFE00707F
#define MATCH_PWORN 0x3A00005B
#define MASK_PWORN  0xFE00707F
#define MATCH_PDORN 0x3A00405B
#define MASK_PDORN  0xFE00707F
#define MATCH_PWXNOR 0x3C00005B
#define MASK_PWXNOR  0xFE00707F
#define MATCH_PDXNOR 0x3C00405B
#define MASK_PDXNOR  0xFE00707F
#define MATCH_PWSLL_B 0x6000005B
#define MASK_PWSLL_B  0xFE00707F
#define MATCH_PWSLL_H 0x6000105B
#define MASK_PWSLL_H  0xFE00707F
#define MATCH_PWSLL_W 0x6000205B
#define MASK_PWSLL_W  0xFE00707F
#define MATCH_PDSLL_B 0x6000405B
#define MASK_PDSLL_B  0xFE00707F
#define MATCH_PDSLL_H 0x6000505B
#define MASK_PDSLL_H  0xFE00707F
#define MATCH_PDSLL_W 0x6000605B
#define MASK_PDSLL_W  0xFE00707F
#define MATCH_PDSLL_D 0x6000705B
#define MASK_PDSLL_D  0xFE00707F
#define MATCH_PWSRL_B 0x6200005B
#define MASK_PWSRL_B  0xFE00707F
#define MATCH_PWSRL_H 0x6200105B
#define MASK_PWSRL_H  0xFE00707F
#define MATCH_PWSRL_W 0x6200205B
#define MASK_PWSRL_W  0xFE00707F
#define MATCH_PDSRL_B 0x6200405B
#define MASK_PDSRL_B  0xFE00707F
#define MATCH_PDSRL_H 0x6200505B
#define MASK_PDSRL_H  0xFE00707F
#define MATCH_PDSRL_W 0x6200605B
#define MASK_PDSRL_W  0xFE00707F
#define MATCH_PDSRL_D 0x6200705B
#define MASK_PDSRL_D  0xFE00707F
#define MATCH_PWSLO_B 0x6800005B
#define MASK_PWSLO_B  0xFE00707F
#define MATCH_PWSLO_H 0x6800105B
#define MASK_PWSLO_H  0xFE00707F
#define MATCH_PWSLO_W 0x6800205B
#define MASK_PWSLO_W  0xFE00707F
#define MATCH_PDSLO_B 0x6800405B
#define MASK_PDSLO_B  0xFE00707F
#define MATCH_PDSLO_H 0x6800505B
#define MASK_PDSLO_H  0xFE00707F
#define MATCH_PDSLO_W 0x6800605B
#define MASK_PDSLO_W  0xFE00707F
#define MATCH_PDSLO_D 0x6800705B
#define MASK_PDSLO_D  0xFE00707F
#define MATCH_PWSRO_B 0x6A00005B
#define MASK_PWSRO_B  0xFE00707F
#define MATCH_PWSRO_H 0x6A00105B
#define MASK_PWSRO_H  0xFE00707F
#define MATCH_PWSRO_W 0x6A00205B
#define MASK_PWSRO_W  0xFE00707F
#define MATCH_PDSRO_B 0x6A00405B
#define MASK_PDSRO_B  0xFE00707F
#define MATCH_PDSRO_H 0x6A00505B
#define MASK_PDSRO_H  0xFE00707F
#define MATCH_PDSRO_W 0x6A00605B
#define MASK_PDSRO_W  0xFE00707F
#define MATCH_PDSRO_D 0x6A00705B
#define MASK_PDSRO_D  0xFE00707F
#define MATCH_PWSRA_B 0x7200005B
#define MASK_PWSRA_B  0xFE00707F
#define MATCH_PWSRA_H 0x7200105B
#define MASK_PWSRA_H  0xFE00707F
#define MATCH_PWSRA_W 0x7200205B
#define MASK_PWSRA_W  0xFE00707F
#define MATCH_PDSRA_B 0x7200405B
#define MASK_PDSRA_B  0xFE00707F
#define MATCH_PDSRA_H 0x7200505B
#define MASK_PDSRA_H  0xFE00707F
#define MATCH_PDSRA_W 0x7200605B
#define MASK_PDSRA_W  0xFE00707F
#define MATCH_PDSRA_D 0x7200705B
#define MASK_PDSRA_D  0xFE00707F
#define MATCH_PWROL_B 0x7800005B
#define MASK_PWROL_B  0xFE00707F
#define MATCH_PWROL_H 0x7800105B
#define MASK_PWROL_H  0xFE00707F
#define MATCH_PWROL_W 0x7800205B
#define MASK_PWROL_W  0xFE00707F
#define MATCH_PDROL_B 0x7800405B
#define MASK_PDROL_B  0xFE00707F
#define MATCH_PDROL_H 0x7800505B
#define MASK_PDROL_H  0xFE00707F
#define MATCH_PDROL_W 0x7800605B
#define MASK_PDROL_W  0xFE00707F
#define MATCH_PDROL_D 0x7800705B
#define MASK_PDROL_D  0xFE00707F
#define MATCH_PWROR_B 0x7A00005B
#define MASK_PWROR_B  0xFE00707F
#define MATCH_PWROR_H 0x7A00105B
#define MASK_PWROR_H  0xFE00707F
#define MATCH_PWROR_W 0x7A00205B
#define MASK_PWROR_W  0xFE00707F
#define MATCH_PDROR_B 0x7A00405B
#define MASK_PDROR_B  0xFE00707F
#define MATCH_PDROR_H 0x7A00505B
#define MASK_PDROR_H  0xFE00707F
#define MATCH_PDROR_W 0x7A00605B
#define MASK_PDROR_W  0xFE00707F
#define MATCH_PDROR_D 0x7A00705B
#define MASK_PDROR_D  0xFE00707F
#define MATCH_PWMULSSB_B 0x8000005B
#define MASK_PWMULSSB_B  0xFE00707F
#define MATCH_PWMULSSB_H 0x8000105B
#define MASK_PWMULSSB_H  0xFE00707F
#define MATCH_PWMULSSB_W 0x8000205B
#define MASK_PWMULSSB_W  0xFE00707F
#define MATCH_PDMULSSB_B 0x8000405B
#define MASK_PDMULSSB_B  0xFE00707F
#define MATCH_PDMULSSB_H 0x8000505B
#define MASK_PDMULSSB_H  0xFE00707F
#define MATCH_PDMULSSB_W 0x8000605B
#define MASK_PDMULSSB_W  0xFE00707F
#define MATCH_PWMULSUB_B 0x8200005B
#define MASK_PWMULSUB_B  0xFE00707F
#define MATCH_PWMULSUB_H 0x8200105B
#define MASK_PWMULSUB_H  0xFE00707F
#define MATCH_PWMULSUB_W 0x8200205B
#define MASK_PWMULSUB_W  0xFE00707F
#define MATCH_PDMULSUB_B 0x8200405B
#define MASK_PDMULSUB_B  0xFE00707F
#define MATCH_PDMULSUB_H 0x8200505B
#define MASK_PDMULSUB_H  0xFE00707F
#define MATCH_PDMULSUB_W 0x8200605B
#define MASK_PDMULSUB_W  0xFE00707F
#define MATCH_PWMULUUB_B 0x8400005B
#define MASK_PWMULUUB_B  0xFE00707F
#define MATCH_PWMULUUB_H 0x8400105B
#define MASK_PWMULUUB_H  0xFE00707F
#define MATCH_PWMULUUB_W 0x8400205B
#define MASK_PWMULUUB_W  0xFE00707F
#define MATCH_PDMULUUB_B 0x8400405B
#define MASK_PDMULUUB_B  0xFE00707F
#define MATCH_PDMULUUB_H 0x8400505B
#define MASK_PDMULUUB_H  0xFE00707F
#define MATCH_PDMULUUB_W 0x8400605B
#define MASK_PDMULUUB_W  0xFE00707F
#define MATCH_PWMULCCB_B 0x8600005B
#define MASK_PWMULCCB_B  0xFE00707F
#define MATCH_PWMULCCB_H 0x8600105B
#define MASK_PWMULCCB_H  0xFE00707F
#define MATCH_PDMULCCB_B 0x8600405B
#define MASK_PDMULCCB_B  0xFE00707F
#define MATCH_PDMULCCB_H 0x8600505B
#define MASK_PDMULCCB_H  0xFE00707F
#define MATCH_PDMULCCB_W 0x8600605B
#define MASK_PDMULCCB_W  0xFE00707F
#define MATCH_PWMULSSBQU_B 0x8800005B
#define MASK_PWMULSSBQU_B  0xFE00707F
#define MATCH_PWMULSSBQU_H 0x8800105B
#define MASK_PWMULSSBQU_H  0xFE00707F
#define MATCH_PWMULSSBQU_W 0x8800205B
#define MASK_PWMULSSBQU_W  0xFE00707F
#define MATCH_PDMULSSBQU_B 0x8800405B
#define MASK_PDMULSSBQU_B  0xFE00707F
#define MATCH_PDMULSSBQU_H 0x8800505B
#define MASK_PDMULSSBQU_H  0xFE00707F
#define MATCH_PDMULSSBQU_W 0x8800605B
#define MASK_PDMULSSBQU_W  0xFE00707F
#define MATCH_PWMULSUBQU_B 0x8A00005B
#define MASK_PWMULSUBQU_B  0xFE00707F
#define MATCH_PWMULSUBQU_H 0x8A00105B
#define MASK_PWMULSUBQU_H  0xFE00707F
#define MATCH_PWMULSUBQU_W 0x8A00205B
#define MASK_PWMULSUBQU_W  0xFE00707F
#define MATCH_PDMULSUBQU_B 0x8A00405B
#define MASK_PDMULSUBQU_B  0xFE00707F
#define MATCH_PDMULSUBQU_H 0x8A00505B
#define MASK_PDMULSUBQU_H  0xFE00707F
#define MATCH_PDMULSUBQU_W 0x8A00605B
#define MASK_PDMULSUBQU_W  0xFE00707F
#define MATCH_PWMULUUBQU_B 0x8C00005B
#define MASK_PWMULUUBQU_B  0xFE00707F
#define MATCH_PWMULUUBQU_H 0x8C00105B
#define MASK_PWMULUUBQU_H  0xFE00707F
#define MATCH_PWMULUUBQU_W 0x8C00205B
#define MASK_PWMULUUBQU_W  0xFE00707F
#define MATCH_PDMULUUBQU_B 0x8C00405B
#define MASK_PDMULUUBQU_B  0xFE00707F
#define MATCH_PDMULUUBQU_H 0x8C00505B
#define MASK_PDMULUUBQU_H  0xFE00707F
#define MATCH_PDMULUUBQU_W 0x8C00605B
#define MASK_PDMULUUBQU_W  0xFE00707F
#define MATCH_PWMULSSBQS_B 0x9000005B
#define MASK_PWMULSSBQS_B  0xFE00707F
#define MATCH_PWMULSSBQS_H 0x9000105B
#define MASK_PWMULSSBQS_H  0xFE00707F
#define MATCH_PWMULSSBQS_W 0x9000205B
#define MASK_PWMULSSBQS_W  0xFE00707F
#define MATCH_PDMULSSBQS_B 0x9000405B
#define MASK_PDMULSSBQS_B  0xFE00707F
#define MATCH_PDMULSSBQS_H 0x9000505B
#define MASK_PDMULSSBQS_H  0xFE00707F
#define MATCH_PDMULSSBQS_W 0x9000605B
#define MASK_PDMULSSBQS_W  0xFE00707F
#define MATCH_PWMULSUBQS_B 0x9200005B
#define MASK_PWMULSUBQS_B  0xFE00707F
#define MATCH_PWMULSUBQS_H 0x9200105B
#define MASK_PWMULSUBQS_H  0xFE00707F
#define MATCH_PWMULSUBQS_W 0x9200205B
#define MASK_PWMULSUBQS_W  0xFE00707F
#define MATCH_PDMULSUBQS_B 0x9200405B
#define MASK_PDMULSUBQS_B  0xFE00707F
#define MATCH_PDMULSUBQS_H 0x9200505B
#define MASK_PDMULSUBQS_H  0xFE00707F
#define MATCH_PDMULSUBQS_W 0x9200605B
#define MASK_PDMULSUBQS_W  0xFE00707F
#define MATCH_PWMULUUBQS_B 0x9400005B
#define MASK_PWMULUUBQS_B  0xFE00707F
#define MATCH_PWMULUUBQS_H 0x9400105B
#define MASK_PWMULUUBQS_H  0xFE00707F
#define MATCH_PWMULUUBQS_W 0x9400205B
#define MASK_PWMULUUBQS_W  0xFE00707F
#define MATCH_PDMULUUBQS_B 0x9400405B
#define MASK_PDMULUUBQS_B  0xFE00707F
#define MATCH_PDMULUUBQS_H 0x9400505B
#define MASK_PDMULUUBQS_H  0xFE00707F
#define MATCH_PDMULUUBQS_W 0x9400605B
#define MASK_PDMULUUBQS_W  0xFE00707F
#define MATCH_PWMULCCBQ_B 0x9600005B
#define MASK_PWMULCCBQ_B  0xFE00707F
#define MATCH_PWMULCCBQ_H 0x9600105B
#define MASK_PWMULCCBQ_H  0xFE00707F
#define MATCH_PDMULCCBQ_B 0x9600405B
#define MASK_PDMULCCBQ_B  0xFE00707F
#define MATCH_PDMULCCBQ_H 0x9600505B
#define MASK_PDMULCCBQ_H  0xFE00707F
#define MATCH_PDMULCCBQ_W 0x9600605B
#define MASK_PDMULCCBQ_W  0xFE00707F
#define MATCH_PWMULSST_B 0x9800005B
#define MASK_PWMULSST_B  0xFE00707F
#define MATCH_PWMULSST_H 0x9800105B
#define MASK_PWMULSST_H  0xFE00707F
#define MATCH_PWMULSST_W 0x9800205B
#define MASK_PWMULSST_W  0xFE00707F
#define MATCH_PDMULSST_B 0x9800405B
#define MASK_PDMULSST_B  0xFE00707F
#define MATCH_PDMULSST_H 0x9800505B
#define MASK_PDMULSST_H  0xFE00707F
#define MATCH_PDMULSST_W 0x9800605B
#define MASK_PDMULSST_W  0xFE00707F
#define MATCH_PWMULSUT_B 0x9A00005B
#define MASK_PWMULSUT_B  0xFE00707F
#define MATCH_PWMULSUT_H 0x9A00105B
#define MASK_PWMULSUT_H  0xFE00707F
#define MATCH_PWMULSUT_W 0x9A00205B
#define MASK_PWMULSUT_W  0xFE00707F
#define MATCH_PDMULSUT_B 0x9A00405B
#define MASK_PDMULSUT_B  0xFE00707F
#define MATCH_PDMULSUT_H 0x9A00505B
#define MASK_PDMULSUT_H  0xFE00707F
#define MATCH_PDMULSUT_W 0x9A00605B
#define MASK_PDMULSUT_W  0xFE00707F
#define MATCH_PWMULUUT_B 0x9C00005B
#define MASK_PWMULUUT_B  0xFE00707F
#define MATCH_PWMULUUT_H 0x9C00105B
#define MASK_PWMULUUT_H  0xFE00707F
#define MATCH_PWMULUUT_W 0x9C00205B
#define MASK_PWMULUUT_W  0xFE00707F
#define MATCH_PDMULUUT_B 0x9C00405B
#define MASK_PDMULUUT_B  0xFE00707F
#define MATCH_PDMULUUT_H 0x9C00505B
#define MASK_PDMULUUT_H  0xFE00707F
#define MATCH_PDMULUUT_W 0x9C00605B
#define MASK_PDMULUUT_W  0xFE00707F
#define MATCH_PWMULCCT_B 0x9E00005B
#define MASK_PWMULCCT_B  0xFE00707F
#define MATCH_PWMULCCT_H 0x9E00105B
#define MASK_PWMULCCT_H  0xFE00707F
#define MATCH_PDMULCCT_B 0x9E00405B
#define MASK_PDMULCCT_B  0xFE00707F
#define MATCH_PDMULCCT_H 0x9E00505B
#define MASK_PDMULCCT_H  0xFE00707F
#define MATCH_PDMULCCT_W 0x9E00605B
#define MASK_PDMULCCT_W  0xFE00707F
#define MATCH_PWMULSSW_B 0xA000005B
#define MASK_PWMULSSW_B  0xFE00707F
#define MATCH_PWMULSSW_H 0xA000105B
#define MASK_PWMULSSW_H  0xFE00707F
#define MATCH_PWMULSSW_W 0xA000205B
#define MASK_PWMULSSW_W  0xFE00707F
#define MATCH_PWMULSUW_B 0xA200005B
#define MASK_PWMULSUW_B  0xFE00707F
#define MATCH_PWMULSUW_H 0xA200105B
#define MASK_PWMULSUW_H  0xFE00707F
#define MATCH_PWMULSUW_W 0xA200205B
#define MASK_PWMULSUW_W  0xFE00707F
#define MATCH_PWMULUUW_B 0xA400005B
#define MASK_PWMULUUW_B  0xFE00707F
#define MATCH_PWMULUUW_H 0xA400105B
#define MASK_PWMULUUW_H  0xFE00707F
#define MATCH_PWMULUUW_W 0xA400205B
#define MASK_PWMULUUW_W  0xFE00707F
#define MATCH_PWMULCCW_B 0xA600005B
#define MASK_PWMULCCW_B  0xFE00707F
#define MATCH_PWMULCCW_H 0xA600105B
#define MASK_PWMULCCW_H  0xFE00707F
#define MATCH_PWMULCRW_B 0xA800005B
#define MASK_PWMULCRW_B  0xFE00707F
#define MATCH_PWMULCRW_H 0xA800105B
#define MASK_PWMULCRW_H  0xFE00707F
#define MATCH_PWMULCRBQ_B 0xAA00005B
#define MASK_PWMULCRBQ_B  0xFE00707F
#define MATCH_PWMULCRBQ_H 0xAA00105B
#define MASK_PWMULCRBQ_H  0xFE00707F
#define MATCH_PDMULCRBQ_B 0xAA00405B
#define MASK_PDMULCRBQ_B  0xFE00707F
#define MATCH_PDMULCRBQ_H 0xAA00505B
#define MASK_PDMULCRBQ_H  0xFE00707F
#define MATCH_PDMULCRBQ_W 0xAA00605B
#define MASK_PDMULCRBQ_W  0xFE00707F
#define MATCH_PWMULCRB_B 0xAC00005B
#define MASK_PWMULCRB_B  0xFE00707F
#define MATCH_PWMULCRB_H 0xAC00105B
#define MASK_PWMULCRB_H  0xFE00707F
#define MATCH_PDMULCRB_B 0xAC00405B
#define MASK_PDMULCRB_B  0xFE00707F
#define MATCH_PDMULCRB_H 0xAC00505B
#define MASK_PDMULCRB_H  0xFE00707F
#define MATCH_PDMULCRB_W 0xAC00605B
#define MASK_PDMULCRB_W  0xFE00707F
#define MATCH_PWMULCRT_B 0xAE00005B
#define MASK_PWMULCRT_B  0xFE00707F
#define MATCH_PWMULCRT_H 0xAE00105B
#define MASK_PWMULCRT_H  0xFE00707F
#define MATCH_PDMULCRT_B 0xAE00405B
#define MASK_PDMULCRT_B  0xFE00707F
#define MATCH_PDMULCRT_H 0xAE00505B
#define MASK_PDMULCRT_H  0xFE00707F
#define MATCH_PDMULCRT_W 0xAE00605B
#define MASK_PDMULCRT_W  0xFE00707F
#define MATCH_CROT_H 0xB000105B
#define MASK_CROT_H  0xFE00707F
#define MATCH_CROT_W 0xB000205B
#define MASK_CROT_W  0xFE00707F
#define MATCH_CMAGARG_H 0xB200105B
#define MASK_CMAGARG_H  0xFE00707F
#define MATCH_CMAGARG_W 0xB200205B
#define MASK_CMAGARG_W  0xFE00707F
#define MATCH_CHROT_H 0xB400105B
#define MASK_CHROT_H  0xFE00707F
#define MATCH_CHROT_W 0xB400205B
#define MASK_CHROT_W  0xFE00707F
#define MATCH_CHMAGARG_H 0xB600105B
#define MASK_CHMAGARG_H  0xFE00707F
#define MATCH_CHMAGARG_W 0xB600205B
#define MASK_CHMAGARG_W  0xFE00707F
#define MATCH_PWZMACCS_B 0xC000005B
#define MASK_PWZMACCS_B  0xFE00707F
#define MATCH_PWZMACCS_H 0xC000105B
#define MASK_PWZMACCS_H  0xFE00707F
#define MATCH_PWZMACCS_W 0xC000205B
#define MASK_PWZMACCS_W  0xFE00707F
#define MATCH_PDZMACCS_B 0xC000405B
#define MASK_PDZMACCS_B  0xFE00707F
#define MATCH_PDZMACCS_H 0xC000505B
#define MASK_PDZMACCS_H  0xFE00707F
#define MATCH_PDZMACCS_W 0xC000605B
#define MASK_PDZMACCS_W  0xFE00707F
#define MATCH_PWZMACCQS_B 0xC200005B
#define MASK_PWZMACCQS_B  0xFE00707F
#define MATCH_PWZMACCQS_H 0xC200105B
#define MASK_PWZMACCQS_H  0xFE00707F
#define MATCH_PWZMACCQS_W 0xC200205B
#define MASK_PWZMACCQS_W  0xFE00707F
#define MATCH_PDZMACCQS_B 0xC200405B
#define MASK_PDZMACCQS_B  0xFE00707F
#define MATCH_PDZMACCQS_H 0xC200505B
#define MASK_PDZMACCQS_H  0xFE00707F
#define MATCH_PDZMACCQS_W 0xC200605B
#define MASK_PDZMACCQS_W  0xFE00707F
#define MATCH_PWZMACCU_B 0xC400005B
#define MASK_PWZMACCU_B  0xFE00707F
#define MATCH_PWZMACCU_H 0xC400105B
#define MASK_PWZMACCU_H  0xFE00707F
#define MATCH_PWZMACCU_W 0xC400205B
#define MASK_PWZMACCU_W  0xFE00707F
#define MATCH_PDZMACCU_B 0xC400405B
#define MASK_PDZMACCU_B  0xFE00707F
#define MATCH_PDZMACCU_H 0xC400505B
#define MASK_PDZMACCU_H  0xFE00707F
#define MATCH_PDZMACCU_W 0xC400605B
#define MASK_PDZMACCU_W  0xFE00707F
#define MATCH_PWZMACCQU_B 0xC600005B
#define MASK_PWZMACCQU_B  0xFE00707F
#define MATCH_PWZMACCQU_H 0xC600105B
#define MASK_PWZMACCQU_H  0xFE00707F
#define MATCH_PWZMACCQU_W 0xC600205B
#define MASK_PWZMACCQU_W  0xFE00707F
#define MATCH_PDZMACCQU_B 0xC600405B
#define MASK_PDZMACCQU_B  0xFE00707F
#define MATCH_PDZMACCQU_H 0xC600505B
#define MASK_PDZMACCQU_H  0xFE00707F
#define MATCH_PDZMACCQU_W 0xC600605B
#define MASK_PDZMACCQU_W  0xFE00707F
#define MATCH_PWZMACCCC_B 0xC800005B
#define MASK_PWZMACCCC_B  0xFE00707F
#define MATCH_PWZMACCCC_H 0xC800105B
#define MASK_PWZMACCCC_H  0xFE00707F
#define MATCH_PDZMACCCC_B 0xC800405B
#define MASK_PDZMACCCC_B  0xFE00707F
#define MATCH_PDZMACCCC_H 0xC800505B
#define MASK_PDZMACCCC_H  0xFE00707F
#define MATCH_PWZMACCCCQ_B 0xCA00005B
#define MASK_PWZMACCCCQ_B  0xFE00707F
#define MATCH_PWZMACCCCQ_H 0xCA00105B
#define MASK_PWZMACCCCQ_H  0xFE00707F
#define MATCH_PDZMACCCCQ_B 0xCA00405B
#define MASK_PDZMACCCCQ_B  0xFE00707F
#define MATCH_PDZMACCCCQ_H 0xCA00505B
#define MASK_PDZMACCCCQ_H  0xFE00707F
#define MATCH_PWZMACCCR_B 0xCC00005B
#define MASK_PWZMACCCR_B  0xFE00707F
#define MATCH_PWZMACCCR_H 0xCC00105B
#define MASK_PWZMACCCR_H  0xFE00707F
#define MATCH_PDZMACCCR_B 0xCC00405B
#define MASK_PDZMACCCR_B  0xFE00707F
#define MATCH_PDZMACCCR_H 0xCC00505B
#define MASK_PDZMACCCR_H  0xFE00707F
#define MATCH_PWZMACCCRQ_B 0xCE00005B
#define MASK_PWZMACCCRQ_B  0xFE00707F
#define MATCH_PWZMACCCRQ_H 0xCE00105B
#define MASK_PWZMACCCRQ_H  0xFE00707F
#define MATCH_PDZMACCCRQ_B 0xCE00405B
#define MASK_PDZMACCCRQ_B  0xFE00707F
#define MATCH_PDZMACCCRQ_H 0xCE00505B
#define MASK_PDZMACCCRQ_H  0xFE00707F
#define MATCH_PWZMSUBS_B 0xD000005B
#define MASK_PWZMSUBS_B  0xFE00707F
#define MATCH_PWZMSUBS_H 0xD000105B
#define MASK_PWZMSUBS_H  0xFE00707F
#define MATCH_PWZMSUBS_W 0xD000205B
#define MASK_PWZMSUBS_W  0xFE00707F
#define MATCH_PDZMSUBS_B 0xD000405B
#define MASK_PDZMSUBS_B  0xFE00707F
#define MATCH_PDZMSUBS_H 0xD000505B
#define MASK_PDZMSUBS_H  0xFE00707F
#define MATCH_PDZMSUBS_W 0xD000605B
#define MASK_PDZMSUBS_W  0xFE00707F
#define MATCH_PWZMSUBQS_B 0xD200005B
#define MASK_PWZMSUBQS_B  0xFE00707F
#define MATCH_PWZMSUBQS_H 0xD200105B
#define MASK_PWZMSUBQS_H  0xFE00707F
#define MATCH_PWZMSUBQS_W 0xD200205B
#define MASK_PWZMSUBQS_W  0xFE00707F
#define MATCH_PDZMSUBQS_B 0xD200405B
#define MASK_PDZMSUBQS_B  0xFE00707F
#define MATCH_PDZMSUBQS_H 0xD200505B
#define MASK_PDZMSUBQS_H  0xFE00707F
#define MATCH_PDZMSUBQS_W 0xD200605B
#define MASK_PDZMSUBQS_W  0xFE00707F
#define MATCH_PWZMSUBU_B 0xD400005B
#define MASK_PWZMSUBU_B  0xFE00707F
#define MATCH_PWZMSUBU_H 0xD400105B
#define MASK_PWZMSUBU_H  0xFE00707F
#define MATCH_PWZMSUBU_W 0xD400205B
#define MASK_PWZMSUBU_W  0xFE00707F
#define MATCH_PDZMSUBU_B 0xD400405B
#define MASK_PDZMSUBU_B  0xFE00707F
#define MATCH_PDZMSUBU_H 0xD400505B
#define MASK_PDZMSUBU_H  0xFE00707F
#define MATCH_PDZMSUBU_W 0xD400605B
#define MASK_PDZMSUBU_W  0xFE00707F
#define MATCH_PWZMSUBQU_B 0xD600005B
#define MASK_PWZMSUBQU_B  0xFE00707F
#define MATCH_PWZMSUBQU_H 0xD600105B
#define MASK_PWZMSUBQU_H  0xFE00707F
#define MATCH_PWZMSUBQU_W 0xD600205B
#define MASK_PWZMSUBQU_W  0xFE00707F
#define MATCH_PDZMSUBQU_B 0xD600405B
#define MASK_PDZMSUBQU_B  0xFE00707F
#define MATCH_PDZMSUBQU_H 0xD600505B
#define MASK_PDZMSUBQU_H  0xFE00707F
#define MATCH_PDZMSUBQU_W 0xD600605B
#define MASK_PDZMSUBQU_W  0xFE00707F
#define MATCH_PWZMSUBCC_B 0xD800005B
#define MASK_PWZMSUBCC_B  0xFE00707F
#define MATCH_PWZMSUBCC_H 0xD800105B
#define MASK_PWZMSUBCC_H  0xFE00707F
#define MATCH_PDZMSUBCC_B 0xD800405B
#define MASK_PDZMSUBCC_B  0xFE00707F
#define MATCH_PDZMSUBCC_H 0xD800505B
#define MASK_PDZMSUBCC_H  0xFE00707F
#define MATCH_PWZMSUBCCQ_B 0xDA00005B
#define MASK_PWZMSUBCCQ_B  0xFE00707F
#define MATCH_PWZMSUBCCQ_H 0xDA00105B
#define MASK_PWZMSUBCCQ_H  0xFE00707F
#define MATCH_PDZMSUBCCQ_B 0xDA00405B
#define MASK_PDZMSUBCCQ_B  0xFE00707F
#define MATCH_PDZMSUBCCQ_H 0xDA00505B
#define MASK_PDZMSUBCCQ_H  0xFE00707F
#define MATCH_PWZMSUBCR_B 0xDC00005B
#define MASK_PWZMSUBCR_B  0xFE00707F
#define MATCH_PWZMSUBCR_H 0xDC00105B
#define MASK_PWZMSUBCR_H  0xFE00707F
#define MATCH_PDZMSUBCR_B 0xDC00405B
#define MASK_PDZMSUBCR_B  0xFE00707F
#define MATCH_PDZMSUBCR_H 0xDC00505B
#define MASK_PDZMSUBCR_H  0xFE00707F
#define MATCH_PWZMSUBCRQ_B 0xDE00005B
#define MASK_PWZMSUBCRQ_B  0xFE00707F
#define MATCH_PWZMSUBCRQ_H 0xDE00105B
#define MASK_PWZMSUBCRQ_H  0xFE00707F
#define MATCH_PDZMSUBCRQ_B 0xDE00405B
#define MASK_PDZMSUBCRQ_B  0xFE00707F
#define MATCH_PDZMSUBCRQ_H 0xDE00505B
#define MASK_PDZMSUBCRQ_H  0xFE00707F
#define MATCH_PWMACCS_B 0xE000005B
#define MASK_PWMACCS_B  0xFE00707F
#define MATCH_PWMACCS_H 0xE000105B
#define MASK_PWMACCS_H  0xFE00707F
#define MATCH_PWMACCS_W 0xE000205B
#define MASK_PWMACCS_W  0xFE00707F
#define MATCH_PDMACCS_B 0xE000405B
#define MASK_PDMACCS_B  0xFE00707F
#define MATCH_PDMACCS_H 0xE000505B
#define MASK_PDMACCS_H  0xFE00707F
#define MATCH_PDMACCS_W 0xE000605B
#define MASK_PDMACCS_W  0xFE00707F
#define MATCH_PWMACCQS_B 0xE200005B
#define MASK_PWMACCQS_B  0xFE00707F
#define MATCH_PWMACCQS_H 0xE200105B
#define MASK_PWMACCQS_H  0xFE00707F
#define MATCH_PWMACCQS_W 0xE200205B
#define MASK_PWMACCQS_W  0xFE00707F
#define MATCH_PDMACCQS_B 0xE200405B
#define MASK_PDMACCQS_B  0xFE00707F
#define MATCH_PDMACCQS_H 0xE200505B
#define MASK_PDMACCQS_H  0xFE00707F
#define MATCH_PDMACCQS_W 0xE200605B
#define MASK_PDMACCQS_W  0xFE00707F
#define MATCH_PWMACCU_B 0xE400005B
#define MASK_PWMACCU_B  0xFE00707F
#define MATCH_PWMACCU_H 0xE400105B
#define MASK_PWMACCU_H  0xFE00707F
#define MATCH_PWMACCU_W 0xE400205B
#define MASK_PWMACCU_W  0xFE00707F
#define MATCH_PDMACCU_B 0xE400405B
#define MASK_PDMACCU_B  0xFE00707F
#define MATCH_PDMACCU_H 0xE400505B
#define MASK_PDMACCU_H  0xFE00707F
#define MATCH_PDMACCU_W 0xE400605B
#define MASK_PDMACCU_W  0xFE00707F
#define MATCH_PWMACCQU_B 0xE600005B
#define MASK_PWMACCQU_B  0xFE00707F
#define MATCH_PWMACCQU_H 0xE600105B
#define MASK_PWMACCQU_H  0xFE00707F
#define MATCH_PWMACCQU_W 0xE600205B
#define MASK_PWMACCQU_W  0xFE00707F
#define MATCH_PDMACCQU_B 0xE600405B
#define MASK_PDMACCQU_B  0xFE00707F
#define MATCH_PDMACCQU_H 0xE600505B
#define MASK_PDMACCQU_H  0xFE00707F
#define MATCH_PDMACCQU_W 0xE600605B
#define MASK_PDMACCQU_W  0xFE00707F
#define MATCH_PWMACCCC_B 0xE800005B
#define MASK_PWMACCCC_B  0xFE00707F
#define MATCH_PWMACCCC_H 0xE800105B
#define MASK_PWMACCCC_H  0xFE00707F
#define MATCH_PDMACCCC_B 0xE800405B
#define MASK_PDMACCCC_B  0xFE00707F
#define MATCH_PDMACCCC_H 0xE800505B
#define MASK_PDMACCCC_H  0xFE00707F
#define MATCH_PWMACCCCQ_B 0xEA00005B
#define MASK_PWMACCCCQ_B  0xFE00707F
#define MATCH_PWMACCCCQ_H 0xEA00105B
#define MASK_PWMACCCCQ_H  0xFE00707F
#define MATCH_PDMACCCCQ_B 0xEA00405B
#define MASK_PDMACCCCQ_B  0xFE00707F
#define MATCH_PDMACCCCQ_H 0xEA00505B
#define MASK_PDMACCCCQ_H  0xFE00707F
#define MATCH_PWMACCCR_B 0xEC00005B
#define MASK_PWMACCCR_B  0xFE00707F
#define MATCH_PWMACCCR_H 0xEC00105B
#define MASK_PWMACCCR_H  0xFE00707F
#define MATCH_PDMACCCR_B 0xEC00405B
#define MASK_PDMACCCR_B  0xFE00707F
#define MATCH_PDMACCCR_H 0xEC00505B
#define MASK_PDMACCCR_H  0xFE00707F
#define MATCH_PWMACCCRQ_B 0xEE00005B
#define MASK_PWMACCCRQ_B  0xFE00707F
#define MATCH_PWMACCCRQ_H 0xEE00105B
#define MASK_PWMACCCRQ_H  0xFE00707F
#define MATCH_PDMACCCRQ_B 0xEE00405B
#define MASK_PDMACCCRQ_B  0xFE00707F
#define MATCH_PDMACCCRQ_H 0xEE00505B
#define MASK_PDMACCCRQ_H  0xFE00707F
#define MATCH_PWMSUBS_B 0xF000005B
#define MASK_PWMSUBS_B  0xFE00707F
#define MATCH_PWMSUBS_H 0xF000105B
#define MASK_PWMSUBS_H  0xFE00707F
#define MATCH_PWMSUBS_W 0xF000205B
#define MASK_PWMSUBS_W  0xFE00707F
#define MATCH_PDMSUBS_B 0xF000405B
#define MASK_PDMSUBS_B  0xFE00707F
#define MATCH_PDMSUBS_H 0xF000505B
#define MASK_PDMSUBS_H  0xFE00707F
#define MATCH_PDMSUBS_W 0xF000605B
#define MASK_PDMSUBS_W  0xFE00707F
#define MATCH_PWMSUBQS_B 0xF200005B
#define MASK_PWMSUBQS_B  0xFE00707F
#define MATCH_PWMSUBQS_H 0xF200105B
#define MASK_PWMSUBQS_H  0xFE00707F
#define MATCH_PWMSUBQS_W 0xF200205B
#define MASK_PWMSUBQS_W  0xFE00707F
#define MATCH_PDMSUBQS_B 0xF200405B
#define MASK_PDMSUBQS_B  0xFE00707F
#define MATCH_PDMSUBQS_H 0xF200505B
#define MASK_PDMSUBQS_H  0xFE00707F
#define MATCH_PDMSUBQS_W 0xF200605B
#define MASK_PDMSUBQS_W  0xFE00707F
#define MATCH_PWMSUBU_B 0xF400005B
#define MASK_PWMSUBU_B  0xFE00707F
#define MATCH_PWMSUBU_H 0xF400105B
#define MASK_PWMSUBU_H  0xFE00707F
#define MATCH_PWMSUBU_W 0xF400205B
#define MASK_PWMSUBU_W  0xFE00707F
#define MATCH_PDMSUBU_B 0xF400405B
#define MASK_PDMSUBU_B  0xFE00707F
#define MATCH_PDMSUBU_H 0xF400505B
#define MASK_PDMSUBU_H  0xFE00707F
#define MATCH_PDMSUBU_W 0xF400605B
#define MASK_PDMSUBU_W  0xFE00707F
#define MATCH_PWMSUBQU_B 0xF600005B
#define MASK_PWMSUBQU_B  0xFE00707F
#define MATCH_PWMSUBQU_H 0xF600105B
#define MASK_PWMSUBQU_H  0xFE00707F
#define MATCH_PWMSUBQU_W 0xF600205B
#define MASK_PWMSUBQU_W  0xFE00707F
#define MATCH_PDMSUBQU_B 0xF600405B
#define MASK_PDMSUBQU_B  0xFE00707F
#define MATCH_PDMSUBQU_H 0xF600505B
#define MASK_PDMSUBQU_H  0xFE00707F
#define MATCH_PDMSUBQU_W 0xF600605B
#define MASK_PDMSUBQU_W  0xFE00707F
#define MATCH_PWMSUBCC_B 0xF800005B
#define MASK_PWMSUBCC_B  0xFE00707F
#define MATCH_PWMSUBCC_H 0xF800105B
#define MASK_PWMSUBCC_H  0xFE00707F
#define MATCH_PDMSUBCC_B 0xF800405B
#define MASK_PDMSUBCC_B  0xFE00707F
#define MATCH_PDMSUBCC_H 0xF800505B
#define MASK_PDMSUBCC_H  0xFE00707F
#define MATCH_PWMSUBCCQ_B 0xFA00005B
#define MASK_PWMSUBCCQ_B  0xFE00707F
#define MATCH_PWMSUBCCQ_H 0xFA00105B
#define MASK_PWMSUBCCQ_H  0xFE00707F
#define MATCH_PDMSUBCCQ_B 0xFA00405B
#define MASK_PDMSUBCCQ_B  0xFE00707F
#define MATCH_PDMSUBCCQ_H 0xFA00505B
#define MASK_PDMSUBCCQ_H  0xFE00707F
#define MATCH_PWMSUBCR_B 0xFC00005B
#define MASK_PWMSUBCR_B  0xFE00707F
#define MATCH_PWMSUBCR_H 0xFC00105B
#define MASK_PWMSUBCR_H  0xFE00707F
#define MATCH_PDMSUBCR_B 0xFC00405B
#define MASK_PDMSUBCR_B  0xFE00707F
#define MATCH_PDMSUBCR_H 0xFC00505B
#define MASK_PDMSUBCR_H  0xFE00707F
#define MATCH_PWMSUBCRQ_B 0xFE00005B
#define MASK_PWMSUBCRQ_B  0xFE00707F
#define MATCH_PWMSUBCRQ_H 0xFE00105B
#define MASK_PWMSUBCRQ_H  0xFE00707F
#define MATCH_PDMSUBCRQ_B 0xFE00405B
#define MASK_PDMSUBCRQ_B  0xFE00707F
#define MATCH_PDMSUBCRQ_H 0xFE00505B
#define MASK_PDMSUBCRQ_H  0xFE00707F
/* Privileged CSR addresses (v1.11).  */
#define CSR_USTATUS 0x0
#define CSR_UIE 0x4
#define CSR_UTVEC 0x5
#define CSR_USCRATCH 0x40
#define CSR_UEPC 0x41
#define CSR_UCAUSE 0x42
#define CSR_UTVAL 0x43
#define CSR_UIP 0x44
#define CSR_CYCLE 0xc00
#define CSR_TIME 0xc01
#define CSR_INSTRET 0xc02
#define CSR_HPMCOUNTER3 0xc03
#define CSR_HPMCOUNTER4 0xc04
#define CSR_HPMCOUNTER5 0xc05
#define CSR_HPMCOUNTER6 0xc06
#define CSR_HPMCOUNTER7 0xc07
#define CSR_HPMCOUNTER8 0xc08
#define CSR_HPMCOUNTER9 0xc09
#define CSR_HPMCOUNTER10 0xc0a
#define CSR_HPMCOUNTER11 0xc0b
#define CSR_HPMCOUNTER12 0xc0c
#define CSR_HPMCOUNTER13 0xc0d
#define CSR_HPMCOUNTER14 0xc0e
#define CSR_HPMCOUNTER15 0xc0f
#define CSR_HPMCOUNTER16 0xc10
#define CSR_HPMCOUNTER17 0xc11
#define CSR_HPMCOUNTER18 0xc12
#define CSR_HPMCOUNTER19 0xc13
#define CSR_HPMCOUNTER20 0xc14
#define CSR_HPMCOUNTER21 0xc15
#define CSR_HPMCOUNTER22 0xc16
#define CSR_HPMCOUNTER23 0xc17
#define CSR_HPMCOUNTER24 0xc18
#define CSR_HPMCOUNTER25 0xc19
#define CSR_HPMCOUNTER26 0xc1a
#define CSR_HPMCOUNTER27 0xc1b
#define CSR_HPMCOUNTER28 0xc1c
#define CSR_HPMCOUNTER29 0xc1d
#define CSR_HPMCOUNTER30 0xc1e
#define CSR_HPMCOUNTER31 0xc1f
#define CSR_CYCLEH 0xc80
#define CSR_TIMEH 0xc81
#define CSR_INSTRETH 0xc82
#define CSR_HPMCOUNTER3H 0xc83
#define CSR_HPMCOUNTER4H 0xc84
#define CSR_HPMCOUNTER5H 0xc85
#define CSR_HPMCOUNTER6H 0xc86
#define CSR_HPMCOUNTER7H 0xc87
#define CSR_HPMCOUNTER8H 0xc88
#define CSR_HPMCOUNTER9H 0xc89
#define CSR_HPMCOUNTER10H 0xc8a
#define CSR_HPMCOUNTER11H 0xc8b
#define CSR_HPMCOUNTER12H 0xc8c
#define CSR_HPMCOUNTER13H 0xc8d
#define CSR_HPMCOUNTER14H 0xc8e
#define CSR_HPMCOUNTER15H 0xc8f
#define CSR_HPMCOUNTER16H 0xc90
#define CSR_HPMCOUNTER17H 0xc91
#define CSR_HPMCOUNTER18H 0xc92
#define CSR_HPMCOUNTER19H 0xc93
#define CSR_HPMCOUNTER20H 0xc94
#define CSR_HPMCOUNTER21H 0xc95
#define CSR_HPMCOUNTER22H 0xc96
#define CSR_HPMCOUNTER23H 0xc97
#define CSR_HPMCOUNTER24H 0xc98
#define CSR_HPMCOUNTER25H 0xc99
#define CSR_HPMCOUNTER26H 0xc9a
#define CSR_HPMCOUNTER27H 0xc9b
#define CSR_HPMCOUNTER28H 0xc9c
#define CSR_HPMCOUNTER29H 0xc9d
#define CSR_HPMCOUNTER30H 0xc9e
#define CSR_HPMCOUNTER31H 0xc9f
#define CSR_SSTATUS 0x100
#define CSR_SEDELEG 0x102
#define CSR_SIDELEG 0x103
#define CSR_SIE 0x104
#define CSR_STVEC 0x105
#define CSR_SCOUNTEREN 0x106
#define CSR_SSCRATCH 0x140
#define CSR_SEPC 0x141
#define CSR_SCAUSE 0x142
#define CSR_STVAL 0x143
#define CSR_SIP 0x144
#define CSR_SATP 0x180
#define CSR_MVENDORID 0xf11
#define CSR_MARCHID 0xf12
#define CSR_MIMPID 0xf13
#define CSR_MHARTID 0xf14
#define CSR_MSTATUS 0x300
#define CSR_MISA 0x301
#define CSR_MEDELEG 0x302
#define CSR_MIDELEG 0x303
#define CSR_MIE 0x304
#define CSR_MTVEC 0x305
#define CSR_MCOUNTEREN 0x306
#define CSR_MSCRATCH 0x340
#define CSR_MEPC 0x341
#define CSR_MCAUSE 0x342
#define CSR_MTVAL 0x343
#define CSR_MIP 0x344
#define CSR_PMPCFG0 0x3a0
#define CSR_PMPCFG1 0x3a1
#define CSR_PMPCFG2 0x3a2
#define CSR_PMPCFG3 0x3a3
#define CSR_PMPADDR0 0x3b0
#define CSR_PMPADDR1 0x3b1
#define CSR_PMPADDR2 0x3b2
#define CSR_PMPADDR3 0x3b3
#define CSR_PMPADDR4 0x3b4
#define CSR_PMPADDR5 0x3b5
#define CSR_PMPADDR6 0x3b6
#define CSR_PMPADDR7 0x3b7
#define CSR_PMPADDR8 0x3b8
#define CSR_PMPADDR9 0x3b9
#define CSR_PMPADDR10 0x3ba
#define CSR_PMPADDR11 0x3bb
#define CSR_PMPADDR12 0x3bc
#define CSR_PMPADDR13 0x3bd
#define CSR_PMPADDR14 0x3be
#define CSR_PMPADDR15 0x3bf
#define CSR_MCYCLE 0xb00
#define CSR_MINSTRET 0xb02
#define CSR_MHPMCOUNTER3 0xb03
#define CSR_MHPMCOUNTER4 0xb04
#define CSR_MHPMCOUNTER5 0xb05
#define CSR_MHPMCOUNTER6 0xb06
#define CSR_MHPMCOUNTER7 0xb07
#define CSR_MHPMCOUNTER8 0xb08
#define CSR_MHPMCOUNTER9 0xb09
#define CSR_MHPMCOUNTER10 0xb0a
#define CSR_MHPMCOUNTER11 0xb0b
#define CSR_MHPMCOUNTER12 0xb0c
#define CSR_MHPMCOUNTER13 0xb0d
#define CSR_MHPMCOUNTER14 0xb0e
#define CSR_MHPMCOUNTER15 0xb0f
#define CSR_MHPMCOUNTER16 0xb10
#define CSR_MHPMCOUNTER17 0xb11
#define CSR_MHPMCOUNTER18 0xb12
#define CSR_MHPMCOUNTER19 0xb13
#define CSR_MHPMCOUNTER20 0xb14
#define CSR_MHPMCOUNTER21 0xb15
#define CSR_MHPMCOUNTER22 0xb16
#define CSR_MHPMCOUNTER23 0xb17
#define CSR_MHPMCOUNTER24 0xb18
#define CSR_MHPMCOUNTER25 0xb19
#define CSR_MHPMCOUNTER26 0xb1a
#define CSR_MHPMCOUNTER27 0xb1b
#define CSR_MHPMCOUNTER28 0xb1c
#define CSR_MHPMCOUNTER29 0xb1d
#define CSR_MHPMCOUNTER30 0xb1e
#define CSR_MHPMCOUNTER31 0xb1f
#define CSR_MCYCLEH 0xb80
#define CSR_MINSTRETH 0xb82
#define CSR_MHPMCOUNTER3H 0xb83
#define CSR_MHPMCOUNTER4H 0xb84
#define CSR_MHPMCOUNTER5H 0xb85
#define CSR_MHPMCOUNTER6H 0xb86
#define CSR_MHPMCOUNTER7H 0xb87
#define CSR_MHPMCOUNTER8H 0xb88
#define CSR_MHPMCOUNTER9H 0xb89
#define CSR_MHPMCOUNTER10H 0xb8a
#define CSR_MHPMCOUNTER11H 0xb8b
#define CSR_MHPMCOUNTER12H 0xb8c
#define CSR_MHPMCOUNTER13H 0xb8d
#define CSR_MHPMCOUNTER14H 0xb8e
#define CSR_MHPMCOUNTER15H 0xb8f
#define CSR_MHPMCOUNTER16H 0xb90
#define CSR_MHPMCOUNTER17H 0xb91
#define CSR_MHPMCOUNTER18H 0xb92
#define CSR_MHPMCOUNTER19H 0xb93
#define CSR_MHPMCOUNTER20H 0xb94
#define CSR_MHPMCOUNTER21H 0xb95
#define CSR_MHPMCOUNTER22H 0xb96
#define CSR_MHPMCOUNTER23H 0xb97
#define CSR_MHPMCOUNTER24H 0xb98
#define CSR_MHPMCOUNTER25H 0xb99
#define CSR_MHPMCOUNTER26H 0xb9a
#define CSR_MHPMCOUNTER27H 0xb9b
#define CSR_MHPMCOUNTER28H 0xb9c
#define CSR_MHPMCOUNTER29H 0xb9d
#define CSR_MHPMCOUNTER30H 0xb9e
#define CSR_MHPMCOUNTER31H 0xb9f
#define CSR_MCOUNTINHIBIT 0x320
#define CSR_MHPMEVENT3 0x323
#define CSR_MHPMEVENT4 0x324
#define CSR_MHPMEVENT5 0x325
#define CSR_MHPMEVENT6 0x326
#define CSR_MHPMEVENT7 0x327
#define CSR_MHPMEVENT8 0x328
#define CSR_MHPMEVENT9 0x329
#define CSR_MHPMEVENT10 0x32a
#define CSR_MHPMEVENT11 0x32b
#define CSR_MHPMEVENT12 0x32c
#define CSR_MHPMEVENT13 0x32d
#define CSR_MHPMEVENT14 0x32e
#define CSR_MHPMEVENT15 0x32f
#define CSR_MHPMEVENT16 0x330
#define CSR_MHPMEVENT17 0x331
#define CSR_MHPMEVENT18 0x332
#define CSR_MHPMEVENT19 0x333
#define CSR_MHPMEVENT20 0x334
#define CSR_MHPMEVENT21 0x335
#define CSR_MHPMEVENT22 0x336
#define CSR_MHPMEVENT23 0x337
#define CSR_MHPMEVENT24 0x338
#define CSR_MHPMEVENT25 0x339
#define CSR_MHPMEVENT26 0x33a
#define CSR_MHPMEVENT27 0x33b
#define CSR_MHPMEVENT28 0x33c
#define CSR_MHPMEVENT29 0x33d
#define CSR_MHPMEVENT30 0x33e
#define CSR_MHPMEVENT31 0x33f
#define CSR_HSTATUS 0x200
#define CSR_HEDELEG 0x202
#define CSR_HIDELEG 0x203
#define CSR_HIE 0x204
#define CSR_HTVEC 0x205
#define CSR_HSCRATCH 0x240
#define CSR_HEPC 0x241
#define CSR_HCAUSE 0x242
#define CSR_HBADADDR 0x243
#define CSR_HIP 0x244
#define CSR_MBASE 0x380
#define CSR_MBOUND 0x381
#define CSR_MIBASE 0x382
#define CSR_MIBOUND 0x383
#define CSR_MDBASE 0x384
#define CSR_MDBOUND 0x385
#define CSR_MSCOUNTEREN 0x321
#define CSR_MHCOUNTEREN 0x322
/* Unprivileged CSR addresses.  */
#define CSR_FFLAGS 0x1
#define CSR_FRM 0x2
#define CSR_FCSR 0x3
#define CSR_DCSR 0x7b0
#define CSR_DPC 0x7b1
#define CSR_DSCRATCH0 0x7b2
#define CSR_DSCRATCH1 0x7b3
#define CSR_TSELECT 0x7a0
#define CSR_TDATA1 0x7a1
#define CSR_TDATA2 0x7a2
#define CSR_TDATA3 0x7a3
#define CSR_TINFO 0x7a4
#define CSR_TCONTROL 0x7a5
#define CSR_MCONTEXT 0x7a8
#define CSR_SCONTEXT 0x7aa
#endif /* RISCV_ENCODING_H.  */
#ifdef DECLARE_INSN
DECLARE_INSN(slli_rv32, MATCH_SLLI_RV32, MASK_SLLI_RV32)
DECLARE_INSN(srli_rv32, MATCH_SRLI_RV32, MASK_SRLI_RV32)
DECLARE_INSN(srai_rv32, MATCH_SRAI_RV32, MASK_SRAI_RV32)
DECLARE_INSN(frflags, MATCH_FRFLAGS, MASK_FRFLAGS)
DECLARE_INSN(fsflags, MATCH_FSFLAGS, MASK_FSFLAGS)
DECLARE_INSN(fsflagsi, MATCH_FSFLAGSI, MASK_FSFLAGSI)
DECLARE_INSN(frrm, MATCH_FRRM, MASK_FRRM)
DECLARE_INSN(fsrm, MATCH_FSRM, MASK_FSRM)
DECLARE_INSN(fsrmi, MATCH_FSRMI, MASK_FSRMI)
DECLARE_INSN(fscsr, MATCH_FSCSR, MASK_FSCSR)
DECLARE_INSN(frcsr, MATCH_FRCSR, MASK_FRCSR)
DECLARE_INSN(rdcycle, MATCH_RDCYCLE, MASK_RDCYCLE)
DECLARE_INSN(rdtime, MATCH_RDTIME, MASK_RDTIME)
DECLARE_INSN(rdinstret, MATCH_RDINSTRET, MASK_RDINSTRET)
DECLARE_INSN(rdcycleh, MATCH_RDCYCLEH, MASK_RDCYCLEH)
DECLARE_INSN(rdtimeh, MATCH_RDTIMEH, MASK_RDTIMEH)
DECLARE_INSN(rdinstreth, MATCH_RDINSTRETH, MASK_RDINSTRETH)
DECLARE_INSN(scall, MATCH_SCALL, MASK_SCALL)
DECLARE_INSN(sbreak, MATCH_SBREAK, MASK_SBREAK)
DECLARE_INSN(beq, MATCH_BEQ, MASK_BEQ)
DECLARE_INSN(bne, MATCH_BNE, MASK_BNE)
DECLARE_INSN(blt, MATCH_BLT, MASK_BLT)
DECLARE_INSN(bge, MATCH_BGE, MASK_BGE)
DECLARE_INSN(bltu, MATCH_BLTU, MASK_BLTU)
DECLARE_INSN(bgeu, MATCH_BGEU, MASK_BGEU)
DECLARE_INSN(jalr, MATCH_JALR, MASK_JALR)
DECLARE_INSN(jal, MATCH_JAL, MASK_JAL)
DECLARE_INSN(lui, MATCH_LUI, MASK_LUI)
DECLARE_INSN(auipc, MATCH_AUIPC, MASK_AUIPC)
DECLARE_INSN(addi, MATCH_ADDI, MASK_ADDI)
DECLARE_INSN(slli, MATCH_SLLI, MASK_SLLI)
DECLARE_INSN(slti, MATCH_SLTI, MASK_SLTI)
DECLARE_INSN(sltiu, MATCH_SLTIU, MASK_SLTIU)
DECLARE_INSN(xori, MATCH_XORI, MASK_XORI)
DECLARE_INSN(srli, MATCH_SRLI, MASK_SRLI)
DECLARE_INSN(srai, MATCH_SRAI, MASK_SRAI)
DECLARE_INSN(ori, MATCH_ORI, MASK_ORI)
DECLARE_INSN(andi, MATCH_ANDI, MASK_ANDI)
DECLARE_INSN(add, MATCH_ADD, MASK_ADD)
DECLARE_INSN(sub, MATCH_SUB, MASK_SUB)
DECLARE_INSN(sll, MATCH_SLL, MASK_SLL)
DECLARE_INSN(slt, MATCH_SLT, MASK_SLT)
DECLARE_INSN(sltu, MATCH_SLTU, MASK_SLTU)
DECLARE_INSN(xor, MATCH_XOR, MASK_XOR)
DECLARE_INSN(srl, MATCH_SRL, MASK_SRL)
DECLARE_INSN(sra, MATCH_SRA, MASK_SRA)
DECLARE_INSN(or, MATCH_OR, MASK_OR)
DECLARE_INSN(and, MATCH_AND, MASK_AND)
DECLARE_INSN(addiw, MATCH_ADDIW, MASK_ADDIW)
DECLARE_INSN(slliw, MATCH_SLLIW, MASK_SLLIW)
DECLARE_INSN(srliw, MATCH_SRLIW, MASK_SRLIW)
DECLARE_INSN(sraiw, MATCH_SRAIW, MASK_SRAIW)
DECLARE_INSN(addw, MATCH_ADDW, MASK_ADDW)
DECLARE_INSN(subw, MATCH_SUBW, MASK_SUBW)
DECLARE_INSN(sllw, MATCH_SLLW, MASK_SLLW)
DECLARE_INSN(srlw, MATCH_SRLW, MASK_SRLW)
DECLARE_INSN(sraw, MATCH_SRAW, MASK_SRAW)
DECLARE_INSN(lb, MATCH_LB, MASK_LB)
DECLARE_INSN(lh, MATCH_LH, MASK_LH)
DECLARE_INSN(lw, MATCH_LW, MASK_LW)
DECLARE_INSN(ld, MATCH_LD, MASK_LD)
DECLARE_INSN(lbu, MATCH_LBU, MASK_LBU)
DECLARE_INSN(lhu, MATCH_LHU, MASK_LHU)
DECLARE_INSN(lwu, MATCH_LWU, MASK_LWU)
DECLARE_INSN(sb, MATCH_SB, MASK_SB)
DECLARE_INSN(sh, MATCH_SH, MASK_SH)
DECLARE_INSN(sw, MATCH_SW, MASK_SW)
DECLARE_INSN(sd, MATCH_SD, MASK_SD)
DECLARE_INSN(pause, MATCH_PAUSE, MASK_PAUSE)
DECLARE_INSN(fence, MATCH_FENCE, MASK_FENCE)
DECLARE_INSN(fence_i, MATCH_FENCE_I, MASK_FENCE_I)
DECLARE_INSN(mul, MATCH_MUL, MASK_MUL)
DECLARE_INSN(mulh, MATCH_MULH, MASK_MULH)
DECLARE_INSN(mulhsu, MATCH_MULHSU, MASK_MULHSU)
DECLARE_INSN(mulhu, MATCH_MULHU, MASK_MULHU)
DECLARE_INSN(div, MATCH_DIV, MASK_DIV)
DECLARE_INSN(divu, MATCH_DIVU, MASK_DIVU)
DECLARE_INSN(rem, MATCH_REM, MASK_REM)
DECLARE_INSN(remu, MATCH_REMU, MASK_REMU)
DECLARE_INSN(mulw, MATCH_MULW, MASK_MULW)
DECLARE_INSN(divw, MATCH_DIVW, MASK_DIVW)
DECLARE_INSN(divuw, MATCH_DIVUW, MASK_DIVUW)
DECLARE_INSN(remw, MATCH_REMW, MASK_REMW)
DECLARE_INSN(remuw, MATCH_REMUW, MASK_REMUW)
DECLARE_INSN(andn, MATCH_ANDN, MASK_ANDN)
DECLARE_INSN(orn, MATCH_ORN, MASK_ORN)
DECLARE_INSN(xnor, MATCH_XNOR, MASK_XNOR)
DECLARE_INSN(rol, MATCH_ROL, MASK_ROL)
DECLARE_INSN(ror, MATCH_ROR, MASK_ROR)
DECLARE_INSN(bclr, MATCH_BCLR, MASK_BCLR)
DECLARE_INSN(bset, MATCH_BSET, MASK_BSET)
DECLARE_INSN(binv, MATCH_BINV, MASK_BINV)
DECLARE_INSN(bext, MATCH_BEXT, MASK_BEXT)
DECLARE_INSN(gorc, MATCH_GORC, MASK_GORC)
DECLARE_INSN(grev, MATCH_GREV, MASK_GREV)
DECLARE_INSN(rori, MATCH_RORI, MASK_RORI)
DECLARE_INSN(bclri, MATCH_BCLRI, MASK_BCLRI)
DECLARE_INSN(bseti, MATCH_BSETI, MASK_BSETI)
DECLARE_INSN(binvi, MATCH_BINVI, MASK_BINVI)
DECLARE_INSN(bexti, MATCH_BEXTI, MASK_BEXTI)
DECLARE_INSN(gorci, MATCH_GORCI, MASK_GORCI)
DECLARE_INSN(grevi, MATCH_GREVI, MASK_GREVI)
DECLARE_INSN(cmix, MATCH_CMIX, MASK_CMIX)
DECLARE_INSN(cmov, MATCH_CMOV, MASK_CMOV)
DECLARE_INSN(fsl, MATCH_FSL, MASK_FSL)
DECLARE_INSN(fsr, MATCH_FSR, MASK_FSR)
DECLARE_INSN(fsri, MATCH_FSRI, MASK_FSRI)
DECLARE_INSN(clz, MATCH_CLZ, MASK_CLZ)
DECLARE_INSN(ctz, MATCH_CTZ, MASK_CTZ)
DECLARE_INSN(cpop, MATCH_CPOP, MASK_CPOP)
DECLARE_INSN(sext_b, MATCH_SEXT_B, MASK_SEXT_B)
DECLARE_INSN(sext_h, MATCH_SEXT_H, MASK_SEXT_H)
DECLARE_INSN(crc32_b, MATCH_CRC32_B, MASK_CRC32_B)
DECLARE_INSN(crc32_h, MATCH_CRC32_H, MASK_CRC32_H)
DECLARE_INSN(crc32_w, MATCH_CRC32_W, MASK_CRC32_W)
DECLARE_INSN(crc32c_b, MATCH_CRC32C_B, MASK_CRC32C_B)
DECLARE_INSN(crc32c_h, MATCH_CRC32C_H, MASK_CRC32C_H)
DECLARE_INSN(crc32c_w, MATCH_CRC32C_W, MASK_CRC32C_W)
DECLARE_INSN(sh1add, MATCH_SH1ADD, MASK_SH1ADD)
DECLARE_INSN(sh2add, MATCH_SH2ADD, MASK_SH2ADD)
DECLARE_INSN(sh3add, MATCH_SH3ADD, MASK_SH3ADD)
DECLARE_INSN(clmul, MATCH_CLMUL, MASK_CLMUL)
DECLARE_INSN(clmulr, MATCH_CLMULR, MASK_CLMULR)
DECLARE_INSN(clmulh, MATCH_CLMULH, MASK_CLMULH)
DECLARE_INSN(min, MATCH_MIN, MASK_MIN)
DECLARE_INSN(max, MATCH_MAX, MASK_MAX)
DECLARE_INSN(minu, MATCH_MINU, MASK_MINU)
DECLARE_INSN(maxu, MATCH_MAXU, MASK_MAXU)
DECLARE_INSN(shfl, MATCH_SHFL, MASK_SHFL)
DECLARE_INSN(unshfl, MATCH_UNSHFL, MASK_UNSHFL)
DECLARE_INSN(bmext, MATCH_BMEXT, MASK_BMEXT)
DECLARE_INSN(bmdep, MATCH_BMDEP, MASK_BMDEP)
DECLARE_INSN(pack, MATCH_PACK, MASK_PACK)
DECLARE_INSN(packu, MATCH_PACKU, MASK_PACKU)
DECLARE_INSN(packh, MATCH_PACKH, MASK_PACKH)
DECLARE_INSN(bfp, MATCH_BFP, MASK_BFP)
DECLARE_INSN(shfli, MATCH_SHFLI, MASK_SHFLI)
DECLARE_INSN(unshfli, MATCH_UNSHFLI, MASK_UNSHFLI)
DECLARE_INSN(bmatflip, MATCH_BMATFLIP, MASK_BMATFLIP)
DECLARE_INSN(crc32_d, MATCH_CRC32_D, MASK_CRC32_D)
DECLARE_INSN(crc32c_d, MATCH_CRC32C_D, MASK_CRC32C_D)
DECLARE_INSN(bmator, MATCH_BMATOR, MASK_BMATOR)
DECLARE_INSN(bmatxor, MATCH_BMATXOR, MASK_BMATXOR)
DECLARE_INSN(slliu_w, MATCH_SLLIU_W, MASK_SLLIU_W)
DECLARE_INSN(addu_w, MATCH_ADDU_W, MASK_ADDU_W)
DECLARE_INSN(rolw, MATCH_ROLW, MASK_ROLW)
DECLARE_INSN(rorw, MATCH_RORW, MASK_RORW)
DECLARE_INSN(bclrw, MATCH_BCLRW, MASK_BCLRW)
DECLARE_INSN(bsetw, MATCH_BSETW, MASK_BSETW)
DECLARE_INSN(binvw, MATCH_BINVW, MASK_BINVW)
DECLARE_INSN(bextw, MATCH_BEXTW, MASK_BEXTW)
DECLARE_INSN(gorcw, MATCH_GORCW, MASK_GORCW)
DECLARE_INSN(grevw, MATCH_GREVW, MASK_GREVW)
DECLARE_INSN(roriw, MATCH_RORIW, MASK_RORIW)
DECLARE_INSN(bclriw, MATCH_BCLRIW, MASK_BCLRIW)
DECLARE_INSN(bsetiw, MATCH_BSETIW, MASK_BSETIW)
DECLARE_INSN(binviw, MATCH_BINVIW, MASK_BINVIW)
DECLARE_INSN(gorciw, MATCH_GORCIW, MASK_GORCIW)
DECLARE_INSN(greviw, MATCH_GREVIW, MASK_GREVIW)
DECLARE_INSN(fslw, MATCH_FSLW, MASK_FSLW)
DECLARE_INSN(fsrw, MATCH_FSRW, MASK_FSRW)
DECLARE_INSN(fsriw, MATCH_FSRIW, MASK_FSRIW)
DECLARE_INSN(clzw, MATCH_CLZW, MASK_CLZW)
DECLARE_INSN(ctzw, MATCH_CTZW, MASK_CTZW)
DECLARE_INSN(cpopw, MATCH_CPOPW, MASK_CPOPW)
DECLARE_INSN(sh1addu_w, MATCH_SH1ADDU_W, MASK_SH1ADDU_W)
DECLARE_INSN(sh2addu_w, MATCH_SH2ADDU_W, MASK_SH2ADDU_W)
DECLARE_INSN(sh3addu_w, MATCH_SH3ADDU_W, MASK_SH3ADDU_W)
DECLARE_INSN(shflw, MATCH_SHFLW, MASK_SHFLW)
DECLARE_INSN(unshflw, MATCH_UNSHFLW, MASK_UNSHFLW)
DECLARE_INSN(bmextw, MATCH_BMEXTW, MASK_BMEXTW)
DECLARE_INSN(bmdepw, MATCH_BMDEPW, MASK_BMDEPW)
DECLARE_INSN(packw, MATCH_PACKW, MASK_PACKW)
DECLARE_INSN(packuw, MATCH_PACKUW, MASK_PACKUW)
DECLARE_INSN(bfpw, MATCH_BFPW, MASK_BFPW)
DECLARE_INSN(xperm_n, MATCH_XPERMN, MASK_XPERMN)
DECLARE_INSN(xperm_b, MATCH_XPERMB, MASK_XPERMB)
DECLARE_INSN(xperm_h, MATCH_XPERMH, MASK_XPERMH)
DECLARE_INSN(xperm_w, MATCH_XPERMW, MASK_XPERMW)
DECLARE_INSN(aes32esmi, MATCH_AES32ESMI, MASK_AES32ESMI)
DECLARE_INSN(aes32esi, MATCH_AES32ESI, MASK_AES32ESI)
DECLARE_INSN(aes32dsmi, MATCH_AES32DSMI, MASK_AES32DSMI)
DECLARE_INSN(aes32dsi, MATCH_AES32DSI, MASK_AES32DSI)
DECLARE_INSN(sha256sig0, MATCH_SHA256SIG0, MASK_SHA256SIG0)
DECLARE_INSN(sha256sig1, MATCH_SHA256SIG1, MASK_SHA256SIG1)
DECLARE_INSN(sha256sum0, MATCH_SHA256SUM0, MASK_SHA256SUM0)
DECLARE_INSN(sha256sum1, MATCH_SHA256SUM1, MASK_SHA256SUM1)
DECLARE_INSN(sha512sum0r, MATCH_SHA512SUM0R, MASK_SHA512SUM0R)
DECLARE_INSN(sha512sum1r, MATCH_SHA512SUM1R, MASK_SHA512SUM1R)
DECLARE_INSN(sha512sig0l, MATCH_SHA512SIG0L, MASK_SHA512SIG0L)
DECLARE_INSN(sha512sig0h, MATCH_SHA512SIG0H, MASK_SHA512SIG0H)
DECLARE_INSN(sha512sig1l, MATCH_SHA512SIG1L, MASK_SHA512SIG1L)
DECLARE_INSN(sha512sig1h, MATCH_SHA512SIG1H, MASK_SHA512SIG1H)

DECLARE_INSN(amoadd_w, MATCH_AMOADD_W, MASK_AMOADD_W)
DECLARE_INSN(amoxor_w, MATCH_AMOXOR_W, MASK_AMOXOR_W)
DECLARE_INSN(amoor_w, MATCH_AMOOR_W, MASK_AMOOR_W)
DECLARE_INSN(amoand_w, MATCH_AMOAND_W, MASK_AMOAND_W)
DECLARE_INSN(amomin_w, MATCH_AMOMIN_W, MASK_AMOMIN_W)
DECLARE_INSN(amomax_w, MATCH_AMOMAX_W, MASK_AMOMAX_W)
DECLARE_INSN(amominu_w, MATCH_AMOMINU_W, MASK_AMOMINU_W)
DECLARE_INSN(amomaxu_w, MATCH_AMOMAXU_W, MASK_AMOMAXU_W)
DECLARE_INSN(amoswap_w, MATCH_AMOSWAP_W, MASK_AMOSWAP_W)
DECLARE_INSN(lr_w, MATCH_LR_W, MASK_LR_W)
DECLARE_INSN(sc_w, MATCH_SC_W, MASK_SC_W)
DECLARE_INSN(amoadd_d, MATCH_AMOADD_D, MASK_AMOADD_D)
DECLARE_INSN(amoxor_d, MATCH_AMOXOR_D, MASK_AMOXOR_D)
DECLARE_INSN(amoor_d, MATCH_AMOOR_D, MASK_AMOOR_D)
DECLARE_INSN(amoand_d, MATCH_AMOAND_D, MASK_AMOAND_D)
DECLARE_INSN(amomin_d, MATCH_AMOMIN_D, MASK_AMOMIN_D)
DECLARE_INSN(amomax_d, MATCH_AMOMAX_D, MASK_AMOMAX_D)
DECLARE_INSN(amominu_d, MATCH_AMOMINU_D, MASK_AMOMINU_D)
DECLARE_INSN(amomaxu_d, MATCH_AMOMAXU_D, MASK_AMOMAXU_D)
DECLARE_INSN(amoswap_d, MATCH_AMOSWAP_D, MASK_AMOSWAP_D)
DECLARE_INSN(lr_d, MATCH_LR_D, MASK_LR_D)
DECLARE_INSN(sc_d, MATCH_SC_D, MASK_SC_D)
DECLARE_INSN(ecall, MATCH_ECALL, MASK_ECALL)
DECLARE_INSN(ebreak, MATCH_EBREAK, MASK_EBREAK)
DECLARE_INSN(uret, MATCH_URET, MASK_URET)
DECLARE_INSN(sret, MATCH_SRET, MASK_SRET)
DECLARE_INSN(hret, MATCH_HRET, MASK_HRET)
DECLARE_INSN(mret, MATCH_MRET, MASK_MRET)
DECLARE_INSN(dret, MATCH_DRET, MASK_DRET)
DECLARE_INSN(sfence_vm, MATCH_SFENCE_VM, MASK_SFENCE_VM)
DECLARE_INSN(sfence_vma, MATCH_SFENCE_VMA, MASK_SFENCE_VMA)
DECLARE_INSN(wfi, MATCH_WFI, MASK_WFI)
DECLARE_INSN(csrrw, MATCH_CSRRW, MASK_CSRRW)
DECLARE_INSN(csrrs, MATCH_CSRRS, MASK_CSRRS)
DECLARE_INSN(csrrc, MATCH_CSRRC, MASK_CSRRC)
DECLARE_INSN(csrrwi, MATCH_CSRRWI, MASK_CSRRWI)
DECLARE_INSN(csrrsi, MATCH_CSRRSI, MASK_CSRRSI)
DECLARE_INSN(csrrci, MATCH_CSRRCI, MASK_CSRRCI)
DECLARE_INSN(fadd_s, MATCH_FADD_S, MASK_FADD_S)
DECLARE_INSN(fsub_s, MATCH_FSUB_S, MASK_FSUB_S)
DECLARE_INSN(fmul_s, MATCH_FMUL_S, MASK_FMUL_S)
DECLARE_INSN(fdiv_s, MATCH_FDIV_S, MASK_FDIV_S)
DECLARE_INSN(fsgnj_s, MATCH_FSGNJ_S, MASK_FSGNJ_S)
DECLARE_INSN(fsgnjn_s, MATCH_FSGNJN_S, MASK_FSGNJN_S)
DECLARE_INSN(fsgnjx_s, MATCH_FSGNJX_S, MASK_FSGNJX_S)
DECLARE_INSN(fmin_s, MATCH_FMIN_S, MASK_FMIN_S)
DECLARE_INSN(fmax_s, MATCH_FMAX_S, MASK_FMAX_S)
DECLARE_INSN(fsqrt_s, MATCH_FSQRT_S, MASK_FSQRT_S)
DECLARE_INSN(fadd_d, MATCH_FADD_D, MASK_FADD_D)
DECLARE_INSN(fsub_d, MATCH_FSUB_D, MASK_FSUB_D)
DECLARE_INSN(fmul_d, MATCH_FMUL_D, MASK_FMUL_D)
DECLARE_INSN(fdiv_d, MATCH_FDIV_D, MASK_FDIV_D)
DECLARE_INSN(fsgnj_d, MATCH_FSGNJ_D, MASK_FSGNJ_D)
DECLARE_INSN(fsgnjn_d, MATCH_FSGNJN_D, MASK_FSGNJN_D)
DECLARE_INSN(fsgnjx_d, MATCH_FSGNJX_D, MASK_FSGNJX_D)
DECLARE_INSN(fmin_d, MATCH_FMIN_D, MASK_FMIN_D)
DECLARE_INSN(fmax_d, MATCH_FMAX_D, MASK_FMAX_D)
DECLARE_INSN(fcvt_s_d, MATCH_FCVT_S_D, MASK_FCVT_S_D)
DECLARE_INSN(fcvt_d_s, MATCH_FCVT_D_S, MASK_FCVT_D_S)
DECLARE_INSN(fsqrt_d, MATCH_FSQRT_D, MASK_FSQRT_D)
DECLARE_INSN(fadd_q, MATCH_FADD_Q, MASK_FADD_Q)
DECLARE_INSN(fsub_q, MATCH_FSUB_Q, MASK_FSUB_Q)
DECLARE_INSN(fmul_q, MATCH_FMUL_Q, MASK_FMUL_Q)
DECLARE_INSN(fdiv_q, MATCH_FDIV_Q, MASK_FDIV_Q)
DECLARE_INSN(fsgnj_q, MATCH_FSGNJ_Q, MASK_FSGNJ_Q)
DECLARE_INSN(fsgnjn_q, MATCH_FSGNJN_Q, MASK_FSGNJN_Q)
DECLARE_INSN(fsgnjx_q, MATCH_FSGNJX_Q, MASK_FSGNJX_Q)
DECLARE_INSN(fmin_q, MATCH_FMIN_Q, MASK_FMIN_Q)
DECLARE_INSN(fmax_q, MATCH_FMAX_Q, MASK_FMAX_Q)
DECLARE_INSN(fcvt_s_q, MATCH_FCVT_S_Q, MASK_FCVT_S_Q)
DECLARE_INSN(fcvt_q_s, MATCH_FCVT_Q_S, MASK_FCVT_Q_S)
DECLARE_INSN(fcvt_d_q, MATCH_FCVT_D_Q, MASK_FCVT_D_Q)
DECLARE_INSN(fcvt_q_d, MATCH_FCVT_Q_D, MASK_FCVT_Q_D)
DECLARE_INSN(fsqrt_q, MATCH_FSQRT_Q, MASK_FSQRT_Q)
DECLARE_INSN(fle_s, MATCH_FLE_S, MASK_FLE_S)
DECLARE_INSN(flt_s, MATCH_FLT_S, MASK_FLT_S)
DECLARE_INSN(feq_s, MATCH_FEQ_S, MASK_FEQ_S)
DECLARE_INSN(fle_d, MATCH_FLE_D, MASK_FLE_D)
DECLARE_INSN(flt_d, MATCH_FLT_D, MASK_FLT_D)
DECLARE_INSN(feq_d, MATCH_FEQ_D, MASK_FEQ_D)
DECLARE_INSN(fle_q, MATCH_FLE_Q, MASK_FLE_Q)
DECLARE_INSN(flt_q, MATCH_FLT_Q, MASK_FLT_Q)
DECLARE_INSN(feq_q, MATCH_FEQ_Q, MASK_FEQ_Q)
DECLARE_INSN(fcvt_w_s, MATCH_FCVT_W_S, MASK_FCVT_W_S)
DECLARE_INSN(fcvt_wu_s, MATCH_FCVT_WU_S, MASK_FCVT_WU_S)
DECLARE_INSN(fcvt_l_s, MATCH_FCVT_L_S, MASK_FCVT_L_S)
DECLARE_INSN(fcvt_lu_s, MATCH_FCVT_LU_S, MASK_FCVT_LU_S)
DECLARE_INSN(fmv_x_s, MATCH_FMV_X_S, MASK_FMV_X_S)
DECLARE_INSN(fclass_s, MATCH_FCLASS_S, MASK_FCLASS_S)
DECLARE_INSN(fcvt_w_d, MATCH_FCVT_W_D, MASK_FCVT_W_D)
DECLARE_INSN(fcvt_wu_d, MATCH_FCVT_WU_D, MASK_FCVT_WU_D)
DECLARE_INSN(fcvt_l_d, MATCH_FCVT_L_D, MASK_FCVT_L_D)
DECLARE_INSN(fcvt_lu_d, MATCH_FCVT_LU_D, MASK_FCVT_LU_D)
DECLARE_INSN(fmv_x_d, MATCH_FMV_X_D, MASK_FMV_X_D)
DECLARE_INSN(fclass_d, MATCH_FCLASS_D, MASK_FCLASS_D)
DECLARE_INSN(fcvt_w_q, MATCH_FCVT_W_Q, MASK_FCVT_W_Q)
DECLARE_INSN(fcvt_wu_q, MATCH_FCVT_WU_Q, MASK_FCVT_WU_Q)
DECLARE_INSN(fcvt_l_q, MATCH_FCVT_L_Q, MASK_FCVT_L_Q)
DECLARE_INSN(fcvt_lu_q, MATCH_FCVT_LU_Q, MASK_FCVT_LU_Q)
DECLARE_INSN(fmv_x_q, MATCH_FMV_X_Q, MASK_FMV_X_Q)
DECLARE_INSN(fclass_q, MATCH_FCLASS_Q, MASK_FCLASS_Q)
DECLARE_INSN(fcvt_s_w, MATCH_FCVT_S_W, MASK_FCVT_S_W)
DECLARE_INSN(fcvt_s_wu, MATCH_FCVT_S_WU, MASK_FCVT_S_WU)
DECLARE_INSN(fcvt_s_l, MATCH_FCVT_S_L, MASK_FCVT_S_L)
DECLARE_INSN(fcvt_s_lu, MATCH_FCVT_S_LU, MASK_FCVT_S_LU)
DECLARE_INSN(fmv_s_x, MATCH_FMV_S_X, MASK_FMV_S_X)
DECLARE_INSN(fcvt_d_w, MATCH_FCVT_D_W, MASK_FCVT_D_W)
DECLARE_INSN(fcvt_d_wu, MATCH_FCVT_D_WU, MASK_FCVT_D_WU)
DECLARE_INSN(fcvt_d_l, MATCH_FCVT_D_L, MASK_FCVT_D_L)
DECLARE_INSN(fcvt_d_lu, MATCH_FCVT_D_LU, MASK_FCVT_D_LU)
DECLARE_INSN(fmv_d_x, MATCH_FMV_D_X, MASK_FMV_D_X)
DECLARE_INSN(fcvt_q_w, MATCH_FCVT_Q_W, MASK_FCVT_Q_W)
DECLARE_INSN(fcvt_q_wu, MATCH_FCVT_Q_WU, MASK_FCVT_Q_WU)
DECLARE_INSN(fcvt_q_l, MATCH_FCVT_Q_L, MASK_FCVT_Q_L)
DECLARE_INSN(fcvt_q_lu, MATCH_FCVT_Q_LU, MASK_FCVT_Q_LU)
DECLARE_INSN(fmv_q_x, MATCH_FMV_Q_X, MASK_FMV_Q_X)
DECLARE_INSN(flw, MATCH_FLW, MASK_FLW)
DECLARE_INSN(fld, MATCH_FLD, MASK_FLD)
DECLARE_INSN(flq, MATCH_FLQ, MASK_FLQ)
DECLARE_INSN(fsw, MATCH_FSW, MASK_FSW)
DECLARE_INSN(fsd, MATCH_FSD, MASK_FSD)
DECLARE_INSN(fsq, MATCH_FSQ, MASK_FSQ)
DECLARE_INSN(fmadd_s, MATCH_FMADD_S, MASK_FMADD_S)
DECLARE_INSN(fmsub_s, MATCH_FMSUB_S, MASK_FMSUB_S)
DECLARE_INSN(fnmsub_s, MATCH_FNMSUB_S, MASK_FNMSUB_S)
DECLARE_INSN(fnmadd_s, MATCH_FNMADD_S, MASK_FNMADD_S)
DECLARE_INSN(fmadd_d, MATCH_FMADD_D, MASK_FMADD_D)
DECLARE_INSN(fmsub_d, MATCH_FMSUB_D, MASK_FMSUB_D)
DECLARE_INSN(fnmsub_d, MATCH_FNMSUB_D, MASK_FNMSUB_D)
DECLARE_INSN(fnmadd_d, MATCH_FNMADD_D, MASK_FNMADD_D)
DECLARE_INSN(fmadd_q, MATCH_FMADD_Q, MASK_FMADD_Q)
DECLARE_INSN(fmsub_q, MATCH_FMSUB_Q, MASK_FMSUB_Q)
DECLARE_INSN(fnmsub_q, MATCH_FNMSUB_Q, MASK_FNMSUB_Q)
DECLARE_INSN(fnmadd_q, MATCH_FNMADD_Q, MASK_FNMADD_Q)
DECLARE_INSN(c_addi4spn, MATCH_C_ADDI4SPN, MASK_C_ADDI4SPN)
DECLARE_INSN(c_fld, MATCH_C_FLD, MASK_C_FLD)
DECLARE_INSN(c_lw, MATCH_C_LW, MASK_C_LW)
DECLARE_INSN(c_flw, MATCH_C_FLW, MASK_C_FLW)
DECLARE_INSN(c_fsd, MATCH_C_FSD, MASK_C_FSD)
DECLARE_INSN(c_sw, MATCH_C_SW, MASK_C_SW)
DECLARE_INSN(c_fsw, MATCH_C_FSW, MASK_C_FSW)
DECLARE_INSN(c_addi, MATCH_C_ADDI, MASK_C_ADDI)
DECLARE_INSN(c_jal, MATCH_C_JAL, MASK_C_JAL)
DECLARE_INSN(c_li, MATCH_C_LI, MASK_C_LI)
DECLARE_INSN(c_lui, MATCH_C_LUI, MASK_C_LUI)
DECLARE_INSN(c_srli, MATCH_C_SRLI, MASK_C_SRLI)
DECLARE_INSN(c_srai, MATCH_C_SRAI, MASK_C_SRAI)
DECLARE_INSN(c_andi, MATCH_C_ANDI, MASK_C_ANDI)
DECLARE_INSN(c_sub, MATCH_C_SUB, MASK_C_SUB)
DECLARE_INSN(c_xor, MATCH_C_XOR, MASK_C_XOR)
DECLARE_INSN(c_or, MATCH_C_OR, MASK_C_OR)
DECLARE_INSN(c_and, MATCH_C_AND, MASK_C_AND)
DECLARE_INSN(c_subw, MATCH_C_SUBW, MASK_C_SUBW)
DECLARE_INSN(c_addw, MATCH_C_ADDW, MASK_C_ADDW)
DECLARE_INSN(c_j, MATCH_C_J, MASK_C_J)
DECLARE_INSN(c_beqz, MATCH_C_BEQZ, MASK_C_BEQZ)
DECLARE_INSN(c_bnez, MATCH_C_BNEZ, MASK_C_BNEZ)
DECLARE_INSN(c_slli, MATCH_C_SLLI, MASK_C_SLLI)
DECLARE_INSN(c_fldsp, MATCH_C_FLDSP, MASK_C_FLDSP)
DECLARE_INSN(c_lwsp, MATCH_C_LWSP, MASK_C_LWSP)
DECLARE_INSN(c_flwsp, MATCH_C_FLWSP, MASK_C_FLWSP)
DECLARE_INSN(c_mv, MATCH_C_MV, MASK_C_MV)
DECLARE_INSN(c_add, MATCH_C_ADD, MASK_C_ADD)
DECLARE_INSN(c_fsdsp, MATCH_C_FSDSP, MASK_C_FSDSP)
DECLARE_INSN(c_swsp, MATCH_C_SWSP, MASK_C_SWSP)
DECLARE_INSN(c_fswsp, MATCH_C_FSWSP, MASK_C_FSWSP)
DECLARE_INSN(c_nop, MATCH_C_NOP, MASK_C_NOP)
DECLARE_INSN(c_addi16sp, MATCH_C_ADDI16SP, MASK_C_ADDI16SP)
DECLARE_INSN(c_jr, MATCH_C_JR, MASK_C_JR)
DECLARE_INSN(c_jalr, MATCH_C_JALR, MASK_C_JALR)
DECLARE_INSN(c_ebreak, MATCH_C_EBREAK, MASK_C_EBREAK)
DECLARE_INSN(c_ld, MATCH_C_LD, MASK_C_LD)
DECLARE_INSN(c_sd, MATCH_C_SD, MASK_C_SD)
DECLARE_INSN(c_addiw, MATCH_C_ADDIW, MASK_C_ADDIW)
DECLARE_INSN(c_ldsp, MATCH_C_LDSP, MASK_C_LDSP)
DECLARE_INSN(c_sdsp, MATCH_C_SDSP, MASK_C_SDSP)
DECLARE_INSN(custom0, MATCH_CUSTOM0, MASK_CUSTOM0)
DECLARE_INSN(custom0_rs1, MATCH_CUSTOM0_RS1, MASK_CUSTOM0_RS1)
DECLARE_INSN(custom0_rs1_rs2, MATCH_CUSTOM0_RS1_RS2, MASK_CUSTOM0_RS1_RS2)
DECLARE_INSN(custom0_rd, MATCH_CUSTOM0_RD, MASK_CUSTOM0_RD)
DECLARE_INSN(custom0_rd_rs1, MATCH_CUSTOM0_RD_RS1, MASK_CUSTOM0_RD_RS1)
DECLARE_INSN(custom0_rd_rs1_rs2, MATCH_CUSTOM0_RD_RS1_RS2, MASK_CUSTOM0_RD_RS1_RS2)
DECLARE_INSN(custom1, MATCH_CUSTOM1, MASK_CUSTOM1)
DECLARE_INSN(custom1_rs1, MATCH_CUSTOM1_RS1, MASK_CUSTOM1_RS1)
DECLARE_INSN(custom1_rs1_rs2, MATCH_CUSTOM1_RS1_RS2, MASK_CUSTOM1_RS1_RS2)
DECLARE_INSN(custom1_rd, MATCH_CUSTOM1_RD, MASK_CUSTOM1_RD)
DECLARE_INSN(custom1_rd_rs1, MATCH_CUSTOM1_RD_RS1, MASK_CUSTOM1_RD_RS1)
DECLARE_INSN(custom1_rd_rs1_rs2, MATCH_CUSTOM1_RD_RS1_RS2, MASK_CUSTOM1_RD_RS1_RS2)
DECLARE_INSN(custom2, MATCH_CUSTOM2, MASK_CUSTOM2)
DECLARE_INSN(custom2_rs1, MATCH_CUSTOM2_RS1, MASK_CUSTOM2_RS1)
DECLARE_INSN(custom2_rs1_rs2, MATCH_CUSTOM2_RS1_RS2, MASK_CUSTOM2_RS1_RS2)
DECLARE_INSN(custom2_rd, MATCH_CUSTOM2_RD, MASK_CUSTOM2_RD)
DECLARE_INSN(custom2_rd_rs1, MATCH_CUSTOM2_RD_RS1, MASK_CUSTOM2_RD_RS1)
DECLARE_INSN(custom2_rd_rs1_rs2, MATCH_CUSTOM2_RD_RS1_RS2, MASK_CUSTOM2_RD_RS1_RS2)
DECLARE_INSN(custom3, MATCH_CUSTOM3, MASK_CUSTOM3)
DECLARE_INSN(custom3_rs1, MATCH_CUSTOM3_RS1, MASK_CUSTOM3_RS1)
DECLARE_INSN(custom3_rs1_rs2, MATCH_CUSTOM3_RS1_RS2, MASK_CUSTOM3_RS1_RS2)
DECLARE_INSN(custom3_rd, MATCH_CUSTOM3_RD, MASK_CUSTOM3_RD)
DECLARE_INSN(custom3_rd_rs1, MATCH_CUSTOM3_RD_RS1, MASK_CUSTOM3_RD_RS1)
DECLARE_INSN(custom3_rd_rs1_rs2, MATCH_CUSTOM3_RD_RS1_RS2, MASK_CUSTOM3_RD_RS1_RS2)
/* Amethyst SIMD Instructions */
DECLARE_INSN(pwsub_b, MATCH_PWSUB_B, MASK_PWSUB_B)
DECLARE_INSN(pwsub_h, MATCH_PWSUB_H, MASK_PWSUB_H)
DECLARE_INSN(pwsub_w, MATCH_PWSUB_W, MASK_PWSUB_W)
DECLARE_INSN(pdsub_b, MATCH_PDSUB_B, MASK_PDSUB_B)
DECLARE_INSN(pdsub_h, MATCH_PDSUB_H, MASK_PDSUB_H)
DECLARE_INSN(pdsub_w, MATCH_PDSUB_W, MASK_PDSUB_W)
DECLARE_INSN(pdsub_d, MATCH_PDSUB_D, MASK_PDSUB_D)
DECLARE_INSN(pwsubhu_b, MATCH_PWSUBHU_B, MASK_PWSUBHU_B)
DECLARE_INSN(pwsubhu_h, MATCH_PWSUBHU_H, MASK_PWSUBHU_H)
DECLARE_INSN(pwsubhu_w, MATCH_PWSUBHU_W, MASK_PWSUBHU_W)
DECLARE_INSN(pdsubhu_b, MATCH_PDSUBHU_B, MASK_PDSUBHU_B)
DECLARE_INSN(pdsubhu_h, MATCH_PDSUBHU_H, MASK_PDSUBHU_H)
DECLARE_INSN(pdsubhu_w, MATCH_PDSUBHU_W, MASK_PDSUBHU_W)
DECLARE_INSN(pdsubhu_d, MATCH_PDSUBHU_D, MASK_PDSUBHU_D)
DECLARE_INSN(pwsubss_b, MATCH_PWSUBSS_B, MASK_PWSUBSS_B)
DECLARE_INSN(pwsubss_h, MATCH_PWSUBSS_H, MASK_PWSUBSS_H)
DECLARE_INSN(pwsubss_w, MATCH_PWSUBSS_W, MASK_PWSUBSS_W)
DECLARE_INSN(pdsubss_b, MATCH_PDSUBSS_B, MASK_PDSUBSS_B)
DECLARE_INSN(pdsubss_h, MATCH_PDSUBSS_H, MASK_PDSUBSS_H)
DECLARE_INSN(pdsubss_w, MATCH_PDSUBSS_W, MASK_PDSUBSS_W)
DECLARE_INSN(pdsubss_d, MATCH_PDSUBSS_D, MASK_PDSUBSS_D)
DECLARE_INSN(pwsubus_b, MATCH_PWSUBUS_B, MASK_PWSUBUS_B)
DECLARE_INSN(pwsubus_h, MATCH_PWSUBUS_H, MASK_PWSUBUS_H)
DECLARE_INSN(pwsubus_w, MATCH_PWSUBUS_W, MASK_PWSUBUS_W)
DECLARE_INSN(pdsubus_b, MATCH_PDSUBUS_B, MASK_PDSUBUS_B)
DECLARE_INSN(pdsubus_h, MATCH_PDSUBUS_H, MASK_PDSUBUS_H)
DECLARE_INSN(pdsubus_w, MATCH_PDSUBUS_W, MASK_PDSUBUS_W)
DECLARE_INSN(pdsubus_d, MATCH_PDSUBUS_D, MASK_PDSUBUS_D)
DECLARE_INSN(pwsubhs_b, MATCH_PWSUBHS_B, MASK_PWSUBHS_B)
DECLARE_INSN(pwsubhs_h, MATCH_PWSUBHS_H, MASK_PWSUBHS_H)
DECLARE_INSN(pwsubhs_w, MATCH_PWSUBHS_W, MASK_PWSUBHS_W)
DECLARE_INSN(pdsubhs_b, MATCH_PDSUBHS_B, MASK_PDSUBHS_B)
DECLARE_INSN(pdsubhs_h, MATCH_PDSUBHS_H, MASK_PDSUBHS_H)
DECLARE_INSN(pdsubhs_w, MATCH_PDSUBHS_W, MASK_PDSUBHS_W)
DECLARE_INSN(pdsubhs_d, MATCH_PDSUBHS_D, MASK_PDSUBHS_D)
DECLARE_INSN(pwhadd_b, MATCH_PWHADD_B, MASK_PWHADD_B)
DECLARE_INSN(pwhadd_h, MATCH_PWHADD_H, MASK_PWHADD_H)
DECLARE_INSN(pdhadd_b, MATCH_PDHADD_B, MASK_PDHADD_B)
DECLARE_INSN(pdhadd_h, MATCH_PDHADD_H, MASK_PDHADD_H)
DECLARE_INSN(pdhadd_w, MATCH_PDHADD_W, MASK_PDHADD_W)
DECLARE_INSN(pwhsub_b, MATCH_PWHSUB_B, MASK_PWHSUB_B)
DECLARE_INSN(pwhsub_h, MATCH_PWHSUB_H, MASK_PWHSUB_H)
DECLARE_INSN(pdhsub_b, MATCH_PDHSUB_B, MASK_PDHSUB_B)
DECLARE_INSN(pdhsub_h, MATCH_PDHSUB_H, MASK_PDHSUB_H)
DECLARE_INSN(pdhsub_w, MATCH_PDHSUB_W, MASK_PDHSUB_W)
DECLARE_INSN(pwslt_b, MATCH_PWSLT_B, MASK_PWSLT_B)
DECLARE_INSN(pwslt_h, MATCH_PWSLT_H, MASK_PWSLT_H)
DECLARE_INSN(pwslt_w, MATCH_PWSLT_W, MASK_PWSLT_W)
DECLARE_INSN(pdslt_b, MATCH_PDSLT_B, MASK_PDSLT_B)
DECLARE_INSN(pdslt_h, MATCH_PDSLT_H, MASK_PDSLT_H)
DECLARE_INSN(pdslt_w, MATCH_PDSLT_W, MASK_PDSLT_W)
DECLARE_INSN(pdslt_d, MATCH_PDSLT_D, MASK_PDSLT_D)
DECLARE_INSN(pwsltm_b, MATCH_PWSLTM_B, MASK_PWSLTM_B)
DECLARE_INSN(pwsltm_h, MATCH_PWSLTM_H, MASK_PWSLTM_H)
DECLARE_INSN(pwsltm_w, MATCH_PWSLTM_W, MASK_PWSLTM_W)
DECLARE_INSN(pdsltm_b, MATCH_PDSLTM_B, MASK_PDSLTM_B)
DECLARE_INSN(pdsltm_h, MATCH_PDSLTM_H, MASK_PDSLTM_H)
DECLARE_INSN(pdsltm_w, MATCH_PDSLTM_W, MASK_PDSLTM_W)
DECLARE_INSN(pdsltm_d, MATCH_PDSLTM_D, MASK_PDSLTM_D)
DECLARE_INSN(pwsltu_b, MATCH_PWSLTU_B, MASK_PWSLTU_B)
DECLARE_INSN(pwsltu_h, MATCH_PWSLTU_H, MASK_PWSLTU_H)
DECLARE_INSN(pwsltu_w, MATCH_PWSLTU_W, MASK_PWSLTU_W)
DECLARE_INSN(pdsltu_b, MATCH_PDSLTU_B, MASK_PDSLTU_B)
DECLARE_INSN(pdsltu_h, MATCH_PDSLTU_H, MASK_PDSLTU_H)
DECLARE_INSN(pdsltu_w, MATCH_PDSLTU_W, MASK_PDSLTU_W)
DECLARE_INSN(pdsltu_d, MATCH_PDSLTU_D, MASK_PDSLTU_D)
DECLARE_INSN(pwsltum_b, MATCH_PWSLTUM_B, MASK_PWSLTUM_B)
DECLARE_INSN(pwsltum_h, MATCH_PWSLTUM_H, MASK_PWSLTUM_H)
DECLARE_INSN(pwsltum_w, MATCH_PWSLTUM_W, MASK_PWSLTUM_W)
DECLARE_INSN(pdsltum_b, MATCH_PDSLTUM_B, MASK_PDSLTUM_B)
DECLARE_INSN(pdsltum_h, MATCH_PDSLTUM_H, MASK_PDSLTUM_H)
DECLARE_INSN(pdsltum_w, MATCH_PDSLTUM_W, MASK_PDSLTUM_W)
DECLARE_INSN(pdsltum_d, MATCH_PDSLTUM_D, MASK_PDSLTUM_D)
DECLARE_INSN(pwmin_b, MATCH_PWMIN_B, MASK_PWMIN_B)
DECLARE_INSN(pwmin_h, MATCH_PWMIN_H, MASK_PWMIN_H)
DECLARE_INSN(pwmin_w, MATCH_PWMIN_W, MASK_PWMIN_W)
DECLARE_INSN(pdmin_b, MATCH_PDMIN_B, MASK_PDMIN_B)
DECLARE_INSN(pdmin_h, MATCH_PDMIN_H, MASK_PDMIN_H)
DECLARE_INSN(pdmin_w, MATCH_PDMIN_W, MASK_PDMIN_W)
DECLARE_INSN(pdmin_d, MATCH_PDMIN_D, MASK_PDMIN_D)
DECLARE_INSN(pwminu_b, MATCH_PWMINU_B, MASK_PWMINU_B)
DECLARE_INSN(pwminu_h, MATCH_PWMINU_H, MASK_PWMINU_H)
DECLARE_INSN(pwminu_w, MATCH_PWMINU_W, MASK_PWMINU_W)
DECLARE_INSN(pdminu_b, MATCH_PDMINU_B, MASK_PDMINU_B)
DECLARE_INSN(pdminu_h, MATCH_PDMINU_H, MASK_PDMINU_H)
DECLARE_INSN(pdminu_w, MATCH_PDMINU_W, MASK_PDMINU_W)
DECLARE_INSN(pdminu_d, MATCH_PDMINU_D, MASK_PDMINU_D)
DECLARE_INSN(pwmax_b, MATCH_PWMAX_B, MASK_PWMAX_B)
DECLARE_INSN(pwmax_h, MATCH_PWMAX_H, MASK_PWMAX_H)
DECLARE_INSN(pwmax_w, MATCH_PWMAX_W, MASK_PWMAX_W)
DECLARE_INSN(pdmax_b, MATCH_PDMAX_B, MASK_PDMAX_B)
DECLARE_INSN(pdmax_h, MATCH_PDMAX_H, MASK_PDMAX_H)
DECLARE_INSN(pdmax_w, MATCH_PDMAX_W, MASK_PDMAX_W)
DECLARE_INSN(pdmax_d, MATCH_PDMAX_D, MASK_PDMAX_D)
DECLARE_INSN(pwmaxu_b, MATCH_PWMAXU_B, MASK_PWMAXU_B)
DECLARE_INSN(pwmaxu_h, MATCH_PWMAXU_H, MASK_PWMAXU_H)
DECLARE_INSN(pwmaxu_w, MATCH_PWMAXU_W, MASK_PWMAXU_W)
DECLARE_INSN(pdmaxu_b, MATCH_PDMAXU_B, MASK_PDMAXU_B)
DECLARE_INSN(pdmaxu_h, MATCH_PDMAXU_H, MASK_PDMAXU_H)
DECLARE_INSN(pdmaxu_w, MATCH_PDMAXU_W, MASK_PDMAXU_W)
DECLARE_INSN(pdmaxu_d, MATCH_PDMAXU_D, MASK_PDMAXU_D)
DECLARE_INSN(pwadd_b, MATCH_PWADD_B, MASK_PWADD_B)
DECLARE_INSN(pwadd_h, MATCH_PWADD_H, MASK_PWADD_H)
DECLARE_INSN(pwadd_w, MATCH_PWADD_W, MASK_PWADD_W)
DECLARE_INSN(pdadd_b, MATCH_PDADD_B, MASK_PDADD_B)
DECLARE_INSN(pdadd_h, MATCH_PDADD_H, MASK_PDADD_H)
DECLARE_INSN(pdadd_w, MATCH_PDADD_W, MASK_PDADD_W)
DECLARE_INSN(pdadd_d, MATCH_PDADD_D, MASK_PDADD_D)
DECLARE_INSN(pwavgu_b, MATCH_PWAVGU_B, MASK_PWAVGU_B)
DECLARE_INSN(pwavgu_h, MATCH_PWAVGU_H, MASK_PWAVGU_H)
DECLARE_INSN(pwavgu_w, MATCH_PWAVGU_W, MASK_PWAVGU_W)
DECLARE_INSN(pdavgu_b, MATCH_PDAVGU_B, MASK_PDAVGU_B)
DECLARE_INSN(pdavgu_h, MATCH_PDAVGU_H, MASK_PDAVGU_H)
DECLARE_INSN(pdavgu_w, MATCH_PDAVGU_W, MASK_PDAVGU_W)
DECLARE_INSN(pdavgu_d, MATCH_PDAVGU_D, MASK_PDAVGU_D)
DECLARE_INSN(pwaddss_b, MATCH_PWADDSS_B, MASK_PWADDSS_B)
DECLARE_INSN(pwaddss_h, MATCH_PWADDSS_H, MASK_PWADDSS_H)
DECLARE_INSN(pwaddss_w, MATCH_PWADDSS_W, MASK_PWADDSS_W)
DECLARE_INSN(pdaddss_b, MATCH_PDADDSS_B, MASK_PDADDSS_B)
DECLARE_INSN(pdaddss_h, MATCH_PDADDSS_H, MASK_PDADDSS_H)
DECLARE_INSN(pdaddss_w, MATCH_PDADDSS_W, MASK_PDADDSS_W)
DECLARE_INSN(pdaddss_d, MATCH_PDADDSS_D, MASK_PDADDSS_D)
DECLARE_INSN(pwaddus_b, MATCH_PWADDUS_B, MASK_PWADDUS_B)
DECLARE_INSN(pwaddus_h, MATCH_PWADDUS_H, MASK_PWADDUS_H)
DECLARE_INSN(pwaddus_w, MATCH_PWADDUS_W, MASK_PWADDUS_W)
DECLARE_INSN(pdaddus_b, MATCH_PDADDUS_B, MASK_PDADDUS_B)
DECLARE_INSN(pdaddus_h, MATCH_PDADDUS_H, MASK_PDADDUS_H)
DECLARE_INSN(pdaddus_w, MATCH_PDADDUS_W, MASK_PDADDUS_W)
DECLARE_INSN(pdaddus_d, MATCH_PDADDUS_D, MASK_PDADDUS_D)
DECLARE_INSN(pwavgs_b, MATCH_PWAVGS_B, MASK_PWAVGS_B)
DECLARE_INSN(pwavgs_h, MATCH_PWAVGS_H, MASK_PWAVGS_H)
DECLARE_INSN(pwavgs_w, MATCH_PWAVGS_W, MASK_PWAVGS_W)
DECLARE_INSN(pdavgs_b, MATCH_PDAVGS_B, MASK_PDAVGS_B)
DECLARE_INSN(pdavgs_h, MATCH_PDAVGS_H, MASK_PDAVGS_H)
DECLARE_INSN(pdavgs_w, MATCH_PDAVGS_W, MASK_PDAVGS_W)
DECLARE_INSN(pdavgs_d, MATCH_PDAVGS_D, MASK_PDAVGS_D)
DECLARE_INSN(pwsh1add_b, MATCH_PWSH1ADD_B, MASK_PWSH1ADD_B)
DECLARE_INSN(pwsh1add_h, MATCH_PWSH1ADD_H, MASK_PWSH1ADD_H)
DECLARE_INSN(pwsh1add_w, MATCH_PWSH1ADD_W, MASK_PWSH1ADD_W)
DECLARE_INSN(pdsh1add_b, MATCH_PDSH1ADD_B, MASK_PDSH1ADD_B)
DECLARE_INSN(pdsh1add_h, MATCH_PDSH1ADD_H, MASK_PDSH1ADD_H)
DECLARE_INSN(pdsh1add_w, MATCH_PDSH1ADD_W, MASK_PDSH1ADD_W)
DECLARE_INSN(pdsh1add_d, MATCH_PDSH1ADD_D, MASK_PDSH1ADD_D)
DECLARE_INSN(pwsh2add_b, MATCH_PWSH2ADD_B, MASK_PWSH2ADD_B)
DECLARE_INSN(pwsh2add_h, MATCH_PWSH2ADD_H, MASK_PWSH2ADD_H)
DECLARE_INSN(pwsh2add_w, MATCH_PWSH2ADD_W, MASK_PWSH2ADD_W)
DECLARE_INSN(pdsh2add_b, MATCH_PDSH2ADD_B, MASK_PDSH2ADD_B)
DECLARE_INSN(pdsh2add_h, MATCH_PDSH2ADD_H, MASK_PDSH2ADD_H)
DECLARE_INSN(pdsh2add_w, MATCH_PDSH2ADD_W, MASK_PDSH2ADD_W)
DECLARE_INSN(pdsh2add_d, MATCH_PDSH2ADD_D, MASK_PDSH2ADD_D)
DECLARE_INSN(pwsh3add_b, MATCH_PWSH3ADD_B, MASK_PWSH3ADD_B)
DECLARE_INSN(pwsh3add_h, MATCH_PWSH3ADD_H, MASK_PWSH3ADD_H)
DECLARE_INSN(pwsh3add_w, MATCH_PWSH3ADD_W, MASK_PWSH3ADD_W)
DECLARE_INSN(pdsh3add_b, MATCH_PDSH3ADD_B, MASK_PDSH3ADD_B)
DECLARE_INSN(pdsh3add_h, MATCH_PDSH3ADD_H, MASK_PDSH3ADD_H)
DECLARE_INSN(pdsh3add_w, MATCH_PDSH3ADD_W, MASK_PDSH3ADD_W)
DECLARE_INSN(pdsh3add_d, MATCH_PDSH3ADD_D, MASK_PDSH3ADD_D)
DECLARE_INSN(pwand, MATCH_PWAND, MASK_PWAND)
DECLARE_INSN(pdand, MATCH_PDAND, MASK_PDAND)
DECLARE_INSN(pwor, MATCH_PWOR, MASK_PWOR)
DECLARE_INSN(pdor, MATCH_PDOR, MASK_PDOR)
DECLARE_INSN(pwxor, MATCH_PWXOR, MASK_PWXOR)
DECLARE_INSN(pdxor, MATCH_PDXOR, MASK_PDXOR)
DECLARE_INSN(pwandn, MATCH_PWANDN, MASK_PWANDN)
DECLARE_INSN(pdandn, MATCH_PDANDN, MASK_PDANDN)
DECLARE_INSN(pworn, MATCH_PWORN, MASK_PWORN)
DECLARE_INSN(pdorn, MATCH_PDORN, MASK_PDORN)
DECLARE_INSN(pwxnor, MATCH_PWXNOR, MASK_PWXNOR)
DECLARE_INSN(pdxnor, MATCH_PDXNOR, MASK_PDXNOR)
DECLARE_INSN(pwsll_b, MATCH_PWSLL_B, MASK_PWSLL_B)
DECLARE_INSN(pwsll_h, MATCH_PWSLL_H, MASK_PWSLL_H)
DECLARE_INSN(pwsll_w, MATCH_PWSLL_W, MASK_PWSLL_W)
DECLARE_INSN(pdsll_b, MATCH_PDSLL_B, MASK_PDSLL_B)
DECLARE_INSN(pdsll_h, MATCH_PDSLL_H, MASK_PDSLL_H)
DECLARE_INSN(pdsll_w, MATCH_PDSLL_W, MASK_PDSLL_W)
DECLARE_INSN(pdsll_d, MATCH_PDSLL_D, MASK_PDSLL_D)
DECLARE_INSN(pwsrl_b, MATCH_PWSRL_B, MASK_PWSRL_B)
DECLARE_INSN(pwsrl_h, MATCH_PWSRL_H, MASK_PWSRL_H)
DECLARE_INSN(pwsrl_w, MATCH_PWSRL_W, MASK_PWSRL_W)
DECLARE_INSN(pdsrl_b, MATCH_PDSRL_B, MASK_PDSRL_B)
DECLARE_INSN(pdsrl_h, MATCH_PDSRL_H, MASK_PDSRL_H)
DECLARE_INSN(pdsrl_w, MATCH_PDSRL_W, MASK_PDSRL_W)
DECLARE_INSN(pdsrl_d, MATCH_PDSRL_D, MASK_PDSRL_D)
DECLARE_INSN(pwslo_b, MATCH_PWSLO_B, MASK_PWSLO_B)
DECLARE_INSN(pwslo_h, MATCH_PWSLO_H, MASK_PWSLO_H)
DECLARE_INSN(pwslo_w, MATCH_PWSLO_W, MASK_PWSLO_W)
DECLARE_INSN(pdslo_b, MATCH_PDSLO_B, MASK_PDSLO_B)
DECLARE_INSN(pdslo_h, MATCH_PDSLO_H, MASK_PDSLO_H)
DECLARE_INSN(pdslo_w, MATCH_PDSLO_W, MASK_PDSLO_W)
DECLARE_INSN(pdslo_d, MATCH_PDSLO_D, MASK_PDSLO_D)
DECLARE_INSN(pwsro_b, MATCH_PWSRO_B, MASK_PWSRO_B)
DECLARE_INSN(pwsro_h, MATCH_PWSRO_H, MASK_PWSRO_H)
DECLARE_INSN(pwsro_w, MATCH_PWSRO_W, MASK_PWSRO_W)
DECLARE_INSN(pdsro_b, MATCH_PDSRO_B, MASK_PDSRO_B)
DECLARE_INSN(pdsro_h, MATCH_PDSRO_H, MASK_PDSRO_H)
DECLARE_INSN(pdsro_w, MATCH_PDSRO_W, MASK_PDSRO_W)
DECLARE_INSN(pdsro_d, MATCH_PDSRO_D, MASK_PDSRO_D)
DECLARE_INSN(pwsra_b, MATCH_PWSRA_B, MASK_PWSRA_B)
DECLARE_INSN(pwsra_h, MATCH_PWSRA_H, MASK_PWSRA_H)
DECLARE_INSN(pwsra_w, MATCH_PWSRA_W, MASK_PWSRA_W)
DECLARE_INSN(pdsra_b, MATCH_PDSRA_B, MASK_PDSRA_B)
DECLARE_INSN(pdsra_h, MATCH_PDSRA_H, MASK_PDSRA_H)
DECLARE_INSN(pdsra_w, MATCH_PDSRA_W, MASK_PDSRA_W)
DECLARE_INSN(pdsra_d, MATCH_PDSRA_D, MASK_PDSRA_D)
DECLARE_INSN(pwrol_b, MATCH_PWROL_B, MASK_PWROL_B)
DECLARE_INSN(pwrol_h, MATCH_PWROL_H, MASK_PWROL_H)
DECLARE_INSN(pwrol_w, MATCH_PWROL_W, MASK_PWROL_W)
DECLARE_INSN(pdrol_b, MATCH_PDROL_B, MASK_PDROL_B)
DECLARE_INSN(pdrol_h, MATCH_PDROL_H, MASK_PDROL_H)
DECLARE_INSN(pdrol_w, MATCH_PDROL_W, MASK_PDROL_W)
DECLARE_INSN(pdrol_d, MATCH_PDROL_D, MASK_PDROL_D)
DECLARE_INSN(pwror_b, MATCH_PWROR_B, MASK_PWROR_B)
DECLARE_INSN(pwror_h, MATCH_PWROR_H, MASK_PWROR_H)
DECLARE_INSN(pwror_w, MATCH_PWROR_W, MASK_PWROR_W)
DECLARE_INSN(pdror_b, MATCH_PDROR_B, MASK_PDROR_B)
DECLARE_INSN(pdror_h, MATCH_PDROR_H, MASK_PDROR_H)
DECLARE_INSN(pdror_w, MATCH_PDROR_W, MASK_PDROR_W)
DECLARE_INSN(pdror_d, MATCH_PDROR_D, MASK_PDROR_D)
DECLARE_INSN(pwmulssb_b, MATCH_PWMULSSB_B, MASK_PWMULSSB_B)
DECLARE_INSN(pwmulssb_h, MATCH_PWMULSSB_H, MASK_PWMULSSB_H)
DECLARE_INSN(pwmulssb_w, MATCH_PWMULSSB_W, MASK_PWMULSSB_W)
DECLARE_INSN(pdmulssb_b, MATCH_PDMULSSB_B, MASK_PDMULSSB_B)
DECLARE_INSN(pdmulssb_h, MATCH_PDMULSSB_H, MASK_PDMULSSB_H)
DECLARE_INSN(pdmulssb_w, MATCH_PDMULSSB_W, MASK_PDMULSSB_W)
DECLARE_INSN(pwmulsub_b, MATCH_PWMULSUB_B, MASK_PWMULSUB_B)
DECLARE_INSN(pwmulsub_h, MATCH_PWMULSUB_H, MASK_PWMULSUB_H)
DECLARE_INSN(pwmulsub_w, MATCH_PWMULSUB_W, MASK_PWMULSUB_W)
DECLARE_INSN(pdmulsub_b, MATCH_PDMULSUB_B, MASK_PDMULSUB_B)
DECLARE_INSN(pdmulsub_h, MATCH_PDMULSUB_H, MASK_PDMULSUB_H)
DECLARE_INSN(pdmulsub_w, MATCH_PDMULSUB_W, MASK_PDMULSUB_W)
DECLARE_INSN(pwmuluub_b, MATCH_PWMULUUB_B, MASK_PWMULUUB_B)
DECLARE_INSN(pwmuluub_h, MATCH_PWMULUUB_H, MASK_PWMULUUB_H)
DECLARE_INSN(pwmuluub_w, MATCH_PWMULUUB_W, MASK_PWMULUUB_W)
DECLARE_INSN(pdmuluub_b, MATCH_PDMULUUB_B, MASK_PDMULUUB_B)
DECLARE_INSN(pdmuluub_h, MATCH_PDMULUUB_H, MASK_PDMULUUB_H)
DECLARE_INSN(pdmuluub_w, MATCH_PDMULUUB_W, MASK_PDMULUUB_W)
DECLARE_INSN(pwmulccb_b, MATCH_PWMULCCB_B, MASK_PWMULCCB_B)
DECLARE_INSN(pwmulccb_h, MATCH_PWMULCCB_H, MASK_PWMULCCB_H)
DECLARE_INSN(pdmulccb_b, MATCH_PDMULCCB_B, MASK_PDMULCCB_B)
DECLARE_INSN(pdmulccb_h, MATCH_PDMULCCB_H, MASK_PDMULCCB_H)
DECLARE_INSN(pdmulccb_w, MATCH_PDMULCCB_W, MASK_PDMULCCB_W)
DECLARE_INSN(pwmulssbqu_b, MATCH_PWMULSSBQU_B, MASK_PWMULSSBQU_B)
DECLARE_INSN(pwmulssbqu_h, MATCH_PWMULSSBQU_H, MASK_PWMULSSBQU_H)
DECLARE_INSN(pwmulssbqu_w, MATCH_PWMULSSBQU_W, MASK_PWMULSSBQU_W)
DECLARE_INSN(pdmulssbqu_b, MATCH_PDMULSSBQU_B, MASK_PDMULSSBQU_B)
DECLARE_INSN(pdmulssbqu_h, MATCH_PDMULSSBQU_H, MASK_PDMULSSBQU_H)
DECLARE_INSN(pdmulssbqu_w, MATCH_PDMULSSBQU_W, MASK_PDMULSSBQU_W)
DECLARE_INSN(pwmulsubqu_b, MATCH_PWMULSUBQU_B, MASK_PWMULSUBQU_B)
DECLARE_INSN(pwmulsubqu_h, MATCH_PWMULSUBQU_H, MASK_PWMULSUBQU_H)
DECLARE_INSN(pwmulsubqu_w, MATCH_PWMULSUBQU_W, MASK_PWMULSUBQU_W)
DECLARE_INSN(pdmulsubqu_b, MATCH_PDMULSUBQU_B, MASK_PDMULSUBQU_B)
DECLARE_INSN(pdmulsubqu_h, MATCH_PDMULSUBQU_H, MASK_PDMULSUBQU_H)
DECLARE_INSN(pdmulsubqu_w, MATCH_PDMULSUBQU_W, MASK_PDMULSUBQU_W)
DECLARE_INSN(pwmuluubqu_b, MATCH_PWMULUUBQU_B, MASK_PWMULUUBQU_B)
DECLARE_INSN(pwmuluubqu_h, MATCH_PWMULUUBQU_H, MASK_PWMULUUBQU_H)
DECLARE_INSN(pwmuluubqu_w, MATCH_PWMULUUBQU_W, MASK_PWMULUUBQU_W)
DECLARE_INSN(pdmuluubqu_b, MATCH_PDMULUUBQU_B, MASK_PDMULUUBQU_B)
DECLARE_INSN(pdmuluubqu_h, MATCH_PDMULUUBQU_H, MASK_PDMULUUBQU_H)
DECLARE_INSN(pdmuluubqu_w, MATCH_PDMULUUBQU_W, MASK_PDMULUUBQU_W)
DECLARE_INSN(pwmulssbqs_b, MATCH_PWMULSSBQS_B, MASK_PWMULSSBQS_B)
DECLARE_INSN(pwmulssbqs_h, MATCH_PWMULSSBQS_H, MASK_PWMULSSBQS_H)
DECLARE_INSN(pwmulssbqs_w, MATCH_PWMULSSBQS_W, MASK_PWMULSSBQS_W)
DECLARE_INSN(pdmulssbqs_b, MATCH_PDMULSSBQS_B, MASK_PDMULSSBQS_B)
DECLARE_INSN(pdmulssbqs_h, MATCH_PDMULSSBQS_H, MASK_PDMULSSBQS_H)
DECLARE_INSN(pdmulssbqs_w, MATCH_PDMULSSBQS_W, MASK_PDMULSSBQS_W)
DECLARE_INSN(pwmulsubqs_b, MATCH_PWMULSUBQS_B, MASK_PWMULSUBQS_B)
DECLARE_INSN(pwmulsubqs_h, MATCH_PWMULSUBQS_H, MASK_PWMULSUBQS_H)
DECLARE_INSN(pwmulsubqs_w, MATCH_PWMULSUBQS_W, MASK_PWMULSUBQS_W)
DECLARE_INSN(pdmulsubqs_b, MATCH_PDMULSUBQS_B, MASK_PDMULSUBQS_B)
DECLARE_INSN(pdmulsubqs_h, MATCH_PDMULSUBQS_H, MASK_PDMULSUBQS_H)
DECLARE_INSN(pdmulsubqs_w, MATCH_PDMULSUBQS_W, MASK_PDMULSUBQS_W)
DECLARE_INSN(pwmuluubqs_b, MATCH_PWMULUUBQS_B, MASK_PWMULUUBQS_B)
DECLARE_INSN(pwmuluubqs_h, MATCH_PWMULUUBQS_H, MASK_PWMULUUBQS_H)
DECLARE_INSN(pwmuluubqs_w, MATCH_PWMULUUBQS_W, MASK_PWMULUUBQS_W)
DECLARE_INSN(pdmuluubqs_b, MATCH_PDMULUUBQS_B, MASK_PDMULUUBQS_B)
DECLARE_INSN(pdmuluubqs_h, MATCH_PDMULUUBQS_H, MASK_PDMULUUBQS_H)
DECLARE_INSN(pdmuluubqs_w, MATCH_PDMULUUBQS_W, MASK_PDMULUUBQS_W)
DECLARE_INSN(pwmulccbq_b, MATCH_PWMULCCBQ_B, MASK_PWMULCCBQ_B)
DECLARE_INSN(pwmulccbq_h, MATCH_PWMULCCBQ_H, MASK_PWMULCCBQ_H)
DECLARE_INSN(pdmulccbq_b, MATCH_PDMULCCBQ_B, MASK_PDMULCCBQ_B)
DECLARE_INSN(pdmulccbq_h, MATCH_PDMULCCBQ_H, MASK_PDMULCCBQ_H)
DECLARE_INSN(pdmulccbq_w, MATCH_PDMULCCBQ_W, MASK_PDMULCCBQ_W)
DECLARE_INSN(pwmulsst_b, MATCH_PWMULSST_B, MASK_PWMULSST_B)
DECLARE_INSN(pwmulsst_h, MATCH_PWMULSST_H, MASK_PWMULSST_H)
DECLARE_INSN(pwmulsst_w, MATCH_PWMULSST_W, MASK_PWMULSST_W)
DECLARE_INSN(pdmulsst_b, MATCH_PDMULSST_B, MASK_PDMULSST_B)
DECLARE_INSN(pdmulsst_h, MATCH_PDMULSST_H, MASK_PDMULSST_H)
DECLARE_INSN(pdmulsst_w, MATCH_PDMULSST_W, MASK_PDMULSST_W)
DECLARE_INSN(pwmulsut_b, MATCH_PWMULSUT_B, MASK_PWMULSUT_B)
DECLARE_INSN(pwmulsut_h, MATCH_PWMULSUT_H, MASK_PWMULSUT_H)
DECLARE_INSN(pwmulsut_w, MATCH_PWMULSUT_W, MASK_PWMULSUT_W)
DECLARE_INSN(pdmulsut_b, MATCH_PDMULSUT_B, MASK_PDMULSUT_B)
DECLARE_INSN(pdmulsut_h, MATCH_PDMULSUT_H, MASK_PDMULSUT_H)
DECLARE_INSN(pdmulsut_w, MATCH_PDMULSUT_W, MASK_PDMULSUT_W)
DECLARE_INSN(pwmuluut_b, MATCH_PWMULUUT_B, MASK_PWMULUUT_B)
DECLARE_INSN(pwmuluut_h, MATCH_PWMULUUT_H, MASK_PWMULUUT_H)
DECLARE_INSN(pwmuluut_w, MATCH_PWMULUUT_W, MASK_PWMULUUT_W)
DECLARE_INSN(pdmuluut_b, MATCH_PDMULUUT_B, MASK_PDMULUUT_B)
DECLARE_INSN(pdmuluut_h, MATCH_PDMULUUT_H, MASK_PDMULUUT_H)
DECLARE_INSN(pdmuluut_w, MATCH_PDMULUUT_W, MASK_PDMULUUT_W)
DECLARE_INSN(pwmulcct_b, MATCH_PWMULCCT_B, MASK_PWMULCCT_B)
DECLARE_INSN(pwmulcct_h, MATCH_PWMULCCT_H, MASK_PWMULCCT_H)
DECLARE_INSN(pdmulcct_b, MATCH_PDMULCCT_B, MASK_PDMULCCT_B)
DECLARE_INSN(pdmulcct_h, MATCH_PDMULCCT_H, MASK_PDMULCCT_H)
DECLARE_INSN(pdmulcct_w, MATCH_PDMULCCT_W, MASK_PDMULCCT_W)
DECLARE_INSN(pwmulssw_b, MATCH_PWMULSSW_B, MASK_PWMULSSW_B)
DECLARE_INSN(pwmulssw_h, MATCH_PWMULSSW_H, MASK_PWMULSSW_H)
DECLARE_INSN(pwmulssw_w, MATCH_PWMULSSW_W, MASK_PWMULSSW_W)
DECLARE_INSN(pwmulsuw_b, MATCH_PWMULSUW_B, MASK_PWMULSUW_B)
DECLARE_INSN(pwmulsuw_h, MATCH_PWMULSUW_H, MASK_PWMULSUW_H)
DECLARE_INSN(pwmulsuw_w, MATCH_PWMULSUW_W, MASK_PWMULSUW_W)
DECLARE_INSN(pwmuluuw_b, MATCH_PWMULUUW_B, MASK_PWMULUUW_B)
DECLARE_INSN(pwmuluuw_h, MATCH_PWMULUUW_H, MASK_PWMULUUW_H)
DECLARE_INSN(pwmuluuw_w, MATCH_PWMULUUW_W, MASK_PWMULUUW_W)
DECLARE_INSN(pwmulccw_b, MATCH_PWMULCCW_B, MASK_PWMULCCW_B)
DECLARE_INSN(pwmulccw_h, MATCH_PWMULCCW_H, MASK_PWMULCCW_H)
DECLARE_INSN(pwmulcrw_b, MATCH_PWMULCRW_B, MASK_PWMULCRW_B)
DECLARE_INSN(pwmulcrw_h, MATCH_PWMULCRW_H, MASK_PWMULCRW_H)
DECLARE_INSN(pwmulcrbq_b, MATCH_PWMULCRBQ_B, MASK_PWMULCRBQ_B)
DECLARE_INSN(pwmulcrbq_h, MATCH_PWMULCRBQ_H, MASK_PWMULCRBQ_H)
DECLARE_INSN(pdmulcrbq_b, MATCH_PDMULCRBQ_B, MASK_PDMULCRBQ_B)
DECLARE_INSN(pdmulcrbq_h, MATCH_PDMULCRBQ_H, MASK_PDMULCRBQ_H)
DECLARE_INSN(pdmulcrbq_w, MATCH_PDMULCRBQ_W, MASK_PDMULCRBQ_W)
DECLARE_INSN(pwmulcrb_b, MATCH_PWMULCRB_B, MASK_PWMULCRB_B)
DECLARE_INSN(pwmulcrb_h, MATCH_PWMULCRB_H, MASK_PWMULCRB_H)
DECLARE_INSN(pdmulcrb_b, MATCH_PDMULCRB_B, MASK_PDMULCRB_B)
DECLARE_INSN(pdmulcrb_h, MATCH_PDMULCRB_H, MASK_PDMULCRB_H)
DECLARE_INSN(pdmulcrb_w, MATCH_PDMULCRB_W, MASK_PDMULCRB_W)
DECLARE_INSN(pwmulcrt_b, MATCH_PWMULCRT_B, MASK_PWMULCRT_B)
DECLARE_INSN(pwmulcrt_h, MATCH_PWMULCRT_H, MASK_PWMULCRT_H)
DECLARE_INSN(pdmulcrt_b, MATCH_PDMULCRT_B, MASK_PDMULCRT_B)
DECLARE_INSN(pdmulcrt_h, MATCH_PDMULCRT_H, MASK_PDMULCRT_H)
DECLARE_INSN(pdmulcrt_w, MATCH_PDMULCRT_W, MASK_PDMULCRT_W)
DECLARE_INSN(crot_h, MATCH_CROT_H, MASK_CROT_H)
DECLARE_INSN(crot_w, MATCH_CROT_W, MASK_CROT_W)
DECLARE_INSN(cmagarg_h, MATCH_CMAGARG_H, MASK_CMAGARG_H)
DECLARE_INSN(cmagarg_w, MATCH_CMAGARG_W, MASK_CMAGARG_W)
DECLARE_INSN(chrot_h, MATCH_CHROT_H, MASK_CHROT_H)
DECLARE_INSN(chrot_w, MATCH_CHROT_W, MASK_CHROT_W)
DECLARE_INSN(chmagarg_h, MATCH_CHMAGARG_H, MASK_CHMAGARG_H)
DECLARE_INSN(chmagarg_w, MATCH_CHMAGARG_W, MASK_CHMAGARG_W)
DECLARE_INSN(pwzmaccs_b, MATCH_PWZMACCS_B, MASK_PWZMACCS_B)
DECLARE_INSN(pwzmaccs_h, MATCH_PWZMACCS_H, MASK_PWZMACCS_H)
DECLARE_INSN(pwzmaccs_w, MATCH_PWZMACCS_W, MASK_PWZMACCS_W)
DECLARE_INSN(pdzmaccs_b, MATCH_PDZMACCS_B, MASK_PDZMACCS_B)
DECLARE_INSN(pdzmaccs_h, MATCH_PDZMACCS_H, MASK_PDZMACCS_H)
DECLARE_INSN(pdzmaccs_w, MATCH_PDZMACCS_W, MASK_PDZMACCS_W)
DECLARE_INSN(pwzmaccqs_b, MATCH_PWZMACCQS_B, MASK_PWZMACCQS_B)
DECLARE_INSN(pwzmaccqs_h, MATCH_PWZMACCQS_H, MASK_PWZMACCQS_H)
DECLARE_INSN(pwzmaccqs_w, MATCH_PWZMACCQS_W, MASK_PWZMACCQS_W)
DECLARE_INSN(pdzmaccqs_b, MATCH_PDZMACCQS_B, MASK_PDZMACCQS_B)
DECLARE_INSN(pdzmaccqs_h, MATCH_PDZMACCQS_H, MASK_PDZMACCQS_H)
DECLARE_INSN(pdzmaccqs_w, MATCH_PDZMACCQS_W, MASK_PDZMACCQS_W)
DECLARE_INSN(pwzmaccu_b, MATCH_PWZMACCU_B, MASK_PWZMACCU_B)
DECLARE_INSN(pwzmaccu_h, MATCH_PWZMACCU_H, MASK_PWZMACCU_H)
DECLARE_INSN(pwzmaccu_w, MATCH_PWZMACCU_W, MASK_PWZMACCU_W)
DECLARE_INSN(pdzmaccu_b, MATCH_PDZMACCU_B, MASK_PDZMACCU_B)
DECLARE_INSN(pdzmaccu_h, MATCH_PDZMACCU_H, MASK_PDZMACCU_H)
DECLARE_INSN(pdzmaccu_w, MATCH_PDZMACCU_W, MASK_PDZMACCU_W)
DECLARE_INSN(pwzmaccqu_b, MATCH_PWZMACCQU_B, MASK_PWZMACCQU_B)
DECLARE_INSN(pwzmaccqu_h, MATCH_PWZMACCQU_H, MASK_PWZMACCQU_H)
DECLARE_INSN(pwzmaccqu_w, MATCH_PWZMACCQU_W, MASK_PWZMACCQU_W)
DECLARE_INSN(pdzmaccqu_b, MATCH_PDZMACCQU_B, MASK_PDZMACCQU_B)
DECLARE_INSN(pdzmaccqu_h, MATCH_PDZMACCQU_H, MASK_PDZMACCQU_H)
DECLARE_INSN(pdzmaccqu_w, MATCH_PDZMACCQU_W, MASK_PDZMACCQU_W)
DECLARE_INSN(pwzmacccc_b, MATCH_PWZMACCCC_B, MASK_PWZMACCCC_B)
DECLARE_INSN(pwzmacccc_h, MATCH_PWZMACCCC_H, MASK_PWZMACCCC_H)
DECLARE_INSN(pdzmacccc_b, MATCH_PDZMACCCC_B, MASK_PDZMACCCC_B)
DECLARE_INSN(pdzmacccc_h, MATCH_PDZMACCCC_H, MASK_PDZMACCCC_H)
DECLARE_INSN(pwzmaccccq_b, MATCH_PWZMACCCCQ_B, MASK_PWZMACCCCQ_B)
DECLARE_INSN(pwzmaccccq_h, MATCH_PWZMACCCCQ_H, MASK_PWZMACCCCQ_H)
DECLARE_INSN(pdzmaccccq_b, MATCH_PDZMACCCCQ_B, MASK_PDZMACCCCQ_B)
DECLARE_INSN(pdzmaccccq_h, MATCH_PDZMACCCCQ_H, MASK_PDZMACCCCQ_H)
DECLARE_INSN(pwzmacccr_b, MATCH_PWZMACCCR_B, MASK_PWZMACCCR_B)
DECLARE_INSN(pwzmacccr_h, MATCH_PWZMACCCR_H, MASK_PWZMACCCR_H)
DECLARE_INSN(pdzmacccr_b, MATCH_PDZMACCCR_B, MASK_PDZMACCCR_B)
DECLARE_INSN(pdzmacccr_h, MATCH_PDZMACCCR_H, MASK_PDZMACCCR_H)
DECLARE_INSN(pwzmacccrq_b, MATCH_PWZMACCCRQ_B, MASK_PWZMACCCRQ_B)
DECLARE_INSN(pwzmacccrq_h, MATCH_PWZMACCCRQ_H, MASK_PWZMACCCRQ_H)
DECLARE_INSN(pdzmacccrq_b, MATCH_PDZMACCCRQ_B, MASK_PDZMACCCRQ_B)
DECLARE_INSN(pdzmacccrq_h, MATCH_PDZMACCCRQ_H, MASK_PDZMACCCRQ_H)
DECLARE_INSN(pwzmsubs_b, MATCH_PWZMSUBS_B, MASK_PWZMSUBS_B)
DECLARE_INSN(pwzmsubs_h, MATCH_PWZMSUBS_H, MASK_PWZMSUBS_H)
DECLARE_INSN(pwzmsubs_w, MATCH_PWZMSUBS_W, MASK_PWZMSUBS_W)
DECLARE_INSN(pdzmsubs_b, MATCH_PDZMSUBS_B, MASK_PDZMSUBS_B)
DECLARE_INSN(pdzmsubs_h, MATCH_PDZMSUBS_H, MASK_PDZMSUBS_H)
DECLARE_INSN(pdzmsubs_w, MATCH_PDZMSUBS_W, MASK_PDZMSUBS_W)
DECLARE_INSN(pwzmsubqs_b, MATCH_PWZMSUBQS_B, MASK_PWZMSUBQS_B)
DECLARE_INSN(pwzmsubqs_h, MATCH_PWZMSUBQS_H, MASK_PWZMSUBQS_H)
DECLARE_INSN(pwzmsubqs_w, MATCH_PWZMSUBQS_W, MASK_PWZMSUBQS_W)
DECLARE_INSN(pdzmsubqs_b, MATCH_PDZMSUBQS_B, MASK_PDZMSUBQS_B)
DECLARE_INSN(pdzmsubqs_h, MATCH_PDZMSUBQS_H, MASK_PDZMSUBQS_H)
DECLARE_INSN(pdzmsubqs_w, MATCH_PDZMSUBQS_W, MASK_PDZMSUBQS_W)
DECLARE_INSN(pwzmsubu_b, MATCH_PWZMSUBU_B, MASK_PWZMSUBU_B)
DECLARE_INSN(pwzmsubu_h, MATCH_PWZMSUBU_H, MASK_PWZMSUBU_H)
DECLARE_INSN(pwzmsubu_w, MATCH_PWZMSUBU_W, MASK_PWZMSUBU_W)
DECLARE_INSN(pdzmsubu_b, MATCH_PDZMSUBU_B, MASK_PDZMSUBU_B)
DECLARE_INSN(pdzmsubu_h, MATCH_PDZMSUBU_H, MASK_PDZMSUBU_H)
DECLARE_INSN(pdzmsubu_w, MATCH_PDZMSUBU_W, MASK_PDZMSUBU_W)
DECLARE_INSN(pwzmsubqu_b, MATCH_PWZMSUBQU_B, MASK_PWZMSUBQU_B)
DECLARE_INSN(pwzmsubqu_h, MATCH_PWZMSUBQU_H, MASK_PWZMSUBQU_H)
DECLARE_INSN(pwzmsubqu_w, MATCH_PWZMSUBQU_W, MASK_PWZMSUBQU_W)
DECLARE_INSN(pdzmsubqu_b, MATCH_PDZMSUBQU_B, MASK_PDZMSUBQU_B)
DECLARE_INSN(pdzmsubqu_h, MATCH_PDZMSUBQU_H, MASK_PDZMSUBQU_H)
DECLARE_INSN(pdzmsubqu_w, MATCH_PDZMSUBQU_W, MASK_PDZMSUBQU_W)
DECLARE_INSN(pwzmsubcc_b, MATCH_PWZMSUBCC_B, MASK_PWZMSUBCC_B)
DECLARE_INSN(pwzmsubcc_h, MATCH_PWZMSUBCC_H, MASK_PWZMSUBCC_H)
DECLARE_INSN(pdzmsubcc_b, MATCH_PDZMSUBCC_B, MASK_PDZMSUBCC_B)
DECLARE_INSN(pdzmsubcc_h, MATCH_PDZMSUBCC_H, MASK_PDZMSUBCC_H)
DECLARE_INSN(pwzmsubccq_b, MATCH_PWZMSUBCCQ_B, MASK_PWZMSUBCCQ_B)
DECLARE_INSN(pwzmsubccq_h, MATCH_PWZMSUBCCQ_H, MASK_PWZMSUBCCQ_H)
DECLARE_INSN(pdzmsubccq_b, MATCH_PDZMSUBCCQ_B, MASK_PDZMSUBCCQ_B)
DECLARE_INSN(pdzmsubccq_h, MATCH_PDZMSUBCCQ_H, MASK_PDZMSUBCCQ_H)
DECLARE_INSN(pwzmsubcr_b, MATCH_PWZMSUBCR_B, MASK_PWZMSUBCR_B)
DECLARE_INSN(pwzmsubcr_h, MATCH_PWZMSUBCR_H, MASK_PWZMSUBCR_H)
DECLARE_INSN(pdzmsubcr_b, MATCH_PDZMSUBCR_B, MASK_PDZMSUBCR_B)
DECLARE_INSN(pdzmsubcr_h, MATCH_PDZMSUBCR_H, MASK_PDZMSUBCR_H)
DECLARE_INSN(pwzmsubcrq_b, MATCH_PWZMSUBCRQ_B, MASK_PWZMSUBCRQ_B)
DECLARE_INSN(pwzmsubcrq_h, MATCH_PWZMSUBCRQ_H, MASK_PWZMSUBCRQ_H)
DECLARE_INSN(pdzmsubcrq_b, MATCH_PDZMSUBCRQ_B, MASK_PDZMSUBCRQ_B)
DECLARE_INSN(pdzmsubcrq_h, MATCH_PDZMSUBCRQ_H, MASK_PDZMSUBCRQ_H)
DECLARE_INSN(pwmaccs_b, MATCH_PWMACCS_B, MASK_PWMACCS_B)
DECLARE_INSN(pwmaccs_h, MATCH_PWMACCS_H, MASK_PWMACCS_H)
DECLARE_INSN(pwmaccs_w, MATCH_PWMACCS_W, MASK_PWMACCS_W)
DECLARE_INSN(pdmaccs_b, MATCH_PDMACCS_B, MASK_PDMACCS_B)
DECLARE_INSN(pdmaccs_h, MATCH_PDMACCS_H, MASK_PDMACCS_H)
DECLARE_INSN(pdmaccs_w, MATCH_PDMACCS_W, MASK_PDMACCS_W)
DECLARE_INSN(pwmaccqs_b, MATCH_PWMACCQS_B, MASK_PWMACCQS_B)
DECLARE_INSN(pwmaccqs_h, MATCH_PWMACCQS_H, MASK_PWMACCQS_H)
DECLARE_INSN(pwmaccqs_w, MATCH_PWMACCQS_W, MASK_PWMACCQS_W)
DECLARE_INSN(pdmaccqs_b, MATCH_PDMACCQS_B, MASK_PDMACCQS_B)
DECLARE_INSN(pdmaccqs_h, MATCH_PDMACCQS_H, MASK_PDMACCQS_H)
DECLARE_INSN(pdmaccqs_w, MATCH_PDMACCQS_W, MASK_PDMACCQS_W)
DECLARE_INSN(pwmaccu_b, MATCH_PWMACCU_B, MASK_PWMACCU_B)
DECLARE_INSN(pwmaccu_h, MATCH_PWMACCU_H, MASK_PWMACCU_H)
DECLARE_INSN(pwmaccu_w, MATCH_PWMACCU_W, MASK_PWMACCU_W)
DECLARE_INSN(pdmaccu_b, MATCH_PDMACCU_B, MASK_PDMACCU_B)
DECLARE_INSN(pdmaccu_h, MATCH_PDMACCU_H, MASK_PDMACCU_H)
DECLARE_INSN(pdmaccu_w, MATCH_PDMACCU_W, MASK_PDMACCU_W)
DECLARE_INSN(pwmaccqu_b, MATCH_PWMACCQU_B, MASK_PWMACCQU_B)
DECLARE_INSN(pwmaccqu_h, MATCH_PWMACCQU_H, MASK_PWMACCQU_H)
DECLARE_INSN(pwmaccqu_w, MATCH_PWMACCQU_W, MASK_PWMACCQU_W)
DECLARE_INSN(pdmaccqu_b, MATCH_PDMACCQU_B, MASK_PDMACCQU_B)
DECLARE_INSN(pdmaccqu_h, MATCH_PDMACCQU_H, MASK_PDMACCQU_H)
DECLARE_INSN(pdmaccqu_w, MATCH_PDMACCQU_W, MASK_PDMACCQU_W)
DECLARE_INSN(pwmacccc_b, MATCH_PWMACCCC_B, MASK_PWMACCCC_B)
DECLARE_INSN(pwmacccc_h, MATCH_PWMACCCC_H, MASK_PWMACCCC_H)
DECLARE_INSN(pdmacccc_b, MATCH_PDMACCCC_B, MASK_PDMACCCC_B)
DECLARE_INSN(pdmacccc_h, MATCH_PDMACCCC_H, MASK_PDMACCCC_H)
DECLARE_INSN(pwmaccccq_b, MATCH_PWMACCCCQ_B, MASK_PWMACCCCQ_B)
DECLARE_INSN(pwmaccccq_h, MATCH_PWMACCCCQ_H, MASK_PWMACCCCQ_H)
DECLARE_INSN(pdmaccccq_b, MATCH_PDMACCCCQ_B, MASK_PDMACCCCQ_B)
DECLARE_INSN(pdmaccccq_h, MATCH_PDMACCCCQ_H, MASK_PDMACCCCQ_H)
DECLARE_INSN(pwmacccr_b, MATCH_PWMACCCR_B, MASK_PWMACCCR_B)
DECLARE_INSN(pwmacccr_h, MATCH_PWMACCCR_H, MASK_PWMACCCR_H)
DECLARE_INSN(pdmacccr_b, MATCH_PDMACCCR_B, MASK_PDMACCCR_B)
DECLARE_INSN(pdmacccr_h, MATCH_PDMACCCR_H, MASK_PDMACCCR_H)
DECLARE_INSN(pwmacccrq_b, MATCH_PWMACCCRQ_B, MASK_PWMACCCRQ_B)
DECLARE_INSN(pwmacccrq_h, MATCH_PWMACCCRQ_H, MASK_PWMACCCRQ_H)
DECLARE_INSN(pdmacccrq_b, MATCH_PDMACCCRQ_B, MASK_PDMACCCRQ_B)
DECLARE_INSN(pdmacccrq_h, MATCH_PDMACCCRQ_H, MASK_PDMACCCRQ_H)
DECLARE_INSN(pwmsubs_b, MATCH_PWMSUBS_B, MASK_PWMSUBS_B)
DECLARE_INSN(pwmsubs_h, MATCH_PWMSUBS_H, MASK_PWMSUBS_H)
DECLARE_INSN(pwmsubs_w, MATCH_PWMSUBS_W, MASK_PWMSUBS_W)
DECLARE_INSN(pdmsubs_b, MATCH_PDMSUBS_B, MASK_PDMSUBS_B)
DECLARE_INSN(pdmsubs_h, MATCH_PDMSUBS_H, MASK_PDMSUBS_H)
DECLARE_INSN(pdmsubs_w, MATCH_PDMSUBS_W, MASK_PDMSUBS_W)
DECLARE_INSN(pwmsubqs_b, MATCH_PWMSUBQS_B, MASK_PWMSUBQS_B)
DECLARE_INSN(pwmsubqs_h, MATCH_PWMSUBQS_H, MASK_PWMSUBQS_H)
DECLARE_INSN(pwmsubqs_w, MATCH_PWMSUBQS_W, MASK_PWMSUBQS_W)
DECLARE_INSN(pdmsubqs_b, MATCH_PDMSUBQS_B, MASK_PDMSUBQS_B)
DECLARE_INSN(pdmsubqs_h, MATCH_PDMSUBQS_H, MASK_PDMSUBQS_H)
DECLARE_INSN(pdmsubqs_w, MATCH_PDMSUBQS_W, MASK_PDMSUBQS_W)
DECLARE_INSN(pwmsubu_b, MATCH_PWMSUBU_B, MASK_PWMSUBU_B)
DECLARE_INSN(pwmsubu_h, MATCH_PWMSUBU_H, MASK_PWMSUBU_H)
DECLARE_INSN(pwmsubu_w, MATCH_PWMSUBU_W, MASK_PWMSUBU_W)
DECLARE_INSN(pdmsubu_b, MATCH_PDMSUBU_B, MASK_PDMSUBU_B)
DECLARE_INSN(pdmsubu_h, MATCH_PDMSUBU_H, MASK_PDMSUBU_H)
DECLARE_INSN(pdmsubu_w, MATCH_PDMSUBU_W, MASK_PDMSUBU_W)
DECLARE_INSN(pwmsubqu_b, MATCH_PWMSUBQU_B, MASK_PWMSUBQU_B)
DECLARE_INSN(pwmsubqu_h, MATCH_PWMSUBQU_H, MASK_PWMSUBQU_H)
DECLARE_INSN(pwmsubqu_w, MATCH_PWMSUBQU_W, MASK_PWMSUBQU_W)
DECLARE_INSN(pdmsubqu_b, MATCH_PDMSUBQU_B, MASK_PDMSUBQU_B)
DECLARE_INSN(pdmsubqu_h, MATCH_PDMSUBQU_H, MASK_PDMSUBQU_H)
DECLARE_INSN(pdmsubqu_w, MATCH_PDMSUBQU_W, MASK_PDMSUBQU_W)
DECLARE_INSN(pwmsubcc_b, MATCH_PWMSUBCC_B, MASK_PWMSUBCC_B)
DECLARE_INSN(pwmsubcc_h, MATCH_PWMSUBCC_H, MASK_PWMSUBCC_H)
DECLARE_INSN(pdmsubcc_b, MATCH_PDMSUBCC_B, MASK_PDMSUBCC_B)
DECLARE_INSN(pdmsubcc_h, MATCH_PDMSUBCC_H, MASK_PDMSUBCC_H)
DECLARE_INSN(pwmsubccq_b, MATCH_PWMSUBCCQ_B, MASK_PWMSUBCCQ_B)
DECLARE_INSN(pwmsubccq_h, MATCH_PWMSUBCCQ_H, MASK_PWMSUBCCQ_H)
DECLARE_INSN(pdmsubccq_b, MATCH_PDMSUBCCQ_B, MASK_PDMSUBCCQ_B)
DECLARE_INSN(pdmsubccq_h, MATCH_PDMSUBCCQ_H, MASK_PDMSUBCCQ_H)
DECLARE_INSN(pwmsubcr_b, MATCH_PWMSUBCR_B, MASK_PWMSUBCR_B)
DECLARE_INSN(pwmsubcr_h, MATCH_PWMSUBCR_H, MASK_PWMSUBCR_H)
DECLARE_INSN(pdmsubcr_b, MATCH_PDMSUBCR_B, MASK_PDMSUBCR_B)
DECLARE_INSN(pdmsubcr_h, MATCH_PDMSUBCR_H, MASK_PDMSUBCR_H)
DECLARE_INSN(pwmsubcrq_b, MATCH_PWMSUBCRQ_B, MASK_PWMSUBCRQ_B)
DECLARE_INSN(pwmsubcrq_h, MATCH_PWMSUBCRQ_H, MASK_PWMSUBCRQ_H)
DECLARE_INSN(pdmsubcrq_b, MATCH_PDMSUBCRQ_B, MASK_PDMSUBCRQ_B)
DECLARE_INSN(pdmsubcrq_h, MATCH_PDMSUBCRQ_H, MASK_PDMSUBCRQ_H)
#endif /* DECLARE_INSN.  */
#ifdef DECLARE_CSR
/* Privileged.  */
DECLARE_CSR(ustatus, CSR_USTATUS, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(uie, CSR_UIE, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(utvec, CSR_UTVEC, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(uscratch, CSR_USCRATCH, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(uepc, CSR_UEPC, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(ucause, CSR_UCAUSE, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(utval, CSR_UTVAL, CSR_CLASS_I, PRIV_SPEC_CLASS_1P10, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(uip, CSR_UIP, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(cycle, CSR_CYCLE, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(time, CSR_TIME, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(instret, CSR_INSTRET, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter3, CSR_HPMCOUNTER3, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter4, CSR_HPMCOUNTER4, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter5, CSR_HPMCOUNTER5, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter6, CSR_HPMCOUNTER6, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter7, CSR_HPMCOUNTER7, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter8, CSR_HPMCOUNTER8, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter9, CSR_HPMCOUNTER9, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter10, CSR_HPMCOUNTER10, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter11, CSR_HPMCOUNTER11, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter12, CSR_HPMCOUNTER12, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter13, CSR_HPMCOUNTER13, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter14, CSR_HPMCOUNTER14, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter15, CSR_HPMCOUNTER15, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter16, CSR_HPMCOUNTER16, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter17, CSR_HPMCOUNTER17, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter18, CSR_HPMCOUNTER18, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter19, CSR_HPMCOUNTER19, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter20, CSR_HPMCOUNTER20, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter21, CSR_HPMCOUNTER21, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter22, CSR_HPMCOUNTER22, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter23, CSR_HPMCOUNTER23, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter24, CSR_HPMCOUNTER24, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter25, CSR_HPMCOUNTER25, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter26, CSR_HPMCOUNTER26, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter27, CSR_HPMCOUNTER27, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter28, CSR_HPMCOUNTER28, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter29, CSR_HPMCOUNTER29, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter30, CSR_HPMCOUNTER30, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter31, CSR_HPMCOUNTER31, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(cycleh, CSR_CYCLEH, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(timeh, CSR_TIMEH, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(instreth, CSR_INSTRETH, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter3h, CSR_HPMCOUNTER3H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter4h, CSR_HPMCOUNTER4H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter5h, CSR_HPMCOUNTER5H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter6h, CSR_HPMCOUNTER6H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter7h, CSR_HPMCOUNTER7H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter8h, CSR_HPMCOUNTER8H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter9h, CSR_HPMCOUNTER9H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter10h, CSR_HPMCOUNTER10H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter11h, CSR_HPMCOUNTER11H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter12h, CSR_HPMCOUNTER12H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter13h, CSR_HPMCOUNTER13H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter14h, CSR_HPMCOUNTER14H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter15h, CSR_HPMCOUNTER15H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter16h, CSR_HPMCOUNTER16H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter17h, CSR_HPMCOUNTER17H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter18h, CSR_HPMCOUNTER18H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter19h, CSR_HPMCOUNTER19H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter20h, CSR_HPMCOUNTER20H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter21h, CSR_HPMCOUNTER21H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter22h, CSR_HPMCOUNTER22H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter23h, CSR_HPMCOUNTER23H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter24h, CSR_HPMCOUNTER24H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter25h, CSR_HPMCOUNTER25H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter26h, CSR_HPMCOUNTER26H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter27h, CSR_HPMCOUNTER27H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter28h, CSR_HPMCOUNTER28H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter29h, CSR_HPMCOUNTER29H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter30h, CSR_HPMCOUNTER30H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(hpmcounter31h, CSR_HPMCOUNTER31H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(sstatus, CSR_SSTATUS, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(sedeleg, CSR_SEDELEG, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(sideleg, CSR_SIDELEG, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(sie, CSR_SIE, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(stvec, CSR_STVEC, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(scounteren, CSR_SCOUNTEREN, CSR_CLASS_I, PRIV_SPEC_CLASS_1P10, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(sscratch, CSR_SSCRATCH, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(sepc, CSR_SEPC, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(scause, CSR_SCAUSE, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(stval, CSR_STVAL, CSR_CLASS_I, PRIV_SPEC_CLASS_1P10, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(sip, CSR_SIP, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(satp, CSR_SATP, CSR_CLASS_I, PRIV_SPEC_CLASS_1P10, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mvendorid, CSR_MVENDORID, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(marchid, CSR_MARCHID, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mimpid, CSR_MIMPID, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhartid, CSR_MHARTID, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mstatus, CSR_MSTATUS, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(misa, CSR_MISA, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(medeleg, CSR_MEDELEG, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mideleg, CSR_MIDELEG, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mie, CSR_MIE, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mtvec, CSR_MTVEC, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mcounteren, CSR_MCOUNTEREN, CSR_CLASS_I, PRIV_SPEC_CLASS_1P10, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mscratch, CSR_MSCRATCH, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mepc, CSR_MEPC, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mcause, CSR_MCAUSE, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mtval, CSR_MTVAL, CSR_CLASS_I, PRIV_SPEC_CLASS_1P10, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mip, CSR_MIP, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(pmpcfg0, CSR_PMPCFG0, CSR_CLASS_I, PRIV_SPEC_CLASS_1P10, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(pmpcfg1, CSR_PMPCFG1, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P10, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(pmpcfg2, CSR_PMPCFG2, CSR_CLASS_I, PRIV_SPEC_CLASS_1P10, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(pmpcfg3, CSR_PMPCFG3, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P10, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(pmpaddr0, CSR_PMPADDR0, CSR_CLASS_I, PRIV_SPEC_CLASS_1P10, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(pmpaddr1, CSR_PMPADDR1, CSR_CLASS_I, PRIV_SPEC_CLASS_1P10, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(pmpaddr2, CSR_PMPADDR2, CSR_CLASS_I, PRIV_SPEC_CLASS_1P10, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(pmpaddr3, CSR_PMPADDR3, CSR_CLASS_I, PRIV_SPEC_CLASS_1P10, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(pmpaddr4, CSR_PMPADDR4, CSR_CLASS_I, PRIV_SPEC_CLASS_1P10, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(pmpaddr5, CSR_PMPADDR5, CSR_CLASS_I, PRIV_SPEC_CLASS_1P10, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(pmpaddr6, CSR_PMPADDR6, CSR_CLASS_I, PRIV_SPEC_CLASS_1P10, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(pmpaddr7, CSR_PMPADDR7, CSR_CLASS_I, PRIV_SPEC_CLASS_1P10, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(pmpaddr8, CSR_PMPADDR8, CSR_CLASS_I, PRIV_SPEC_CLASS_1P10, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(pmpaddr9, CSR_PMPADDR9, CSR_CLASS_I, PRIV_SPEC_CLASS_1P10, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(pmpaddr10, CSR_PMPADDR10, CSR_CLASS_I, PRIV_SPEC_CLASS_1P10, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(pmpaddr11, CSR_PMPADDR11, CSR_CLASS_I, PRIV_SPEC_CLASS_1P10, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(pmpaddr12, CSR_PMPADDR12, CSR_CLASS_I, PRIV_SPEC_CLASS_1P10, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(pmpaddr13, CSR_PMPADDR13, CSR_CLASS_I, PRIV_SPEC_CLASS_1P10, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(pmpaddr14, CSR_PMPADDR14, CSR_CLASS_I, PRIV_SPEC_CLASS_1P10, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(pmpaddr15, CSR_PMPADDR15, CSR_CLASS_I, PRIV_SPEC_CLASS_1P10, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mcycle, CSR_MCYCLE, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(minstret, CSR_MINSTRET, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter3, CSR_MHPMCOUNTER3, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter4, CSR_MHPMCOUNTER4, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter5, CSR_MHPMCOUNTER5, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter6, CSR_MHPMCOUNTER6, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter7, CSR_MHPMCOUNTER7, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter8, CSR_MHPMCOUNTER8, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter9, CSR_MHPMCOUNTER9, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter10, CSR_MHPMCOUNTER10, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter11, CSR_MHPMCOUNTER11, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter12, CSR_MHPMCOUNTER12, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter13, CSR_MHPMCOUNTER13, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter14, CSR_MHPMCOUNTER14, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter15, CSR_MHPMCOUNTER15, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter16, CSR_MHPMCOUNTER16, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter17, CSR_MHPMCOUNTER17, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter18, CSR_MHPMCOUNTER18, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter19, CSR_MHPMCOUNTER19, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter20, CSR_MHPMCOUNTER20, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter21, CSR_MHPMCOUNTER21, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter22, CSR_MHPMCOUNTER22, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter23, CSR_MHPMCOUNTER23, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter24, CSR_MHPMCOUNTER24, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter25, CSR_MHPMCOUNTER25, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter26, CSR_MHPMCOUNTER26, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter27, CSR_MHPMCOUNTER27, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter28, CSR_MHPMCOUNTER28, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter29, CSR_MHPMCOUNTER29, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter30, CSR_MHPMCOUNTER30, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter31, CSR_MHPMCOUNTER31, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mcycleh, CSR_MCYCLEH, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(minstreth, CSR_MINSTRETH, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter3h, CSR_MHPMCOUNTER3H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter4h, CSR_MHPMCOUNTER4H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter5h, CSR_MHPMCOUNTER5H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter6h, CSR_MHPMCOUNTER6H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter7h, CSR_MHPMCOUNTER7H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter8h, CSR_MHPMCOUNTER8H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter9h, CSR_MHPMCOUNTER9H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter10h, CSR_MHPMCOUNTER10H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter11h, CSR_MHPMCOUNTER11H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter12h, CSR_MHPMCOUNTER12H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter13h, CSR_MHPMCOUNTER13H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter14h, CSR_MHPMCOUNTER14H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter15h, CSR_MHPMCOUNTER15H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter16h, CSR_MHPMCOUNTER16H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter17h, CSR_MHPMCOUNTER17H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter18h, CSR_MHPMCOUNTER18H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter19h, CSR_MHPMCOUNTER19H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter20h, CSR_MHPMCOUNTER20H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter21h, CSR_MHPMCOUNTER21H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter22h, CSR_MHPMCOUNTER22H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter23h, CSR_MHPMCOUNTER23H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter24h, CSR_MHPMCOUNTER24H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter25h, CSR_MHPMCOUNTER25H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter26h, CSR_MHPMCOUNTER26H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter27h, CSR_MHPMCOUNTER27H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter28h, CSR_MHPMCOUNTER28H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter29h, CSR_MHPMCOUNTER29H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter30h, CSR_MHPMCOUNTER30H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmcounter31h, CSR_MHPMCOUNTER31H, CSR_CLASS_I_32, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mcountinhibit, CSR_MCOUNTINHIBIT, CSR_CLASS_I, PRIV_SPEC_CLASS_1P11, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmevent3, CSR_MHPMEVENT3, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmevent4, CSR_MHPMEVENT4, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmevent5, CSR_MHPMEVENT5, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmevent6, CSR_MHPMEVENT6, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmevent7, CSR_MHPMEVENT7, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmevent8, CSR_MHPMEVENT8, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmevent9, CSR_MHPMEVENT9, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmevent10, CSR_MHPMEVENT10, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmevent11, CSR_MHPMEVENT11, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmevent12, CSR_MHPMEVENT12, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmevent13, CSR_MHPMEVENT13, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmevent14, CSR_MHPMEVENT14, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmevent15, CSR_MHPMEVENT15, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmevent16, CSR_MHPMEVENT16, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmevent17, CSR_MHPMEVENT17, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmevent18, CSR_MHPMEVENT18, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmevent19, CSR_MHPMEVENT19, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmevent20, CSR_MHPMEVENT20, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmevent21, CSR_MHPMEVENT21, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmevent22, CSR_MHPMEVENT22, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmevent23, CSR_MHPMEVENT23, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmevent24, CSR_MHPMEVENT24, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmevent25, CSR_MHPMEVENT25, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmevent26, CSR_MHPMEVENT26, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmevent27, CSR_MHPMEVENT27, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmevent28, CSR_MHPMEVENT28, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmevent29, CSR_MHPMEVENT29, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmevent30, CSR_MHPMEVENT30, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
DECLARE_CSR(mhpmevent31, CSR_MHPMEVENT31, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_DRAFT)
/* Dropped.  */
DECLARE_CSR(hstatus, CSR_HSTATUS, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_1P10)
DECLARE_CSR(hedeleg, CSR_HEDELEG, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_1P10)
DECLARE_CSR(hideleg, CSR_HIDELEG, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_1P10)
DECLARE_CSR(hie, CSR_HIE, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_1P10)
DECLARE_CSR(htvec, CSR_HTVEC, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_1P10)
DECLARE_CSR(hscratch, CSR_HSCRATCH, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_1P10)
DECLARE_CSR(hepc, CSR_HEPC, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_1P10)
DECLARE_CSR(hcause, CSR_HCAUSE, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_1P10)
DECLARE_CSR(hbadaddr, CSR_HBADADDR, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_1P10)
DECLARE_CSR(hip, CSR_HIP, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_1P10)
DECLARE_CSR(mbase, CSR_MBASE, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_1P10)
DECLARE_CSR(mbound, CSR_MBOUND, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_1P10)
DECLARE_CSR(mibase, CSR_MIBASE, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_1P10)
DECLARE_CSR(mibound, CSR_MIBOUND, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_1P10)
DECLARE_CSR(mdbase, CSR_MDBASE, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_1P10)
DECLARE_CSR(mdbound, CSR_MDBOUND, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_1P10)
DECLARE_CSR(mscounteren, CSR_MSCOUNTEREN, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_1P10)
DECLARE_CSR(mhcounteren, CSR_MHCOUNTEREN, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_1P10)
/* Unprivileged.  */
DECLARE_CSR(fflags, CSR_FFLAGS, CSR_CLASS_F, PRIV_SPEC_CLASS_NONE, PRIV_SPEC_CLASS_NONE)
DECLARE_CSR(frm, CSR_FRM, CSR_CLASS_F, PRIV_SPEC_CLASS_NONE, PRIV_SPEC_CLASS_NONE)
DECLARE_CSR(fcsr, CSR_FCSR, CSR_CLASS_F, PRIV_SPEC_CLASS_NONE, PRIV_SPEC_CLASS_NONE)
DECLARE_CSR(dcsr, CSR_DCSR, CSR_CLASS_DEBUG, PRIV_SPEC_CLASS_NONE, PRIV_SPEC_CLASS_NONE)
DECLARE_CSR(dpc, CSR_DPC, CSR_CLASS_DEBUG, PRIV_SPEC_CLASS_NONE, PRIV_SPEC_CLASS_NONE)
DECLARE_CSR(dscratch0, CSR_DSCRATCH0, CSR_CLASS_DEBUG, PRIV_SPEC_CLASS_NONE, PRIV_SPEC_CLASS_NONE)
DECLARE_CSR(dscratch1, CSR_DSCRATCH1, CSR_CLASS_DEBUG, PRIV_SPEC_CLASS_NONE, PRIV_SPEC_CLASS_NONE)
DECLARE_CSR(tselect, CSR_TSELECT, CSR_CLASS_DEBUG, PRIV_SPEC_CLASS_NONE, PRIV_SPEC_CLASS_NONE)
DECLARE_CSR(tdata1, CSR_TDATA1, CSR_CLASS_DEBUG, PRIV_SPEC_CLASS_NONE, PRIV_SPEC_CLASS_NONE)
DECLARE_CSR(tdata2, CSR_TDATA2, CSR_CLASS_DEBUG, PRIV_SPEC_CLASS_NONE, PRIV_SPEC_CLASS_NONE)
DECLARE_CSR(tdata3, CSR_TDATA3, CSR_CLASS_DEBUG, PRIV_SPEC_CLASS_NONE, PRIV_SPEC_CLASS_NONE)
DECLARE_CSR(tinfo, CSR_TINFO, CSR_CLASS_DEBUG, PRIV_SPEC_CLASS_NONE, PRIV_SPEC_CLASS_NONE)
DECLARE_CSR(tcontrol, CSR_TCONTROL, CSR_CLASS_DEBUG, PRIV_SPEC_CLASS_NONE, PRIV_SPEC_CLASS_NONE)
DECLARE_CSR(mcontext, CSR_MCONTEXT, CSR_CLASS_DEBUG, PRIV_SPEC_CLASS_NONE, PRIV_SPEC_CLASS_NONE)
DECLARE_CSR(scontext, CSR_SCONTEXT, CSR_CLASS_DEBUG, PRIV_SPEC_CLASS_NONE, PRIV_SPEC_CLASS_NONE)
#endif /* DECLARE_CSR.  */
#ifdef DECLARE_CSR_ALIAS
DECLARE_CSR_ALIAS(ubadaddr, CSR_UTVAL, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_1P10)
DECLARE_CSR_ALIAS(sbadaddr, CSR_STVAL, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_1P10)
DECLARE_CSR_ALIAS(sptbr, CSR_SATP, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_1P10)
DECLARE_CSR_ALIAS(mbadaddr, CSR_MTVAL, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_1P10)
DECLARE_CSR_ALIAS(mucounteren, CSR_MCOUNTINHIBIT, CSR_CLASS_I, PRIV_SPEC_CLASS_1P9P1, PRIV_SPEC_CLASS_1P10)
DECLARE_CSR_ALIAS(dscratch, CSR_DSCRATCH0, CSR_CLASS_DEBUG, PRIV_SPEC_CLASS_NONE, PRIV_SPEC_CLASS_NONE)
DECLARE_CSR_ALIAS(mcontrol, CSR_TDATA1, CSR_CLASS_DEBUG, PRIV_SPEC_CLASS_NONE, PRIV_SPEC_CLASS_NONE)
DECLARE_CSR_ALIAS(icount, CSR_TDATA1, CSR_CLASS_DEBUG, PRIV_SPEC_CLASS_NONE, PRIV_SPEC_CLASS_NONE)
DECLARE_CSR_ALIAS(itrigger, CSR_TDATA1, CSR_CLASS_DEBUG, PRIV_SPEC_CLASS_NONE, PRIV_SPEC_CLASS_NONE)
DECLARE_CSR_ALIAS(etrigger, CSR_TDATA1, CSR_CLASS_DEBUG, PRIV_SPEC_CLASS_NONE, PRIV_SPEC_CLASS_NONE)
DECLARE_CSR_ALIAS(textra32, CSR_TDATA3, CSR_CLASS_DEBUG, PRIV_SPEC_CLASS_NONE, PRIV_SPEC_CLASS_NONE)
DECLARE_CSR_ALIAS(textra64, CSR_TDATA3, CSR_CLASS_DEBUG, PRIV_SPEC_CLASS_NONE, PRIV_SPEC_CLASS_NONE)
#endif /* DECLARE_CSR_ALIAS.  */
